@@ -1,7 +1,23 @@
 #include "Diplomacy.h"
 
+#include "../util/GameRules.h"
+#include "../util/i18n.h"
+
 FO_COMMON_API extern const int ALL_EMPIRES;
 
+namespace {
+    void AddRules(GameRules& rules) {
+        // determine if diplomacy allowed
+        rules.Add<std::string>("RULE_DIPLOMACY", "RULE_DIPLOMACY_DESC",
+                               "MULTIPLAYER", "RULE_DIPLOMACY_ALLOWED_FOR_ALL", true,
+                               DiscreteValidator<std::string>(std::set<std::string>({
+                                   "RULE_DIPLOMACY_ALLOWED_FOR_ALL",
+                                   "RULE_DIPLOMACY_FORBIDDEN_FOR_ALL"
+                               })));
+    }
+    bool temp_bool = RegisterGameRules(&AddRules);
+}
+
 DiplomaticMessage::DiplomaticMessage() :
     m_sender_empire(ALL_EMPIRES),
     m_recipient_empire(ALL_EMPIRES),
@@ -42,6 +58,10 @@ std::string DiplomaticMessage::Dump() const {
     return retval;
 }
 
+bool DiplomaticMessage::IsAllowed() const {
+    return GetGameRules().Get<std::string>("RULE_DIPLOMACY") != UserStringNop("RULE_DIPLOMACY_FORBIDDEN_FOR_ALL");
+}
+
 
 DiplomaticStatusUpdateInfo::DiplomaticStatusUpdateInfo() :
     empire1_id(ALL_EMPIRES),
