@@ -2,6 +2,8 @@
 
 #include "Empire.h"
 #include "../util/Directories.h"
+#include "../util/GameRules.h"
+#include "../util/i18n.h"
 #include "../util/Logger.h"
 #include "../util/XMLDoc.h"
 #include "../universe/Enums.h"
@@ -26,6 +28,13 @@ const EmpireManager& EmpireManager::operator=(EmpireManager& rhs) {
     Clear();
     m_empire_map = rhs.m_empire_map;
     rhs.m_empire_map.clear();
+
+    m_empire_diplomatic_statuses = rhs.m_empire_diplomatic_statuses;
+    rhs.m_empire_diplomatic_statuses.clear();
+
+    m_diplomatic_messages = rhs.m_diplomatic_messages;
+    rhs.m_diplomatic_messages.clear();
+
     return *this;
 }
 
@@ -53,6 +62,16 @@ EmpireManager::const_iterator EmpireManager::end() const
 int EmpireManager::NumEmpires() const
 { return m_empire_map.size(); }
 
+int EmpireManager::NumEliminatedEmpires() const {
+    int eliminated_count = 0;
+
+    for (const auto& empire : m_empire_map)
+        if (empire.second->Eliminated())
+            eliminated_count++;
+
+    return eliminated_count;
+}
+
 std::string EmpireManager::Dump() const {
     std::string retval = "Empires:\n";
     for (const auto& entry : m_empire_map)
@@ -107,9 +126,9 @@ void EmpireManager::BackPropagateMeters() {
 
 Empire* EmpireManager::CreateEmpire(int empire_id, const std::string& name,
                                     const std::string& player_name,
-                                    const GG::Clr& color)
+                                    const GG::Clr& color, bool authenticated)
 {
-    Empire* empire = new Empire(name, player_name, empire_id, color);
+    Empire* empire = new Empire(name, player_name, empire_id, color, authenticated);
     InsertEmpire(empire);
     return empire;
 }
@@ -216,8 +235,11 @@ void EmpireManager::HandleDiplomaticMessage(const DiplomaticMessage& message) {
     int sender_empire_id = message.SenderEmpireID();
     int recipient_empire_id = message.RecipientEmpireID();
 
+    if (!message.IsAllowed())
+        return;
+
     DiplomaticStatus diplo_status = GetDiplomaticStatus(sender_empire_id, recipient_empire_id);
-    bool message_from_recipient_to_sender_available = DiplomaticMessageAvailable(recipient_empire_id, sender_empire_id); 
+    bool message_from_recipient_to_sender_available = DiplomaticMessageAvailable(recipient_empire_id, sender_empire_id);
     const DiplomaticMessage& existing_message_from_recipient_to_sender = GetDiplomaticMessage(recipient_empire_id, sender_empire_id);
     //bool message_from_sender_to_recipient_available = DiplomaticMessageAvailable(sender_empire_id, recipient_empire_id);
 
