@@ -1,5 +1,5 @@
 // -*- C++ -*-
-/* GG is a GUI for SDL and OpenGL.
+/* GG is a GUI for OpenGL.
    Copyright (C) 2003-2008 T. Zachary Laine
 
    This library is free software; you can redistribute it and/or
@@ -44,7 +44,7 @@ class GroupBox;
 class ListBox;
 class RadioButtonGroup;
 class Scroll;
-template <class T>
+template <typename T>
 class Slider;
 class StateButton;
 class TabBar;
