@@ -1,4 +1,4 @@
-/* GG is a GUI for SDL and OpenGL.
+/* GG is a GUI for OpenGL.
    Copyright (C) 2003-2008 T. Zachary Laine
 
    This library is free software; you can redistribute it and/or
@@ -32,13 +32,11 @@ using namespace GG;
 // GG::Control
 ////////////////////////////////////////////////
 Control::Control() :
-    Wnd (),
-    m_disabled(false)
+    Wnd()
 {}
 
 Control::Control(X x, Y y, X w, Y h, Flags<WndFlag> flags/* = INTERACTIVE*/) :
-    Wnd(x, y, w, h, flags),
-    m_disabled(false)
+    Wnd(x, y, w, h, flags)
 {}
 
 Clr Control::Color() const
