@@ -174,14 +174,18 @@ ModalListPicker::ModalListPicker(Clr color, const DropDownList* relative_to_wnd,
 
 void ModalListPicker::CompleteConstruction()
 {
-    namespace ph = boost::placeholders;
+#if BOOST_VERSION >= 106000
+    using boost::placeholders::_1;
+    using boost::placeholders::_2;
+    using boost::placeholders::_3;
+#endif
 
     m_lb_wnd->SelRowsChangedSignal.connect(
-        boost::bind(&ModalListPicker::LBSelChangedSlot, this, ph::_1));
+        boost::bind(&ModalListPicker::LBSelChangedSlot, this, _1));
     m_lb_wnd->LeftClickedRowSignal.connect(
-        boost::bind(&ModalListPicker::LBLeftClickSlot, this, ph::_1, ph::_2, ph::_3));
+        boost::bind(&ModalListPicker::LBLeftClickSlot, this, _1, _2, _3));
     GUI::GetGUI()->WindowResizedSignal.connect(
-        boost::bind(&ModalListPicker::WindowResizedSlot, this, ph::_1, ph::_2));
+        boost::bind(&ModalListPicker::WindowResizedSlot, this, _1, _2));
     AttachChild(m_lb_wnd);
     m_lb_wnd->InstallEventFilter(shared_from_this());
 
@@ -871,7 +875,7 @@ void DropDownList::UnLockColWidths()
 void DropDownList::ManuallyManageColProps()
 { LB()->ManuallyManageColProps(); }
 
-void DropDownList::SetColAlignment(std::size_t n, Alignment align) 
+void DropDownList::SetColAlignment(std::size_t n, Alignment align)
 { LB()->SetColAlignment(n, align); }
 
 void DropDownList::SetRowAlignment(iterator it, Alignment align)
