@@ -1,16 +1,16 @@
-/* GG is a GUI for SDL and OpenGL.
+/* GG is a GUI for OpenGL.
    Copyright (C) 2003-2008 T. Zachary Laine
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public License
    as published by the Free Software Foundation; either version 2.1
    of the License, or (at your option) any later version.
-   
+
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.
-    
+
    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free
    Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
@@ -18,7 +18,7 @@
 
    If you do not wish to comply with the terms of the LGPL please
    contact the author as other terms are available for a fee.
-    
+
    Zach Laine
    whatwasthataddress@gmail.com */
 
@@ -46,13 +46,18 @@
 
 #include <iostream>
 #include <iomanip>
-#include <boost/scoped_array.hpp>
+
+#if BOOST_VERSION >= 107400
+#include <boost/variant2/variant.hpp>
+#elif BOOST_VERSION >= 107000
+#include <boost/variant/get.hpp>
+#endif
 
 
 using namespace GG;
 
 namespace {
-    template <class T>
+    template <typename T>
     T PowerOfTwo(T input)
     {
         T value(1);
@@ -65,21 +70,7 @@ namespace {
 ///////////////////////////////////////
 // class GG::Texture
 ///////////////////////////////////////
-Texture::Texture() :
-    m_bytes_pp(0),
-    m_width(0),
-    m_height(0),
-    m_wrap_s(GL_REPEAT),
-    m_wrap_t(GL_REPEAT),
-    m_min_filter(GL_LINEAR_MIPMAP_LINEAR),
-    m_mag_filter(GL_LINEAR),
-    m_mipmaps(false),
-    m_opengl_id(0),
-    m_format(GL_INVALID_ENUM),
-    m_type(GL_INVALID_ENUM),
-    m_tex_coords(),
-    m_default_width(0),
-    m_default_height(0)
+Texture::Texture()
 { Clear(); }
 
 Texture::~Texture()
@@ -220,19 +211,29 @@ void Texture::Load(const boost::filesystem::path& path, bool mipmap/* = false*/)
     std::string filename = path.generic_string();
 #endif
 
-    BOOST_STATIC_ASSERT((sizeof(gil::gray8_pixel_t) == 1));
-    BOOST_STATIC_ASSERT((sizeof(gil::gray_alpha8_pixel_t) == 2));
-    BOOST_STATIC_ASSERT((sizeof(gil::rgb8_pixel_t) == 3));
-    BOOST_STATIC_ASSERT((sizeof(gil::rgba8_pixel_t) == 4));
+    static_assert(sizeof(gil::gray8_pixel_t) == 1, "gray8 pixel type does not match expected type size");
+    static_assert(sizeof(gil::gray_alpha8_pixel_t) == 2, "gray_alpha8 pixel type does not match expected type size");
+    static_assert(sizeof(gil::rgb8_pixel_t) == 3, "rgb8 pixel type does not match expected type size");
+    static_assert(sizeof(gil::rgba8_pixel_t) == 4, "rgba8 pixel type does not match expected type size");
 
+#if BOOST_VERSION >= 107400
+    typedef gil::any_image<gil::gray8_image_t,
+        gil::gray_alpha8_image_t,
+        gil::rgb8_image_t,
+        gil::rgba8_image_t> ImageType;
+#else
+# ifdef BOOST_GIL_USES_MP11
+    typedef boost::mp11::mp_list<
+# else
     typedef boost::mpl::vector4<
+# endif
         gil::gray8_image_t,
         gil::gray_alpha8_image_t,
         gil::rgb8_image_t,
         gil::rgba8_image_t
     > ImageTypes;
     typedef gil::any_image<ImageTypes> ImageType;
-
+#endif
     if (!fs::exists(path))
         throw BadFile("Texture file \"" + filename + "\" does not exist");
     if (!fs::is_regular_file(path))
@@ -255,21 +256,21 @@ void Texture::Load(const boost::filesystem::path& path, bool mipmap/* = false*/)
         else
 #endif
             throw BadFile("Texture file \"" + filename + "\" does not have a supported file extension");
-    } catch (const std::ios_base::failure &) {
+    } catch (const std::ios_base::failure&) {
         // Second attempt -- If *_read_image() throws, see if we can convert
         // the image to RGBA.  This is needed for color-indexed images.
 #if GG_HAVE_LIBPNG
         if (extension == ".png") {
             gil::rgba8_image_t rgba_image;
             gil::read_and_convert_image(filename, rgba_image, gil::image_read_settings<gil::png_tag>());
-            image.move_in(rgba_image);
+            image = std::move(rgba_image);
         }
 #endif
 #if GG_HAVE_LIBTIFF
         if (extension == ".tif" || extension == ".tiff") {
             gil::rgba8_image_t rgba_image;
             gil::read_and_convert_image(filename, rgba_image, gil::image_read_settings<gil::tiff_tag>());
-            image.move_in(rgba_image);
+            image = std::move(rgba_image);
         }
 #endif
     }
@@ -279,12 +280,28 @@ void Texture::Load(const boost::filesystem::path& path, bool mipmap/* = false*/)
     m_default_height = Y(image.height());
     m_type = GL_UNSIGNED_BYTE;
 
+#if BOOST_VERSION >= 107400
+#define IF_IMAGE_TYPE_IS(image_prefix)                                  \
+    if (boost::variant2::get_if<image_prefix ## _image_t>(&image)) {    \
+        m_bytes_pp = sizeof(image_prefix ## _pixel_t);                  \
+        image_data = interleaved_view_get_raw_data(                     \
+            const_view(boost::variant2::get<image_prefix ## _image_t>(image))); \
+    }
+#elif BOOST_VERSION >= 107000
+#define IF_IMAGE_TYPE_IS(image_prefix)                                  \
+    if (boost::get<image_prefix ## _image_t>(&image)) {                 \
+        m_bytes_pp = sizeof(image_prefix ## _pixel_t);                  \
+        image_data = interleaved_view_get_raw_data(                     \
+            const_view(boost::get<image_prefix ## _image_t>(image)));   \
+    }
+#else
 #define IF_IMAGE_TYPE_IS(image_prefix)                                  \
     if (image.current_type_is<image_prefix ## _image_t>()) {            \
         m_bytes_pp = sizeof(image_prefix ## _pixel_t);                  \
         image_data = interleaved_view_get_raw_data(                     \
             const_view(image._dynamic_cast<image_prefix ## _image_t>())); \
     }
+#endif
 
     const unsigned char* image_data = nullptr;
 
@@ -307,27 +324,6 @@ void Texture::Load(const boost::filesystem::path& path, bool mipmap/* = false*/)
     Init(m_default_width, m_default_height, image_data, m_format, m_type, m_bytes_pp, mipmap);
 }
 
-void Texture::Init(X x, Y y, X width, Y height, X image_width, const unsigned char* image,
-                   GLenum format, GLenum type, unsigned int bytes_per_pixel, bool mipmap/* = false*/)
-{
-    glPushClientAttrib(GL_CLIENT_PIXEL_STORE_BIT);
-    glPixelStorei(GL_UNPACK_SWAP_BYTES, false);
-    glPixelStorei(GL_UNPACK_LSB_FIRST, false);
-    glPixelStorei(GL_UNPACK_ROW_LENGTH, Value(image_width));
-    glPixelStorei(GL_UNPACK_SKIP_ROWS, Value(y));
-    glPixelStorei(GL_UNPACK_SKIP_PIXELS, Value(x));
-    glPixelStorei(GL_UNPACK_ALIGNMENT, 1);
-
-    try {
-        InitFromRawData(width, height, image, format, type, bytes_per_pixel, mipmap);
-    } catch (...) {
-        glPopClientAttrib();
-        throw;
-    }
-
-    glPopClientAttrib();
-}
-
 void Texture::Init(X width, Y height, const unsigned char* image, GLenum format, GLenum type,
                    unsigned int bytes_per_pixel, bool mipmap/* = false*/)
 {
@@ -349,17 +345,6 @@ void Texture::Init(X width, Y height, const unsigned char* image, GLenum format,
     glPopClientAttrib();
 }
 
-void Texture::SetWrap(GLenum s, GLenum t)
-{
-    m_wrap_s = s;
-    m_wrap_t = t;
-    if (m_opengl_id) {
-        glBindTexture(GL_TEXTURE_2D, m_opengl_id);
-        glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, m_wrap_s);
-        glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, m_wrap_t);
-    }
-}
-
 void Texture::SetFilters(GLenum min, GLenum mag)
 {
     m_min_filter = min;
@@ -415,6 +400,13 @@ void Texture::InitFromRawData(X width, Y height, const unsigned char* image, GLe
     glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, m_wrap_s);
     glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, m_wrap_t);
 
+    if (mipmap) {
+        glTexParameteri(GL_TEXTURE_2D, GL_GENERATE_MIPMAP, GL_TRUE);
+    } else {
+        glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_BASE_LEVEL, 0);
+        glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAX_LEVEL, 0);
+    }
+
     glTexImage2D(GL_PROXY_TEXTURE_2D, 0, format, Value(GL_texture_width), Value(GL_texture_height), 0, format, type, nullptr);
     GLint checked_format;
     glGetTexLevelParameteriv(GL_PROXY_TEXTURE_2D, 0, GL_TEXTURE_INTERNAL_FORMAT, &checked_format);
@@ -442,22 +434,6 @@ void Texture::InitFromRawData(X width, Y height, const unsigned char* image, GLe
     }
     m_tex_coords[2] = Value(1.0 * m_default_width / m_width);
     m_tex_coords[3] = Value(1.0 * m_default_height / m_height);
-
-    if (mipmap) {
-        boost::scoped_array<unsigned char> image_copy;
-        if (!image_is_power_of_two)
-            image_copy.reset(GetRawBytes());
-        unsigned char* image_to_use = image_copy ? image_copy.get() : const_cast<unsigned char*>(image);
-        gluBuild2DMipmaps(GL_PROXY_TEXTURE_2D, format, Value(GL_texture_width), Value(GL_texture_height), format, type, image_to_use);
-        GLint mipmap_checked_format;
-        glGetTexLevelParameteriv(GL_PROXY_TEXTURE_2D, 0, GL_TEXTURE_INTERNAL_FORMAT, &mipmap_checked_format);
-        if (!mipmap_checked_format)
-            throw InsufficientResources("Insufficient resources to create requested mipmapped OpenGL texture");
-        gluBuild2DMipmaps(GL_TEXTURE_2D, format, Value(GL_texture_width), Value(GL_texture_height), format, type, image_to_use);
-    } else {
-        glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_BASE_LEVEL, 0);
-        glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAX_LEVEL, 0);
-    }
 }
 
 unsigned char* Texture::GetRawBytes()
@@ -515,10 +491,10 @@ SubTexture::SubTexture(const std::shared_ptr<const Texture>& texture) :
     m_width = texture->Width();
     m_height = texture->Height();
 
-    m_tex_coords[0] = 0.0;
-    m_tex_coords[1] = 0.0;
-    m_tex_coords[2] = 1.0;
-    m_tex_coords[3] = 1.0;
+    m_tex_coords[0] = 0.0f;
+    m_tex_coords[1] = 0.0f;
+    m_tex_coords[2] = 1.0f;
+    m_tex_coords[3] = 1.0f;
 }
 
 SubTexture::~SubTexture()
@@ -562,13 +538,20 @@ void SubTexture::OrthoBlit(const Pt& pt1, const Pt& pt2) const
 void SubTexture::OrthoBlit(const Pt& pt) const
 { if (m_texture) m_texture->OrthoBlit(pt, pt + Pt(m_width, m_height), m_tex_coords); }
 
+void SubTexture::Clear()
+{
+    m_texture.reset();
+    m_width = X0;
+    m_height = Y0;
+    m_tex_coords[0] = 0.0f;
+    m_tex_coords[1] = 0.0f;
+    m_tex_coords[2] = 1.0f;
+    m_tex_coords[3] = 1.0f;
+}
 
 ///////////////////////////////////////
 // class GG::TextureManager
 ///////////////////////////////////////
-// static member(s)
-bool TextureManager::s_il_initialized = false;
-
 TextureManager::TextureManager()
 {}
 
