@@ -1,4 +1,4 @@
-/* GG is a GUI for SDL and OpenGL.
+/* GG is a GUI for OpenGL.
    Copyright (C) 2003-2008 T. Zachary Laine
 
    This library is free software; you can redistribute it and/or
@@ -155,19 +155,8 @@ FileDlg::FileDlg(const std::string& directory, const std::string& filename, bool
     m_text_color(text_color),
     m_font(font),
     m_save(save),
-    m_select_directories(false),
-    m_append_missing_save_extension(false),
-    m_in_win32_drive_selection(false),
     m_save_str(GetStyleFactory()->Translate("Save")),
     m_open_str(GetStyleFactory()->Translate("Open")),
-    m_curr_dir_text(nullptr),
-    m_files_list(nullptr),
-    m_files_edit(nullptr),
-    m_filter_list(nullptr),
-    m_ok_button(nullptr),
-    m_cancel_button(nullptr),
-    m_files_label(nullptr),
-    m_file_types_label(nullptr),
     m_init_directory(directory),
     m_init_filename(filename)
 {
@@ -207,7 +196,7 @@ void FileDlg::CompleteConstruction()
     AttachChild(m_files_label);
     AttachChild(m_file_types_label);
 
-    if (m_init_directory != "") {
+    if (!m_init_directory.empty()) {
 #if defined(_WIN32)
         // convert UTF-8 file name to UTF-16
         boost::filesystem::path::string_type directory_native;
@@ -225,18 +214,18 @@ void FileDlg::CompleteConstruction()
     PopulateFilters();
     UpdateList();
 
-    m_ok_button->LeftClickedSignal.connect(
-        boost::bind(&FileDlg::OkClicked, this));
-    m_cancel_button->LeftClickedSignal.connect(
-        boost::bind(&FileDlg::CancelClicked, this));
-    m_files_list->SelRowsChangedSignal.connect(
-        boost::bind(&FileDlg::FileSetChanged, this, _1));
-    m_files_list->DoubleClickedRowSignal.connect(
-        boost::bind(&FileDlg::FileDoubleClicked, this, _1, _2, _3));
-    m_files_edit->EditedSignal.connect(
-        boost::bind(&FileDlg::FilesEditChanged, this, _1));
-    m_filter_list->SelChangedSignal.connect(
-        boost::bind(&FileDlg::FilterChanged, this, _1));
+#if BOOST_VERSION >= 106000
+    using boost::placeholders::_1;
+    using boost::placeholders::_2;
+    using boost::placeholders::_3;
+#endif
+
+    m_ok_button->LeftClickedSignal.connect(boost::bind(&FileDlg::OkClicked, this));
+    m_cancel_button->LeftClickedSignal.connect(boost::bind(&FileDlg::CancelClicked, this));
+    m_files_list->SelRowsChangedSignal.connect(boost::bind(&FileDlg::FileSetChanged, this, _1));
+    m_files_list->DoubleClickedRowSignal.connect(boost::bind(&FileDlg::FileDoubleClicked, this, _1, _2, _3));
+    m_files_edit->EditedSignal.connect(boost::bind(&FileDlg::FilesEditChanged, this, _1));
+    m_filter_list->SelChangedSignal.connect(boost::bind(&FileDlg::FilterChanged, this, _1));
 
     if (!m_init_filename.empty()) {
         fs::path filename_path = fs::system_complete(fs::path(m_init_filename));
@@ -550,17 +539,17 @@ void FileDlg::UpdateList()
             if (non_wildcards->empty()) {
                 file_filters[i] = *anychar_p;
             } else {
-                file_filters[i] = 
+                file_filters[i] =
                     if_p (LeadingWildcard(filter_specs[i])) [
-                        *(wildcard - f_str_p(FrontStringBegin(non_wildcards), FrontStringEnd(non_wildcards))) 
+                        *(wildcard - f_str_p(FrontStringBegin(non_wildcards), FrontStringEnd(non_wildcards)))
                         >> f_str_p(FrontStringBegin(non_wildcards), FrontStringEnd(non_wildcards))
                     ] .else_p [
                         f_str_p(FrontStringBegin(non_wildcards), FrontStringEnd(non_wildcards))
-                    ] 
+                    ]
                     >> for_p (Index(1), IndexLess(static_cast<int>(non_wildcards->size()) - 1), IndexIncr()) [
                         *(wildcard - f_str_p(IndexedStringBegin(non_wildcards), IndexedStringEnd(non_wildcards)))
                         >> f_str_p(IndexedStringBegin(non_wildcards), IndexedStringEnd(non_wildcards))
-                    ] 
+                    ]
                     >> if_p (TrailingWildcard(filter_specs[i])) [
                         *wildcard
                     ];
@@ -571,7 +560,7 @@ void FileDlg::UpdateList()
     if (!m_in_win32_drive_selection) {
         // parent directory selector
         if ((s_working_dir.string() != s_working_dir.root_path().string() &&
-             s_working_dir.branch_path().string() != "") ||
+             !s_working_dir.branch_path().string().empty()) ||
             Win32Paths())
         {
             auto row = Wnd::Create<ListBox::Row>();
@@ -714,7 +703,7 @@ void FileDlg::OpenDirectory()
     } else if (directory == "..") {
         // move to parent directory of current directory
         if (s_working_dir.string() != s_working_dir.root_path().string() &&
-            s_working_dir.branch_path().string() != "")
+            !s_working_dir.branch_path().string().empty())
         {
             // move to new directory
             SetWorkingDirectory(s_working_dir.branch_path());
