@@ -1,4 +1,4 @@
-/* GG is a GUI for SDL and OpenGL.
+/* GG is a GUI for OpenGL.
    Copyright (C) 2003-2008 T. Zachary Laine
 
    This library is free software; you can redistribute it and/or
@@ -46,12 +46,7 @@ ThreeButtonDlg::ThreeButtonDlg(X w, Y h, const std::string& msg, const std::shar
     m_border_color(border_color),
     m_text_color(text_color),
     m_button_color(button_color),
-    m_default(0),
     m_escape(buttons - 1),
-    m_result(0),
-    m_button_0(nullptr),
-    m_button_1(nullptr),
-    m_button_2(nullptr),
     m_button_layout(Wnd::Create<Layout>(X0, Y0, X1, Y1, 2, 1, 10))
 {
     if (buttons < 1)
@@ -74,17 +69,17 @@ ThreeButtonDlg::ThreeButtonDlg(X w, Y h, const std::string& msg, const std::shar
     m_button_layout->SetRowStretch(0, 1);
     m_button_layout->SetMinimumRowHeight(1, BUTTON_HEIGHT);
 
-    m_button_0 = style->NewButton((zero == "" ? (buttons < 3 ? "Ok" : "Yes") : zero),
+    m_button_0 = style->NewButton((zero.empty() ? (buttons < 3 ? "Ok" : "Yes") : zero),
                                   font, m_button_color, m_text_color);
     button_layout->Add(m_button_0, 0, 0);
 
     if (2 <= buttons) {
-        m_button_1 = style->NewButton((one == "" ? (buttons < 3 ? "Cancel" : "No") : one),
+        m_button_1 = style->NewButton((one.empty() ? (buttons < 3 ? "Cancel" : "No") : one),
                                       font, m_button_color, m_text_color);
         button_layout->Add(m_button_1, 0, 1);
     }
     if (3 <= buttons) {
-        m_button_2 = style->NewButton((two == "" ? "Cancel" : two),
+        m_button_2 = style->NewButton((two.empty() ? "Cancel" : two),
                                       font, m_button_color, m_text_color);
         button_layout->Add(m_button_2, 0, 2);
     }
