@@ -5,6 +5,7 @@
 #include "CUIDrawUtil.h"
 #include "IconTextBrowseWnd.h"
 #include "Sound.h"
+#include "Hotkeys.h"
 #include "../client/human/HumanClientApp.h"
 #include "../util/i18n.h"
 #include "../util/Logger.h"
@@ -15,7 +16,6 @@
 
 #include <GG/utf8/checked.h>
 #include <GG/dialogs/ColorDlg.h>
-#include <GG/DrawUtil.h>
 #include <GG/GUI.h>
 #include <GG/Layout.h>
 
@@ -28,6 +28,11 @@
 
 
 namespace {
+    void AddOptions(OptionsDB& db) {
+        Hotkey::AddHotkey("ui.autocomplete",    UserStringNop("HOTKEY_AUTOCOMPLETE"),   GG::GGK_TAB);
+    }
+    bool temp_bool = RegisterOptions(&AddOptions);
+
     void PlayButtonClickSound()
     { Sound::GetSound().PlaySound(GetOptionsDB().Get<std::string>("ui.button.press.sound.path"), true); }
 
@@ -197,7 +202,7 @@ void CUIButton::RenderUnpressed() {
 SettableInWindowCUIButton::SettableInWindowCUIButton(const GG::SubTexture& unpressed,
                                                      const GG::SubTexture& pressed,
                                                      const GG::SubTexture& rollover,
-                                                     boost::function<bool(const SettableInWindowCUIButton*, const GG::Pt&)> in_window_function) :
+                                                     std::function<bool (const SettableInWindowCUIButton*, const GG::Pt&)> in_window_function) :
     CUIButton(unpressed, pressed, rollover)
 { m_in_window_func = in_window_function; }
 
@@ -603,7 +608,7 @@ void CUITabBar::DistinguishCurrentTab(const std::vector<GG::StateButton*>& tab_b
         if (index == i)
             tab->SetTextColor(text_color);
         else
-            tab->SetTextColor(DarkColor(text_color));
+            tab->SetTextColor(DarkenClr(text_color));
     }
 }
 
@@ -727,13 +732,11 @@ void CUIScroll::SizeMove(const GG::Pt& ul, const GG::Pt& lr) {
 ///////////////////////////////////////
 // class CUIListBox
 ///////////////////////////////////////
-CUIListBox::CUIListBox(void):
+CUIListBox::CUIListBox(void) :
     ListBox(ClientUI::CtrlBorderColor(), ClientUI::CtrlColor())
 {
-    SelRowsChangedSignal.connect(-1,
-        &PlayListSelectSound);
-    DroppedRowSignal.connect(-1,
-        &PlayItemDropSound);
+    SelRowsChangedSignal.connect(-1,    &PlayListSelectSound);
+    DroppedRowSignal.connect(-1,        &PlayItemDropSound);
 }
 
 void CUIListBox::Render() {
@@ -761,6 +764,7 @@ CUIDropDownList::CUIDropDownList(size_t num_shown_elements) :
 {
     SetInteriorColor(ClientUI::CtrlColor());
     SetMinSize(GG::Pt(MinSize().x, CUISimpleDropDownListRow::DEFAULT_ROW_HEIGHT));
+    SetChildClippingMode(ClipToClient);
 }
 
 void CUIDropDownList::InitBuffer() {
@@ -775,7 +779,7 @@ void CUIDropDownList::InitBuffer() {
 
     GG::Pt triangle_ul = GG::Pt(sz.x - triangle_width - margin * 5 / 2, GG::Y(2 * margin));
     GG::Pt triangle_lr = GG::Pt(sz.x - margin * 5 / 2, sz.y - 2 * margin);
-    BufferStoreIsoscelesTriangle(this->m_buffer, triangle_ul, triangle_lr, SHAPE_DOWN);
+    BufferStoreIsoscelesTriangle(this->m_buffer, triangle_ul, triangle_lr, ShapeOrientation::DOWN);
 
     GG::Pt btn_ul = GG::Pt(sz.x - outline_width - margin, GG::Y(margin));
     GG::Pt btn_lr = GG::Pt(sz.x - margin, sz.y - margin);
@@ -790,6 +794,8 @@ void CUIDropDownList::Render() {
     GG::Pt ul = UpperLeft();
     GG::Clr lb_color = LB()->Color();
     GG::Clr border_color = Disabled() ? DisabledColor(lb_color) : lb_color;
+    if (GG::GUI::GetGUI()->FocusWnd().get() == this)
+        border_color = GG::LightenClr(border_color);
     GG::Clr interior_color = Disabled() ? DisabledColor(InteriorColor()) : InteriorColor();
 
     glPushMatrix();
@@ -877,9 +883,16 @@ void CUIDropDownList::EnableDropArrow()
 CUIEdit::CUIEdit(const std::string& str) :
     Edit(str, ClientUI::GetFont(), ClientUI::CtrlBorderColor(),
          ClientUI::TextColor(), ClientUI::CtrlColor())
-{
+{}
+
+void CUIEdit::CompleteConstruction() {
     EditedSignal.connect(-1, &PlayTextTypingSound);
     SetHiliteColor(ClientUI::EditHiliteColor());
+
+    HotkeyManager* hkm = HotkeyManager::GetManager();
+    auto fx = boost::bind(&CUIEdit::AutoComplete, this);
+    hkm->Connect(fx, "ui.autocomplete", FocusWindowCondition(this));
+    hkm->RebuildShortcuts();
 }
 
 void CUIEdit::RClick(const GG::Pt& pt, GG::Flags<GG::ModKey> mod_keys) {
@@ -921,12 +934,20 @@ void CUIEdit::KeyPress(GG::Key key, std::uint32_t key_code_point,
         GG::GUI::GetGUI()->PasteWndText(this, GG::GUI::GetGUI()->ClipboardText());
 
     // todo: italicize, underline selected text with ctrl-i or ctrl-u
+    // ... though maybe better with a hotkey?
 
     } else {
         GG::Edit::KeyPress(key, key_code_point, mod_keys);
     }
 }
 
+void CUIEdit::AcceptPastedText(const std::string& text) {
+    std::string text_copy;
+    std::copy_if(text.begin(), text.end(), std::back_inserter(text_copy),
+                 [this](char c){ return m_disallowed_chars.find(c) == std::string::npos; });
+    GG::Edit::AcceptPastedText(text_copy);
+}
+
 void CUIEdit::GainingFocus() {
     GG::Edit::GainingFocus();
     GainingFocusSignal();
@@ -940,8 +961,11 @@ void CUIEdit::LosingFocus() {
 void CUIEdit::Render() {
     GG::Clr color = Color();
     GG::Clr border_color = Disabled() ? DisabledColor(color) : color;
+    if (GG::GUI::GetGUI()->FocusWnd().get() == this)
+        border_color = GG::LightenClr(border_color);
     GG::Clr int_color_to_use = Disabled() ? DisabledColor(InteriorColor()) : InteriorColor();
 
+
     GG::Pt ul = UpperLeft(), lr = LowerRight();
     //GG::Pt client_ul = ClientUpperLeft(), client_lr = ClientLowerRight();
 
@@ -976,6 +1000,7 @@ void CensoredCUIEdit::RClick(const GG::Pt& pt, GG::Flags<GG::ModKey> mod_keys) {
 
     auto popup = GG::Wnd::Create<CUIPopupMenu>(pt.x, pt.y);
 
+    // omits copy command from base CUIEdit
     popup->AddMenuItem(GG::MenuItem(UserString("HOTKEY_PASTE"),         false, false, hotkey_paste_action));
     popup->AddMenuItem(GG::MenuItem(true)); // separator
     popup->AddMenuItem(GG::MenuItem(UserString("HOTKEY_SELECT_ALL"),    false, false, hotkey_select_all_action));
@@ -983,48 +1008,6 @@ void CensoredCUIEdit::RClick(const GG::Pt& pt, GG::Flags<GG::ModKey> mod_keys) {
     popup->Run();
 }
 
-void CensoredCUIEdit::KeyPress(GG::Key key, std::uint32_t key_code_point,
-                               GG::Flags<GG::ModKey> mod_keys)
-{
-    if (Disabled()) {
-        CUIEdit::KeyPress(key, key_code_point, mod_keys);
-        return;
-    }
-
-    bool shift_down = mod_keys & (GG::MOD_KEY_LSHIFT | GG::MOD_KEY_RSHIFT);
-    //bool ctrl_down = mod_keys & (GG::MOD_KEY_CTRL | GG::MOD_KEY_RCTRL);
-    //bool numlock_on = mod_keys & GG::MOD_KEY_NUM;
-
-    if (key == GG::GGK_DELETE && shift_down) {
-        GG::GUI::GetGUI()->CutWndText(this);    // should just copy the placeholder character
-
-    } else if (key == GG::GGK_INSERT && shift_down) {
-        GG::GUI::GetGUI()->PasteWndText(this, GG::GUI::GetGUI()->ClipboardText());
-
-    } else if (key == GG::GGK_BACKSPACE) {
-        if (MultiSelected()) {
-            ClearSelected();
-
-        } else if (0 < m_cursor_pos.first) {
-            // delete character before cursor
-            m_cursor_pos.second = m_cursor_pos.first--;
-            ClearSelected();
-        }
-
-    } else if (key == GG::GGK_DELETE) {
-        if (MultiSelected()) {
-            ClearSelected();
-
-        } else {
-            m_cursor_pos.second = m_cursor_pos.first + 1;
-            ClearSelected();
-        }
-
-    } else {
-        CUIEdit::KeyPress(key, key_code_point, mod_keys);
-    }
-}
-
 void CensoredCUIEdit::SetText(const std::string& str) {
     m_raw_text = str;
 
@@ -1096,7 +1079,7 @@ void CensoredCUIEdit::ClearSelected() {
     auto it = m_raw_text.begin() + Value(low);
     auto end_it = m_raw_text.begin() + Value(high);
 
-    if (it == end_it)
+    if (it == m_raw_text.end() || it == end_it)
         return;
 
     m_raw_text.erase(it, end_it);
@@ -1123,6 +1106,8 @@ void CUIMultiEdit::CompleteConstruction() {
 void CUIMultiEdit::Render() {
     GG::Clr color = Color();
     GG::Clr border_color =      Disabled()  ?   DisabledColor(color)            :   color;
+    if (GG::GUI::GetGUI()->FocusWnd().get() == this)
+        border_color = GG::LightenClr(border_color);
     GG::Clr int_color_to_use =  Disabled()  ?   DisabledColor(InteriorColor())  :   InteriorColor();
 
     GG::Pt ul = UpperLeft(), lr = LowerRight();
@@ -1301,7 +1286,7 @@ const GG::Y CUISimpleDropDownListRow::DEFAULT_ROW_HEIGHT(22);
 
 CUISimpleDropDownListRow::CUISimpleDropDownListRow(const std::string& row_text,
                                                    GG::Y row_height/* = DEFAULT_ROW_HEIGHT*/) :
-    GG::ListBox::Row(GG::X1, row_height, ""),
+    GG::ListBox::Row(GG::X1, row_height),
     m_row_label(GG::Wnd::Create<CUILabel>(row_text, GG::FORMAT_LEFT | GG::FORMAT_NOWRAP))
 {}
 
@@ -1320,13 +1305,7 @@ namespace {
 
 StatisticIcon::StatisticIcon(const std::shared_ptr<GG::Texture> texture,
                              GG::X w /*= GG::X1*/, GG::Y h /*= GG::Y1*/) :
-    GG::Control(GG::X0, GG::Y0, w, h, GG::INTERACTIVE),
-    m_num_values(0),
-    m_values(),
-    m_digits(),
-    m_show_signs(),
-    m_icon(nullptr),
-    m_text(nullptr)
+    GG::Control(GG::X0, GG::Y0, w, h, GG::INTERACTIVE)
 {
     m_icon = GG::Wnd::Create<GG::StaticGraphic>(texture, GG::GRAPHIC_FITGRAPHIC);
 }
@@ -1335,38 +1314,11 @@ StatisticIcon::StatisticIcon(const std::shared_ptr<GG::Texture> texture,
                              double value, int digits, bool showsign,
                              GG::X w /*= GG::X1*/, GG::Y h /*= GG::Y1*/) :
     GG::Control(GG::X0, GG::Y0, w, h, GG::INTERACTIVE),
-    m_num_values(1),
-    m_values(std::vector<double>(1, value)),
-    m_digits(std::vector<int>(1, digits)),
-    m_show_signs(std::vector<bool>(1, showsign)),
-    m_icon(nullptr),
-    m_text(nullptr)
+    m_values(1, std::tuple<double, int, bool>{value, digits, showsign})
 {
     m_icon = GG::Wnd::Create<GG::StaticGraphic>(texture, GG::GRAPHIC_FITGRAPHIC);
 }
 
-StatisticIcon::StatisticIcon(const std::shared_ptr<GG::Texture> texture,
-                             double value0, double value1, int digits0, int digits1,
-                             bool showsign0, bool showsign1,
-                             GG::X w /*= GG::X1*/, GG::Y h /*= GG::Y1*/) :
-    GG::Control(GG::X0, GG::Y0, w, h, GG::INTERACTIVE),
-    m_num_values(2),
-    m_values(std::vector<double>(2, 0.0)),
-    m_digits(std::vector<int>(2, 2)),
-    m_show_signs(std::vector<bool>(2, false)),
-    m_icon(nullptr),
-    m_text(nullptr)
-{
-    m_icon = GG::Wnd::Create<GG::StaticGraphic>(texture, GG::GRAPHIC_FITGRAPHIC);
-
-    m_values[0] = value0;
-    m_values[1] = value1;
-    m_digits[0] = digits0;
-    m_digits[1] = digits1;
-    m_show_signs[0] = showsign0;
-    m_show_signs[1] = showsign1;
-}
-
 void StatisticIcon::CompleteConstruction() {
     GG::Control::CompleteConstruction();
 
@@ -1384,26 +1336,23 @@ void StatisticIcon::PreRender() {
     DoLayout();
 }
 
-double StatisticIcon::GetValue(int index) const {
-    if (index < 0) throw std::invalid_argument("negative index passed to StatisticIcon::Value");
+double StatisticIcon::GetValue(size_t index) const {
     if (index > 1) throw std::invalid_argument("index greater than 1 passed to StatisticIcon::Value.  Only 1 or 2 values, with indices 0 or 1, supported.");
-    if (index >= m_num_values) throw std::invalid_argument("index greater than largest index available passed to StatisticIcon::Value");
-    return m_values[index];
+    if (index >= m_values.size()) throw std::invalid_argument("index greater than largest index available passed to StatisticIcon::Value");
+    return std::get<0>(m_values[index]);
 }
 
-void StatisticIcon::SetValue(double value, int index) {
-    if (index < 0) throw std::invalid_argument("negative index passed to StatisticIcon::SetValue");
+void StatisticIcon::SetValue(double value, size_t index) {
     if (index > 1) throw std::invalid_argument("index greater than 1 passed to StatisticIcon::SetValue.  Only 1 or 2 values, with indices 0 or 1, supported.");
-    if (index + 1 > m_num_values) {
-        m_num_values = index + 1;
-        m_values.resize(m_num_values, 0.0);
-        m_show_signs.resize(m_num_values, m_show_signs[0]);
-        m_digits.resize(m_num_values, m_digits[0]);
+    if (index + 1 > m_values.size()) {
+        auto entry = std::tuple<double, int, bool>(m_values[0]);
+        std::get<0>(entry) = value;
+        m_values.resize(index + 1, entry);
         RequirePreRender();
     }
-    if (value != m_values[index])
+    if (value != std::get<0>(m_values[index]))
         RequirePreRender();
-    m_values[index] = value;
+    std::get<0>(m_values[index]) = value;
 }
 
 void StatisticIcon::SizeMove(const GG::Pt& ul, const GG::Pt& lr) {
@@ -1422,39 +1371,68 @@ void StatisticIcon::RButtonDown(const GG::Pt& pt, GG::Flags<GG::ModKey> mod_keys
 { ForwardEventToParent(); }
 
 void StatisticIcon::LClick(const GG::Pt& pt, GG::Flags<GG::ModKey> mod_keys) {
-    if (!Disabled())
-        LeftClickedSignal();
+    if (Disabled())
+        return;
+    LeftClickedSignal(pt);
 }
 
 void StatisticIcon::RClick(const GG::Pt& pt, GG::Flags<GG::ModKey> mod_keys) {
-    if (!Disabled())
-        RightClickedSignal();
+    if (Disabled())
+        return;
+    RightClickedSignal(pt);
 }
 
 void StatisticIcon::MouseWheel(const GG::Pt& pt, int move, GG::Flags<GG::ModKey> mod_keys)
 { ForwardEventToParent(); }
 
+void StatisticIcon::AcceptDrops(const GG::Pt& pt, std::vector<std::shared_ptr<GG::Wnd>> wnds, GG::Flags<GG::ModKey> mod_keys)
+{ ForwardEventToParent(); }
+
+void StatisticIcon::DragDropEnter(const GG::Pt& pt, std::map<const GG::Wnd*, bool>& drop_wnds_acceptable,
+                                  GG::Flags<GG::ModKey> mod_keys)
+{ ForwardEventToParent(); }
+
+void StatisticIcon::DragDropHere(const GG::Pt& pt, std::map<const GG::Wnd*, bool>& drop_wnds_acceptable,
+                                 GG::Flags<GG::ModKey> mod_keys)
+{ ForwardEventToParent(); }
+
+void StatisticIcon::CheckDrops(const GG::Pt& pt, std::map<const GG::Wnd*, bool>& drop_wnds_acceptable, GG::Flags<GG::ModKey> mod_keys)
+{ ForwardEventToParent(); }
+
+void StatisticIcon::DragDropLeave()
+{ ForwardEventToParent(); }
+
 void StatisticIcon::DoLayout() {
     // arrange child controls horizontally if icon is wider than it is high, or vertically otherwise
     int icon_dim = std::min(Value(Height()), Value(Width()));
     m_icon->SizeMove(GG::Pt(GG::X0, GG::Y0),
                      GG::Pt(GG::X(icon_dim), GG::Y(icon_dim)));
 
-    if (m_num_values <= 0)
+    if (m_values.size() <= 0)
         return;
 
     // Precompute text elements
     GG::Font::TextAndElementsAssembler text_elements(*ClientUI::GetFont());
-    text_elements.AddOpenTag(ValueColor(0))
-        .AddText(DoubleToString(m_values[0], m_digits[0], m_show_signs[0]))
+    text_elements.AddOpenTag(ClientUI::TextColor())
+        .AddText(DoubleToString(std::get<0>(m_values[0]), std::get<1>(m_values[0]), std::get<2>(m_values[0])))
         .AddCloseTag("rgba");
-    if (m_num_values > 1)
+    if (m_values.size() > 1) {
+        GG::Clr clr = ClientUI::TextColor();
+
+        int effectiveSign = EffectiveSign(std::get<0>(m_values.at(1)));
+
+        if (effectiveSign == -1)
+            clr = ClientUI::StatDecrColor();
+        if (effectiveSign == 1)
+            clr = ClientUI::StatIncrColor();
+
         text_elements
             .AddText(" (")
-            .AddOpenTag(ValueColor(1))
-            .AddText(DoubleToString(m_values[1], m_digits[1], m_show_signs[1]) )
+            .AddOpenTag(clr)
+            .AddText(DoubleToString(std::get<0>(m_values[1]), std::get<1>(m_values[1]), std::get<2>(m_values[1])))
             .AddCloseTag("rgba")
             .AddText(")");
+    }
 
     // Calculate location and format
     GG::Flags<GG::TextFormat> format;
@@ -1482,25 +1460,11 @@ void StatisticIcon::DoLayout() {
     }
 }
 
-GG::Clr StatisticIcon::ValueColor(int index) const {
-    if (m_values.empty() || index >= m_num_values || index < 0)
-        return ClientUI::TextColor();
-
-    int effectiveSign = EffectiveSign(m_values.at(index));
-
-    if (index == 0) return ClientUI::TextColor();
-
-    if (effectiveSign == -1) return ClientUI::StatDecrColor();
-    if (effectiveSign == 1) return ClientUI::StatIncrColor();
-
-    return ClientUI::TextColor();
-}
-
 GG::Pt StatisticIcon::MinUsableSize() const {
     if (!m_icon)
         return GG::Pt(GG::X1, GG::Y1);
 
-    if (m_num_values <= 0 || !m_text)
+    if (m_values.empty() || !m_text)
         return m_icon->Size();
 
     if (Width() >= Value(Height()))
@@ -1541,8 +1505,9 @@ namespace {
     // row type used in the SpeciesSelector
     struct SpeciesRow : public GG::ListBox::Row {
         SpeciesRow(const Species* species, GG::X w, GG::Y h) :
-            GG::ListBox::Row(w, h, "", GG::ALIGN_VCENTER, 0)
+            GG::ListBox::Row(w, h)
         {
+            SetMargin(0);
             if (!species)
                 return;
             const std::string& species_name = species->Name();
@@ -1553,8 +1518,9 @@ namespace {
 
         SpeciesRow(const std::string& species_name, const std::string& localized_name, const std::string& species_desc,
                    GG::X w, GG::Y h, std::shared_ptr<GG::Texture> species_icon) :
-            GG::ListBox::Row(w, h, "", GG::ALIGN_VCENTER, 0)
+            GG::ListBox::Row(w, h)
         {
+            SetMargin(0);
             GG::Wnd::SetName(species_name);
             Init(species_name, localized_name, species_desc, w, h, species_icon);
         };
@@ -1663,7 +1629,7 @@ namespace {
         };
 
         ColorRow(const GG::Clr& color, GG::Y h) :
-            GG::ListBox::Row(GG::X(Value(h)), h, ""),
+            GG::ListBox::Row(GG::X(Value(h)), h),
             m_color_square(GG::Wnd::Create<ColorSquare>(color, h))
         {}
 
@@ -2187,12 +2153,12 @@ void MultiTurnProgressBar::Render() {
         segment_verts.reserve(2 * m_num_segments);
         segment_colors.reserve(2 * m_num_segments);
 
-        GG::Clr current_colour(GG::DarkColor(m_clr_bar));
+        GG::Clr current_colour(GG::DarkenClr(m_clr_bar));
 
         for (int n = 1; n < m_num_segments; ++n) {
             GG::X separator_x(ul.x + Width() * n / m_num_segments);
             if (separator_x > comp_rect.lr.x)
-                current_colour = GG::LightColor(m_clr_bg);
+                current_colour = GG::LightenClr(m_clr_bg);
             segment_verts.store(separator_x, ul.y);
             segment_verts.store(separator_x, lr.y);
             segment_colors.store(current_colour);
@@ -2220,7 +2186,7 @@ void MultiTurnProgressBar::Render() {
         pred_verts.activate();
         glColor(m_clr_outline);
         glDrawArrays(GL_QUAD_STRIP, 0, 10);
-        glColor(GG::LightColor(m_clr_bar));
+        glColor(GG::LightenClr(m_clr_bar));
         glDrawArrays(GL_QUADS, 10, 4);
     }
 
