@@ -17,8 +17,6 @@
 #include <GG/dialogs/FileDlg.h>
 #include <GG/GLClientAndServerBuffer.h>
 
-#include <boost/function.hpp>
-
 #include "LinkText.h"
 
 /** \file
@@ -82,14 +80,14 @@ protected:
 class SettableInWindowCUIButton : public CUIButton {
 public:
     /** \name Structors */ //@{
-    SettableInWindowCUIButton(const GG::SubTexture& unpressed, const GG::SubTexture& pressed, const GG::SubTexture& rollover, boost::function<bool(const SettableInWindowCUIButton*, const GG::Pt&)> in_window_function);
+    SettableInWindowCUIButton(const GG::SubTexture& unpressed, const GG::SubTexture& pressed, const GG::SubTexture& rollover, std::function<bool (const SettableInWindowCUIButton*, const GG::Pt&)> in_window_function);
     //@}
     /** \name Accessors */ //@{
     bool InWindow(const GG::Pt& pt) const override;
     //@}
 
 private:
-    boost::function<bool(const SettableInWindowCUIButton*, const GG::Pt&)>    m_in_window_func;
+    std::function<bool (const SettableInWindowCUIButton*, const GG::Pt&)>    m_in_window_func;
 };
 
 /** a FreeOrion triangular arrow button */
@@ -311,17 +309,26 @@ public:
     explicit CUIEdit(const std::string& str);
     //@}
 
+    void CompleteConstruction() override;
+
     /** \name Mutators */ //@{
     void RClick(const GG::Pt& pt, GG::Flags<GG::ModKey> mod_keys) override;
     void KeyPress(GG::Key key, std::uint32_t key_code_point,
                   GG::Flags<GG::ModKey> mod_keys) override;
+    void AcceptPastedText(const std::string& text) override;
     void GainingFocus() override;
     void LosingFocus() override;
     void Render() override;
+    virtual bool AutoComplete() { return false; };
+    void DisallowChars(const std::string& chars)
+    { m_disallowed_chars = chars; }
     //@}
 
     mutable boost::signals2::signal<void ()> GainingFocusSignal;
     mutable boost::signals2::signal<void ()> LosingFocusSignal;
+
+private:
+    std::string m_disallowed_chars;
 };
 
 /** a FreeOrion Edit control that replaces its displayed characters with a
@@ -338,8 +345,6 @@ public:
 
     /** \name Mutators */ //@{
     void RClick(const GG::Pt& pt, GG::Flags<GG::ModKey> mod_keys) override;
-    void KeyPress(GG::Key key, std::uint32_t key_code_point,
-                  GG::Flags<GG::ModKey> mod_keys) override;
     void SetText(const std::string& str) override;
     void AcceptPastedText(const std::string& text) override;
     //@}
@@ -437,18 +442,13 @@ public:
     StatisticIcon(const std::shared_ptr<GG::Texture> texture,
                   double value, int digits, bool showsign,
                   GG::X w = GG::X1, GG::Y h = GG::Y1); ///< initializes with one value
-
-    StatisticIcon(const std::shared_ptr<GG::Texture> texture,
-                  double value0, double value1, int digits0, int digits1,
-                  bool showsign0, bool showsign1,
-                  GG::X w = GG::X1, GG::Y h = GG::Y1); ///< initializes with two values
     //@}
 
     void CompleteConstruction() override;
 
     /** \name Accessors */ //@{
-    double          GetValue(int index = 0) const;
-    GG::Pt          MinUsableSize() const override;
+    double GetValue(size_t index = 0) const;
+    GG::Pt MinUsableSize() const override;
     //@}
 
     /** \name Mutators */ //@{
@@ -469,24 +469,32 @@ public:
 
     void MouseWheel(const GG::Pt& pt, int move, GG::Flags<GG::ModKey> mod_keys) override;
 
-    void            SetValue(double value, int index = 0);  ///< sets displayed \a value with \a index
+    void AcceptDrops(const GG::Pt& pt, std::vector<std::shared_ptr<GG::Wnd>> wnds, GG::Flags<GG::ModKey> mod_keys) override;
+
+    void DragDropEnter(const GG::Pt& pt, std::map<const GG::Wnd*, bool>& drop_wnds_acceptable,
+                       GG::Flags<GG::ModKey> mod_keys) override;
+
+    void DragDropHere(const GG::Pt& pt, std::map<const GG::Wnd*, bool>& drop_wnds_acceptable,
+                      GG::Flags<GG::ModKey> mod_keys) override;
+
+    void CheckDrops(const GG::Pt& pt, std::map<const GG::Wnd*, bool>& drop_wnds_acceptable,
+                    GG::Flags<GG::ModKey> mod_keys) override;
+
+    void DragDropLeave() override;
+
+    void SetValue(double value, size_t index = 0);  ///< sets displayed \a value with \a index
     //@}
 
-    mutable boost::signals2::signal<void ()>    LeftClickedSignal;
-    mutable boost::signals2::signal<void ()>    RightClickedSignal;
+    mutable boost::signals2::signal<void (const GG::Pt&)> LeftClickedSignal;
+    mutable boost::signals2::signal<void (const GG::Pt&)> RightClickedSignal;
 
 private:
-    void            DoLayout();
-    GG::Clr         ValueColor(int index) const;        ///< returns colour in which to draw value
+    void    DoLayout();
 
-    int                 m_num_values;
-
-    std::vector<double> m_values;
-    std::vector<int>    m_digits;
-    std::vector<bool>   m_show_signs;
-
-    std::shared_ptr<GG::StaticGraphic>  m_icon;
-    std::shared_ptr<GG::Label>          m_text;
+    /// The value, precision and sign of the statistic value
+    std::vector<std::tuple<double, int, bool>> m_values;
+    std::shared_ptr<GG::StaticGraphic>         m_icon;
+    std::shared_ptr<GG::Label>                 m_text;
 };
 
 class CUIToolBar : public GG::Control {
