@@ -15,7 +15,7 @@ namespace {
                                        double& x1_, double& y1_, double& x2_, double& y2_, double& x3_, double& y3_)
     {
         switch (orientation) {
-        case SHAPE_UP:
+        case ShapeOrientation::UP:
             x1_ = Value(ul.x);
             y1_ = Value(lr.y);
             x2_ = Value(lr.x);
@@ -23,7 +23,7 @@ namespace {
             x3_ = Value((ul.x + lr.x) / 2.0);
             y3_ = Value(ul.y);
             break;
-        case SHAPE_DOWN:
+        case ShapeOrientation::DOWN:
             x1_ = Value(lr.x);
             y1_ = Value(ul.y);
             x2_ = Value(ul.x);
@@ -31,7 +31,7 @@ namespace {
             x3_ = Value((ul.x + lr.x) / 2.0);
             y3_ = Value(lr.y);
             break;
-        case SHAPE_LEFT:
+        case ShapeOrientation::LEFT:
             x1_ = Value(lr.x);
             y1_ = Value(lr.y);
             x2_ = Value(lr.x);
@@ -41,7 +41,7 @@ namespace {
             break;
         default:
             ErrorLogger() << "FindIsoscelesTriangleVertices passed invalid orientation";
-        case SHAPE_RIGHT:
+        case ShapeOrientation::RIGHT:
             x1_ = Value(ul.x);
             y1_ = Value(ul.y);
             x2_ = Value(ul.x);
@@ -159,9 +159,9 @@ void AdjustBrightness(GG::Clr& color, int amount, bool jointly_capped)
         int maxVal = std::max(std::max(color.r, color.g), color.b);
         amount = std::min(amount, 255-maxVal);
     }
-    color.r = std::max(0, std::min(color.r + amount, 255));
-    color.g = std::max(0, std::min(color.g + amount, 255));
-    color.b = std::max(0, std::min(color.b + amount, 255));
+    color.r = static_cast<unsigned char>(std::max(0, std::min(color.r + amount, 255)));
+    color.g = static_cast<unsigned char>(std::max(0, std::min(color.g + amount, 255)));
+    color.b = static_cast<unsigned char>(std::max(0, std::min(color.b + amount, 255)));
 }
 
 void AdjustBrightness(GG::Clr& color, double amount, bool jointly_capped)
@@ -170,15 +170,15 @@ void AdjustBrightness(GG::Clr& color, double amount, bool jointly_capped)
         int maxVal = std::max(std::max(color.r, color.g), color.b);
         amount = std::min(amount, 255.0/maxVal);
     }
-    color.r = std::max(0, std::min(static_cast<int>(color.r * amount), 255));
-    color.g = std::max(0, std::min(static_cast<int>(color.g * amount), 255));
-    color.b = std::max(0, std::min(static_cast<int>(color.b * amount), 255));
+    color.r = static_cast<unsigned char>(std::max(0, std::min(static_cast<int>(color.r * amount), 255)));
+    color.g = static_cast<unsigned char>(std::max(0, std::min(static_cast<int>(color.g * amount), 255)));
+    color.b = static_cast<unsigned char>(std::max(0, std::min(static_cast<int>(color.b * amount), 255)));
 }
 
 GG::Clr OpaqueColor(const GG::Clr& color)
 {
     GG::Clr retval = color;
-    retval.a = 255;
+    retval.a = static_cast<unsigned char>(255);
     return retval;
 }
 
@@ -335,7 +335,7 @@ bool InIsoscelesTriangle(const GG::Pt& pt, const GG::Pt& ul, const GG::Pt& lr,
 void CircleArc(const GG::Pt& ul, const GG::Pt& lr, double theta1, double theta2,
                bool filled_shape)
 {
-    //std::cout << "CircleArc ul: " << ul << "  lr: " << lr << "  theta1: " << theta1 << "  theta2: " << theta2 << "  filled: " << filled_shape << std::flush << std::endl;
+    //std::cout << "CircleArc ul: " << ul << "  lr: " << lr << "  theta1: " << theta1 << "  theta2: " << theta2 << "  filled: " << filled_shape << std::endl;
     GG::GL2DVertexBuffer vert_buf;
     vert_buf.reserve(50);   // max number that BufferStoreCircleArcVertices might add
 
