@@ -15,6 +15,7 @@ public:
                      const GG::Clr& color,
                      GG::Flags< GG::WndFlag > flags);
 
+    void CompleteConstruction() override;
     GG::Pt SetMaxWidth(GG::X width) override;
 
     void Render() override
@@ -26,12 +27,12 @@ public:
     public:
         //! Creates a control from the tag (with unparsed parameters) and the content between the tags.
         //! You own the returned control.
-        GG::BlockControl* CreateFromTag(const std::string& tag,
-                                        const GG::RichText::TAG_PARAMS& params,
-                                        const std::string& content,
-                                        const std::shared_ptr<GG::Font>& font,
-                                        const GG::Clr& color,
-                                        GG::Flags<GG::TextFormat> format) override;
+        std::shared_ptr<GG::BlockControl> CreateFromTag(const std::string& tag,
+                                                        const GG::RichText::TAG_PARAMS& params,
+                                                        const std::string& content,
+                                                        const std::shared_ptr<GG::Font>& font,
+                                                        const GG::Clr& color,
+                                                        GG::Flags<GG::TextFormat> format) override;
 
         ///< link clicked signals: first string is the link type, second string is the specific item clicked
         mutable boost::signals2::signal<void (const std::string&, const std::string&)> LinkClickedSignal;
@@ -40,7 +41,7 @@ public:
     };
 
 private:
-    CUILinkTextMultiEdit* m_link_text;
+    std::shared_ptr<CUILinkTextMultiEdit> m_link_text;
 };
 
 #endif // CUILINKTEXTBLOCK_H
