@@ -5,6 +5,9 @@
 
 #include <GG/Wnd.h>
 
+#include <boost/signals2/signal.hpp>
+
+
 class BarSizer;
 class SideBar;
 class OptionsBar;
@@ -15,6 +18,7 @@ public:
     boost::signals2::signal<void()> MinSizeChangedSignal;
 
     GraphicalSummaryWnd();
+    ~GraphicalSummaryWnd();
 
     /// Get the minimum size of this window required to show all of its
     /// children
@@ -29,19 +33,14 @@ public:
     void DoLayout();
 
 private:
-    std::vector<SideBar*>        m_side_boxes;
-    std::map<int, CombatSummary> m_summaries;
-
-    std::unique_ptr<BarSizer> m_sizer;
-
-    OptionsBar*                  m_options_bar; // Is a child window->GG handles memory
+    std::vector<std::shared_ptr<SideBar>>   m_side_boxes;
+    std::map<int, CombatSummary>            m_summaries;
+    std::unique_ptr<BarSizer>               m_sizer;
+    std::shared_ptr<OptionsBar>             m_options_bar; // Is a child window->GG handles memory
 
     void HandleButtonChanged();
-
     void MakeSummaries(int log_id);
-
     void DeleteSideBars();
-
     void GenerateGraph();
 };
 
