@@ -128,64 +128,62 @@ public:
     void SizeMove(const GG::Pt& ul, const GG::Pt& lr) override;
 
     /** Deselect all fleets. */
-    void                    DeselectAllFleets();
-    void                    SelectFleet(int fleet_id);                     ///< deselects any selected fleets, and selects the indicated fleet, bringing it into the fleet detail window
-    void                    SelectFleets(const std::set<int>& fleet_ids);  ///< deselects any selected fleets, and selects the fleets with the indicated ids
-    void                    SelectShips(const std::set<int>& ship_ids);    ///< deselected any selected ships, and selects the ships with the indicated ids if they are in the selected fleet.
+    void DeselectAllFleets();
+    void SelectFleet(int fleet_id);                     ///< deselects any selected fleets, and selects the indicated fleet, bringing it into the fleet detail window
+    void SelectFleets(const std::set<int>& fleet_ids);  ///< deselects any selected fleets, and selects the fleets with the indicated ids
+    void SelectShips(const std::set<int>& ship_ids);    ///< deselected any selected ships, and selects the ships with the indicated ids if they are in the selected fleet.
 
     /** Enables, or disables if \a enable is false, issuing orders via this FleetWnd. */
     void                    EnableOrderIssuing(bool enable = true);
     //@}
 
-    mutable boost::signals2::signal<void ()>          SelectedFleetsChangedSignal;
-    mutable boost::signals2::signal<void ()>          SelectedShipsChangedSignal;
+    mutable boost::signals2::signal<void ()>    SelectedFleetsChangedSignal;
+    mutable boost::signals2::signal<void ()>    SelectedShipsChangedSignal;
     mutable boost::signals2::signal<void (std::shared_ptr<FleetWnd>)> ClickedSignal;
-    mutable boost::signals2::signal<void (int)>       FleetRightClickedSignal;
-    mutable boost::signals2::signal<void (int)>       ShipRightClickedSignal;
+    mutable boost::signals2::signal<void (int)> FleetRightClickedSignal;
+    mutable boost::signals2::signal<void (int)> ShipRightClickedSignal;
 
 protected:
     //! \name Mutators //@{
     void CloseClicked() override;
-
     void LClick(const GG::Pt& pt, GG::Flags<GG::ModKey> mod_keys) override;
-
-    void            DoLayout();
+    void DoLayout();
     //@}
 
 private:
-    void            RequireRefresh();
-    void            Refresh();                          ///< regenerates contents
-    void            RefreshStateChangedSignals();
+    void RequireRefresh();
+    void Refresh();                          ///< regenerates contents
+    void RefreshStateChangedSignals();
 
-    void            AddFleet(int fleet_id);     ///< adds a new fleet row to this FleetWnd's ListBox of FleetRows and updates internal fleets bookkeeping
+    void AddFleet(int fleet_id);     ///< adds a new fleet row to this FleetWnd's ListBox of FleetRows and updates internal fleets bookkeeping
 
-    void            FleetSelectionChanged(const GG::ListBox::SelectionSet& rows);
-    void            FleetRightClicked(GG::ListBox::iterator it, const GG::Pt& pt, const GG::Flags<GG::ModKey>& modkeys);
-    void            FleetLeftClicked(GG::ListBox::iterator it, const GG::Pt& pt, const GG::Flags<GG::ModKey>& modkeys);
-    void            FleetDoubleClicked(GG::ListBox::iterator it, const GG::Pt& pt, const GG::Flags<GG::ModKey>& modkeys);
+    void FleetSelectionChanged(const GG::ListBox::SelectionSet& rows);
+    void FleetRightClicked(GG::ListBox::iterator it, const GG::Pt& pt, const GG::Flags<GG::ModKey>& modkeys);
+    void FleetLeftClicked(GG::ListBox::iterator it, const GG::Pt& pt, const GG::Flags<GG::ModKey>& modkeys);
+    void FleetDoubleClicked(GG::ListBox::iterator it, const GG::Pt& pt, const GG::Flags<GG::ModKey>& modkeys);
 
-    int             FleetInRow(GG::ListBox::iterator it) const;
-    std::string     TitleText() const;
-    void            CreateNewFleetFromDrops(const std::vector<int>& ship_ids);
+    int         FleetInRow(GG::ListBox::iterator it) const;
+    std::string TitleText() const;
+    void        CreateNewFleetFromDrops(const std::vector<int>& ship_ids);
 
-    void            ShipSelectionChanged(const GG::ListBox::SelectionSet& rows);
+    void ShipSelectionChanged(const GG::ListBox::SelectionSet& rows);
+    void UniverseObjectDeleted(std::shared_ptr<const UniverseObject> obj);
 
-    void            UniverseObjectDeleted(std::shared_ptr<const UniverseObject> obj);
+    void SetStatIconValues();          ///< sets values for multi-fleet aggregate stat icons at top of FleetWnd
 
-    void            SetStatIconValues();          ///< sets values for multi-fleet aggregate stat icons at top of FleetWnd
     mutable boost::signals2::signal<void (FleetWnd*)> ClosingSignal;
 
     boost::signals2::connection              m_system_connection;
     std::vector<boost::signals2::connection> m_fleet_connections;
 
-    std::set<int>       m_fleet_ids;        ///< IDs of fleets shown in this wnd (always.  set when creating wnd, either by being passed in directly, or found by checking indicated system for indicated empire's fleets.  If set directly, never updates.  If set by checking system, updates when the system has a fleet added or removed.
-    int                 m_empire_id;        ///< ID of empire whose fleets are shown in this wnd.  May be ALL_EMPIRES if this FleetWnd wasn't set to shown a particular empire's fleets.
-    int                 m_system_id;        ///< ID of system whose fleets are shown in this wnd.  May be INVALID_OBJECT_ID if this FleetWnd wasn't set to show a system's fleets.
+    std::set<int>   m_fleet_ids;                    ///< IDs of fleets shown in this wnd (always.  set when creating wnd, either by being passed in directly, or found by checking indicated system for indicated empire's fleets.  If set directly, never updates.  If set by checking system, updates when the system has a fleet added or removed.
+    int             m_empire_id = ALL_EMPIRES;      ///< ID of empire whose fleets are shown in this wnd.  May be ALL_EMPIRES if this FleetWnd wasn't set to shown a particular empire's fleets.
+    int             m_system_id =INVALID_OBJECT_ID; ///< ID of system whose fleets are shown in this wnd.  May be INVALID_OBJECT_ID if this FleetWnd wasn't set to show a system's fleets.
 
     /** The size of box up to which moving fleets are still within the same fleet window.*/
-    GG::Rect            m_bounding_box;
-    bool                m_order_issuing_enabled;
-    bool                m_needs_refresh = false;
+    GG::Rect        m_bounding_box;
+    bool            m_order_issuing_enabled = false;
+    bool            m_needs_refresh = false;
 
     std::shared_ptr<FleetsListBox>      m_fleets_lb;
     std::shared_ptr<FleetDataPanel>     m_new_fleet_drop_target;
