@@ -161,7 +161,7 @@ private:
     const GG::Wnd* target;
 };
 
-template<class W>
+template <typename W>
 class FocusWindowIsA {
 public:
     bool operator()() const {
@@ -228,12 +228,10 @@ private:
     typedef std::map<std::string, ConditionalConnectionList> Connections;
 
     /// A set of connected shortcuts.
-    Connections             m_connections;
-    std::map<std::string, GG::GUI::AcceleratorSignalType*>
-                            m_signals;
-    std::set<boost::signals2::connection>
-                            m_internal_connections;
-    static HotkeyManager*   s_singleton;
+    Connections                                             m_connections;
+    std::map<std::string, GG::GUI::AcceleratorSignalType*>  m_signals;
+    std::set<boost::signals2::connection>                   m_internal_connections;
+    static HotkeyManager*                                   s_singleton;
 };
 
 #endif
