@@ -15,7 +15,6 @@
 
 #include <GG/Button.h>
 #include <GG/Clr.h>
-#include <GG/DrawUtil.h>
 #include <GG/dialogs/ThreeButtonDlg.h>
 
 #include <boost/filesystem/operations.hpp>
@@ -48,21 +47,15 @@ void InGameMenu::CompleteConstruction() {
     AttachChild(m_resign_btn);
     AttachChild(m_done_btn);
 
-    m_save_btn->LeftClickedSignal.connect(
-        boost::bind(&InGameMenu::Save, this));
+    m_save_btn->LeftClickedSignal.connect(boost::bind(&InGameMenu::Save, this));
     if (HumanClientApp::GetApp()->SinglePlayerGame()) {
-        m_load_or_concede_btn->LeftClickedSignal.connect(
-            boost::bind(&InGameMenu::Load, this));
+        m_load_or_concede_btn->LeftClickedSignal.connect(boost::bind(&InGameMenu::Load, this));
     } else {
-        m_load_or_concede_btn->LeftClickedSignal.connect(
-            boost::bind(&InGameMenu::Concede, this));
+        m_load_or_concede_btn->LeftClickedSignal.connect(boost::bind(&InGameMenu::Concede, this));
     }
-    m_options_btn->LeftClickedSignal.connect(
-        boost::bind(&InGameMenu::Options, this));
-    m_resign_btn->LeftClickedSignal.connect(
-        boost::bind(&InGameMenu::Resign, this));
-    m_done_btn->LeftClickedSignal.connect(
-        boost::bind(&InGameMenu::Done, this));
+    m_options_btn->LeftClickedSignal.connect(boost::bind(&InGameMenu::Options, this));
+    m_resign_btn->LeftClickedSignal.connect(boost::bind(&InGameMenu::Resign, this));
+    m_done_btn->LeftClickedSignal.connect(boost::bind(&InGameMenu::Done, this));
 
     if (!HumanClientApp::GetApp()->CanSaveNow()) {
         m_save_btn->Disable();
@@ -170,6 +163,9 @@ void InGameMenu::Save() {
         return;
     }
 
+    // send order changes could be made when player decide to save game
+    app->SendPartialOrders();
+
     try {
         // When saving in multiplayer, you cannot see the old saves or
         // browse directories, only give a save file name.
@@ -208,10 +204,10 @@ void InGameMenu::Options() {
 void InGameMenu::Concede() {
     // show confirmation dialog
     std::shared_ptr<GG::Font> font = ClientUI::GetFont();
-    auto prompt = GG::Wnd::Create<GG::ThreeButtonDlg>(
+    auto prompt = GG::GUI::GetGUI()->GetStyleFactory()->NewThreeButtonDlg(
         GG::X(200), GG::Y(75), UserString("GAME_MENU_REALLY_CONCEDE"), font,
         ClientUI::CtrlColor(), ClientUI::CtrlBorderColor(), ClientUI::CtrlColor(), ClientUI::TextColor(),
-        std::size_t(2), UserString("YES"), UserString("CANCEL"), "");
+        2, UserString("YES"), UserString("CANCEL"));
     prompt->Run();
     if (prompt->Result() == 0) {
        // send ELIMINATE_SELF message
@@ -221,6 +217,9 @@ void InGameMenu::Concede() {
 }
 
 void InGameMenu::Resign() {
+    // send order changes could be made when player decides to disconnect
+    HumanClientApp::GetApp()->SendPartialOrders();
+
     HumanClientApp::GetApp()->ResetToIntro(false);
     CloseClicked();
 }
