@@ -10,9 +10,9 @@
 #include "../universe/Fleet.h"
 #include "FleetButton.h"
 
-#include <boost/unordered_map.hpp>
 #include <boost/functional/hash.hpp>
 
+#include <chrono>
 #include <unordered_map>
 #include <unordered_set>
 #include <vector>
@@ -128,6 +128,7 @@ public:
     void MouseWheel(const GG::Pt& pt, int move, GG::Flags<GG::ModKey> mod_keys) override;
     void KeyPress(GG::Key key, std::uint32_t key_code_point, GG::Flags<GG::ModKey> mod_keys) override;
     void KeyRelease(GG::Key key, std::uint32_t key_code_point, GG::Flags<GG::ModKey> mod_keys) override;
+    void TimerFiring(unsigned int ticks, GG::Timer* timer) override;
 
     void DoLayout();
 
@@ -158,8 +159,15 @@ public:
     void ShowCombatLog(int log_id);                              //!< brings up encyclopedia panel and displays info about the combat
     void ShowTech(const std::string& tech_name);                 //!< brings up the research screen and centers the tech tree on \a tech_name
     void ShowBuildingType(const std::string& building_type_name);//!< brings up the production screen and displays info about the buildtype \a type_name
-    void ShowPartType(const std::string& part_type_name);        //!< brings up the production screen and displays info about the buildtype \a type_name
-    void ShowHullType(const std::string& hull_type_name);        //!< brings up the production screen and displays info about the buildtype \a type_name
+
+    //! Brings up the production screen and displays info about
+    //! the ShipPart @a ship_part_name.
+    void ShowShipPart(const std::string& ship_part_name);
+
+    //! Brings up the production screen and displays info about the ShipHull
+    //! @p ship_hull_name
+    void ShowShipHull(const std::string& ship_hull_name);
+
     void ShowShipDesign(int design_id);                          //!< brings up the production screen and displays info about the buildtype \a type_name
     void ShowSpecial(const std::string& special_name);           //!< brings up encyclopedia panel and displays info about the special with name \a special_name
     void ShowSpecies(const std::string& species_name);           //!< brings up encyclopedia panel and displays info about the species with name \a species_name
@@ -200,6 +208,7 @@ public:
     void RegisterPopup(const std::shared_ptr<MapWndPopup>& popup);              //!< registers a MapWndPopup, which can be cleaned up with a call to DeleteAllPopups( )
     void RemovePopup(MapWndPopup* popup);        //!< removes a MapWndPopup from the list cleaned up on a call to DeleteAllPopups( )
     void Sanitize();                             //!< sanitizes the MapWnd after a game
+    void ResetTimeoutClock(int timeout);         //!< start count down \a timeout seconds
     //!@}
 
     void SetFleetExploring(const int fleet_id);
@@ -209,6 +218,8 @@ public:
 
 
 private:
+    void RefreshTurnButtonTooltip();
+
     void RefreshTradeResourceIndicator();
     void RefreshFleetResourceIndicator();
     void RefreshResearchResourceIndicator();
@@ -270,21 +281,6 @@ private:
 
     void RefreshFleetButtonSelectionIndicators();    //!< marks (only) selected fleets' buttons as selected
 
-    /** Connect all \p fleets StateChangedSignal to RefreshFleetButtons. */
-    void AddFleetsStateChangedSignal(const std::vector<std::shared_ptr<Fleet>>& fleets);
-
-    /** Disconnect all \p fleets StateChangedSignal from RefreshFleetButtons. */
-    void RemoveFleetsStateChangedSignal(const std::vector<std::shared_ptr<Fleet>>& fleets);
-
-    /** Handle FleetsInsertedSignal by connecting signals and refreshing fleet
-        buttons. */
-    void FleetsInsertedSignalHandler(const std::vector<std::shared_ptr<Fleet>>& fleets);
-
-    /** Handle FleetsRemovedSignal by disconnecting signals and refreshing fleet
-        buttons. */
-    void FleetsRemovedSignalHandler(const std::vector<std::shared_ptr<Fleet>>& fleets);
-
-
     void DoFleetButtonsLayout();                     //!< does layout of fleet buttons
 
     /** Return fleets ids of all fleet buttons containing or overlapping the
@@ -303,8 +299,6 @@ private:
     void DoSystemIconsLayout();          //!< does layout of system icons
     void DoFieldIconsLayout();           //!< does layout of field icons
 
-    void RefreshFleetSignals();          //!< disconnects and reconnects all fleet change signals
-
     void RefreshSliders();               //!< shows or hides sliders on map
 
     void InitTurnRendering();            //!< sets up rendering of system icons, galaxy gas, starlanes at start of turn
@@ -372,7 +366,7 @@ private:
     void FleetButtonRightClicked(const FleetButton* fleet_btn);
     void FleetRightClicked(int fleet_id);
     void FleetsRightClicked(const std::vector<int>& fleet_ids);
-    
+
     void ShipRightClicked(int fleet_id);
     void ShipsRightClicked(const std::vector<int>& fleet_ids);
 
@@ -412,7 +406,7 @@ private:
     bool ShowGraphs();
 
     void HideSidePanel();
-    void RestoreSidePanel();
+    void RestoreSidePanel(); //!< restores side panel, sends to server changes made in other windows
 
     bool ToggleResearch();
     void ShowResearch();
@@ -456,22 +450,22 @@ private:
     std::set<int>                               m_selected_fleet_ids;
     std::set<int>                               m_selected_ship_ids;
 
-    double                                      m_zoom_steps_in = 1.0;          //!< number of zoom steps in.  each 1.0 step increases display scaling by the same zoom step factor
-    std::shared_ptr<SidePanel>                  m_side_panel = nullptr;         //!< planet view panel on the side of the main map
-    boost::unordered_map<int, std::shared_ptr<SystemIcon>> m_system_icons;      //!< system icons in the main map, indexed by system id
-    std::map<int, std::shared_ptr<FieldIcon>>   m_field_icons;                  //!< field icons in the main map, indexed by field id
-    std::shared_ptr<SitRepPanel>                m_sitrep_panel = nullptr;       //!< sitrep panel
-    std::shared_ptr<ResearchWnd>                m_research_wnd = nullptr;       //!< research screen
-    std::shared_ptr<ProductionWnd>              m_production_wnd = nullptr;     //!< production screen
-    std::shared_ptr<DesignWnd>                  m_design_wnd = nullptr;         //!< design screen
-    std::shared_ptr<EncyclopediaDetailPanel>    m_pedia_panel = nullptr;        //!< encyclpedia panel
-    std::shared_ptr<ObjectListWnd>              m_object_list_wnd = nullptr;    //!< filterable list of objects in universe
-    std::shared_ptr<ModeratorActionsWnd>        m_moderator_wnd = nullptr;      //!< buttons to select moderator actions
-    std::shared_ptr<CombatReportWnd>            m_combat_report_wnd = nullptr;  //!< shows graphical reports of combats
+    double                                      m_zoom_steps_in = 1.0;      //!< number of zoom steps in.  each 1.0 step increases display scaling by the same zoom step factor
+    std::shared_ptr<SidePanel>                  m_side_panel;               //!< planet view panel on the side of the main map
+    std::unordered_map<int, std::shared_ptr<SystemIcon>> m_system_icons;    //!< system icons in the main map, indexed by system id
+    std::map<int, std::shared_ptr<FieldIcon>>   m_field_icons;              //!< field icons in the main map, indexed by field id
+    std::shared_ptr<SitRepPanel>                m_sitrep_panel;             //!< sitrep panel
+    std::shared_ptr<ResearchWnd>                m_research_wnd;             //!< research screen
+    std::shared_ptr<ProductionWnd>              m_production_wnd;           //!< production screen
+    std::shared_ptr<DesignWnd>                  m_design_wnd;               //!< design screen
+    std::shared_ptr<EncyclopediaDetailPanel>    m_pedia_panel;              //!< encyclpedia panel
+    std::shared_ptr<ObjectListWnd>              m_object_list_wnd;          //!< filterable list of objects in universe
+    std::shared_ptr<ModeratorActionsWnd>        m_moderator_wnd;            //!< buttons to select moderator actions
+    std::shared_ptr<CombatReportWnd>            m_combat_report_wnd;        //!< shows graphical reports of combats
 
-    std::vector<std::weak_ptr<GG::Wnd>>         m_wnd_stack;        //!< stack of open windows, to allow closing them with escape in a LIFO order
+    std::vector<std::weak_ptr<GG::Wnd>>         m_wnd_stack;                //!< stack of open windows, to allow closing them with escape in a LIFO order
 
-    std::map<std::pair<int, int>, LaneEndpoints>m_starlane_endpoints;//!< map from starlane start and end system IDs (stored in pair in increasing order) to the universe coordiates at which to draw the starlane ends
+    std::map<std::pair<int, int>, LaneEndpoints>m_starlane_endpoints;       //!< map from starlane start and end system IDs (stored in pair in increasing order) to the universe coordiates at which to draw the starlane ends
 
     /** Icons representing fleets at a system that are not departing, indexed
         by system. */
@@ -504,18 +498,18 @@ private:
                        boost::hash<std::pair<double, double>>>
         m_offroad_fleet_buttons;
 
-    boost::unordered_map<int, std::shared_ptr<FleetButton>>
+    std::unordered_map<int, std::shared_ptr<FleetButton>>
         m_fleet_buttons;                        //!< fleet icons, index by fleet
 
-    boost::unordered_map<int, boost::signals2::connection>
+    std::unordered_map<int, boost::signals2::connection>
         m_fleet_state_change_signals;
-    boost::unordered_map<int, std::vector<boost::signals2::connection>>
+    std::unordered_map<int, std::vector<boost::signals2::connection>>
         m_system_fleet_insert_remove_signals;
 
     std::map<int, MovementLineData> m_fleet_lines;                  //!< lines used for moving fleets in the main map
     std::map<int, MovementLineData> m_projected_fleet_lines;        //!< lines that show the projected path of the active fleet in the FleetWnd
 
-    std::pair<int, int>             m_line_between_systems;         //!< set when map should render line connecting 2 systems
+    std::pair<int, int>             m_line_between_systems = {INVALID_OBJECT_ID, INVALID_OBJECT_ID};//!< set when map should render line connecting 2 systems
 
     std::map<std::shared_ptr<GG::Texture>, GG::GL2DVertexBuffer> m_star_core_quad_vertices;
     std::map<std::shared_ptr<GG::Texture>, GG::GL2DVertexBuffer> m_star_halo_quad_vertices;
@@ -556,36 +550,42 @@ private:
     GG::Pt                          m_drag_offset = {-GG::X1, -GG::Y1}; //!< distance the cursor is from the upper-left corner of the window during a drag ((-1, -1) if no drag is occurring)
     bool                            m_dragged = false;          //!< tracks whether or not a drag occurs during a left button down sequence of events
 
-    std::shared_ptr<GG::Button>     m_btn_turn = nullptr;       //!< button that updates player's turn;
-    std::shared_ptr<GG::Button>     m_btn_auto_turn = nullptr;  //!< button that toggles whether to automatically end turns;
+    std::shared_ptr<GG::Button>     m_btn_turn;                 //!< button that updates player's turn;
+    std::shared_ptr<GG::Button>     m_btn_auto_turn;            //!< button that toggles whether to automatically end turns;
     bool                            m_auto_end_turn = false;    //!< should turns be ended automatically by this client?
+    bool                            m_ready_turn = false;       //!< is turn orders are ready and sent to server?
+    std::shared_ptr<GG::Label>      m_timeout_remain;           //!< label to show remaining time
+    GG::Timer                       m_timeout_clock{1000};      //!< clock to update remaining time
     std::list<std::weak_ptr<MapWndPopup>> m_popups;             //!< list of currently active popup windows
     bool                            m_menu_showing = false;     //!< set during ShowMenu() to prevent reentrency
-    int                             m_current_owned_system;
-    int                             m_current_fleet_id;
+    int                             m_current_owned_system = INVALID_OBJECT_ID;
+    int                             m_current_fleet_id = INVALID_OBJECT_ID;
     bool                            m_in_production_view_mode = false;
 
     bool                            m_sidepanel_open_before_showing_other = false;  //!< was the sidepanel open before switching to production, research or design screens?  If so, it should be restored when leaving them.
 
-    std::shared_ptr<CUIToolBar>     m_toolbar = nullptr;
-    std::shared_ptr<StatisticIcon>  m_trade = nullptr, m_population = nullptr, m_research = nullptr,
-                                    m_industry = nullptr, m_stockpile = nullptr, m_detection = nullptr,
-                                    m_fleet = nullptr;
-    std::shared_ptr<GG::Button>     m_industry_wasted = nullptr, m_research_wasted = nullptr,
-                                    m_btn_moderator = nullptr, m_btn_messages = nullptr, m_btn_empires = nullptr,
-                                    m_btn_siterep = nullptr, m_btn_research = nullptr, m_btn_production = nullptr,
-                                    m_btn_design = nullptr, m_btn_pedia = nullptr, m_btn_graphs = nullptr,
-                                    m_btn_objects = nullptr, m_btn_menu = nullptr;
-    std::shared_ptr<GG::Label>      m_FPS = nullptr;
+    std::shared_ptr<CUIToolBar>     m_toolbar;
+    std::shared_ptr<StatisticIcon>  m_trade, m_population, m_research,
+                                    m_industry, m_stockpile, m_detection,
+                                    m_fleet;
+    std::shared_ptr<GG::Button>     m_industry_wasted, m_research_wasted,
+                                    m_btn_moderator, m_btn_messages, m_btn_empires,
+                                    m_btn_siterep, m_btn_research, m_btn_production,
+                                    m_btn_design, m_btn_pedia, m_btn_graphs,
+                                    m_btn_objects, m_btn_menu;
+    std::shared_ptr<GG::Label>      m_FPS;
 
-    std::shared_ptr<MapScaleLine>       m_scale_line = nullptr;     //!< indicates the on-screen distance that reprensents an in-universe distance
-    std::shared_ptr<GG::Slider<double>> m_zoom_slider = nullptr;    //!< allows user to set zoom level;
+    std::shared_ptr<MapScaleLine>       m_scale_line;   //!< indicates the on-screen distance that reprensents an in-universe distance
+    std::shared_ptr<GG::Slider<double>> m_zoom_slider;  //!< allows user to set zoom level;
 
     std::set<int>                   m_fleets_exploring;
 
     /// indicates that refresh fleet button work should be done before rendering.
     bool                            m_deferred_refresh_fleet_buttons = false;
 
+    std::chrono::time_point<std::chrono::high_resolution_clock>
+                                    m_timeout_time;
+
     friend struct IntroMenu;
     friend struct WaitingForGameStart;
     friend struct PlayingTurn;
