@@ -1,7 +1,5 @@
 #include "MeterBrowseWnd.h"
 
-#include <GG/DrawUtil.h>
-
 #include "../util/i18n.h"
 #include "../util/Logger.h"
 #include "../util/GameRules.h"
@@ -11,6 +9,7 @@
 #include "../universe/PopCenter.h"
 #include "../universe/Ship.h"
 #include "../universe/ShipDesign.h"
+#include "../universe/ShipPart.h"
 #include "../universe/UniverseObject.h"
 #include "../universe/Enums.h"
 #include "../Empire/Empire.h"
@@ -130,7 +129,7 @@ void MeterBrowseWnd::Initialize() {
     const GG::X TOTAL_WIDTH = MeterBrowseLabelWidth() + MeterBrowseValueWidth();
 
     // get objects and meters to verify that they exist
-    auto obj = GetUniverseObject(m_object_id);
+    auto obj = Objects().get(m_object_id);
     if (!obj) {
         ErrorLogger() << "MeterBrowseWnd couldn't get object with id " << m_object_id;
         return;
@@ -238,7 +237,7 @@ namespace {
         int obj_id, const MeterType& meter_type)
     {
         // get object and meter, aborting if not valid
-        auto obj = GetUniverseObject(obj_id);
+        auto obj = Objects().get(obj_id);
         if (!obj) {
             ErrorLogger() << "Couldn't get object with id " << obj_id;
             return boost::none;
@@ -262,7 +261,7 @@ namespace {
 }
 
 void MeterBrowseWnd::UpdateSummary() {
-    auto obj = GetUniverseObject(m_object_id);
+    auto obj = Objects().get(m_object_id);
     if (!obj)
         return;
 
@@ -331,7 +330,7 @@ void MeterBrowseWnd::UpdateEffectLabelsAndValues(GG::Y& top) {
 
     // add label-value pairs for each alteration recorded for this meter
     for (const auto& info : *maybe_info_vec) {
-        auto source = GetUniverseObject(info.source_id);
+        auto source = Objects().get(info.source_id);
 
         std::string text;
         std::string name;
@@ -354,7 +353,7 @@ void MeterBrowseWnd::UpdateEffectLabelsAndValues(GG::Y& top) {
         case ECT_BUILDING: {
             name.clear();
             if (const auto& building = std::dynamic_pointer_cast<const Building>(source))
-                if (const auto& planet = GetPlanet(building->PlanetID()))
+                if (const auto& planet = Objects().get<Planet>(building->PlanetID()))
                     name = planet->Name();
             const std::string& label_template = (info.custom_label.empty()
                 ? UserString("TT_BUILDING")
@@ -446,7 +445,7 @@ void ShipDamageBrowseWnd::Initialize() {
     const GG::X TOTAL_WIDTH = MeterBrowseLabelWidth() + MeterBrowseValueWidth();
 
     // get objects and meters to verify that they exist
-    auto ship = GetShip(m_object_id);
+    auto ship = Objects().get<Ship>(m_object_id);
     if (!ship) {
         ErrorLogger() << "ShipDamageBrowseWnd couldn't get ship with id " << m_object_id;
         return;
@@ -484,7 +483,7 @@ void ShipDamageBrowseWnd::UpdateImpl(std::size_t mode, const Wnd* target) {
 }
 
 void ShipDamageBrowseWnd::UpdateSummary() {
-    auto ship = GetShip(m_object_id);
+    auto ship = Objects().get<Ship>(m_object_id);
     if (!ship)
         return;
 
@@ -509,7 +508,7 @@ void ShipDamageBrowseWnd::UpdateEffectLabelsAndValues(GG::Y& top) {
     m_effect_labels_and_values.clear();
 
     // get object and meter, aborting if not valid
-    auto ship = GetShip(m_object_id);
+    auto ship = Objects().get<Ship>(m_object_id);
     if (!ship) {
         ErrorLogger() << "ShipDamageBrowseWnd::UpdateEffectLabelsAndValues couldn't get ship with id " << m_object_id;
         return;
@@ -524,7 +523,7 @@ void ShipDamageBrowseWnd::UpdateEffectLabelsAndValues(GG::Y& top) {
 
     // for each weapon part, get its damage meter value
     for (const std::string& part_name : design->Parts()) {
-        const PartType* part = GetPartType(part_name);
+        const ShipPart* part = GetShipPart(part_name);
         if (!part)
             continue;
         ShipPartClass part_class = part->Class();
@@ -562,7 +561,7 @@ namespace {
          * @param [in] base_value optional; If greater than 0.0f: the value label is formatted to "value of base_value"
          */
         ShipFightersBrowseRow(const std::string& label, int qty, double value, double base_value = 0.0f) :
-            GG::ListBox::Row(FighterBrowseListWidth(), MeterBrowseRowHeight(), "")
+            GG::ListBox::Row(FighterBrowseListWidth(), MeterBrowseRowHeight())
         {
             const GG::Clr QTY_COLOR = GG::CLR_GRAY;
 
@@ -609,8 +608,6 @@ namespace {
 
 ShipFightersBrowseWnd::ShipFightersBrowseWnd(int object_id, MeterType primary_meter_type, bool show_all_bouts /* = false*/) :
     MeterBrowseWnd(object_id, primary_meter_type),
-    m_bay_list(nullptr),
-    m_hangar_list(nullptr),
     m_show_all_bouts(show_all_bouts)
 {}
 
@@ -624,7 +621,7 @@ void ShipFightersBrowseWnd::Initialize() {
     const GG::Clr BG_COLOR = ClientUI::WndColor();
 
     // get objects and meters to verify that they exist
-    auto ship = GetShip(m_object_id);
+    auto ship = Objects().get<Ship>(m_object_id);
     if (!ship) {
         ErrorLogger() << "Couldn't get ship with id " << m_object_id;
         return;
@@ -679,7 +676,7 @@ void ShipFightersBrowseWnd::UpdateImpl(std::size_t mode, const Wnd* target) {
 }
 
 void ShipFightersBrowseWnd::UpdateSummary() {
-    auto ship = GetShip(m_object_id);
+    auto ship = Objects().get<Ship>(m_object_id);
     if (!ship)
         return;
 
@@ -751,7 +748,7 @@ void ShipFightersBrowseWnd::UpdateEffectLabelsAndValues(GG::Y& top) {
     m_hangar_list->DetachChildren();
 
     // early return if no valid ship, ship design, or no parts in the design
-    auto ship = GetShip(m_object_id);
+    auto ship = Objects().get<Ship>(m_object_id);
     if (!ship) {
         ErrorLogger() << "Couldn't get ship with id " << m_object_id;
         return;
@@ -782,7 +779,7 @@ void ShipFightersBrowseWnd::UpdateEffectLabelsAndValues(GG::Y& top) {
 
     // populate values from hangars and bays
     for (std::string part_name : parts) {
-        const PartType* part = GetPartType(part_name);
+        const ShipPart* part = GetShipPart(part_name);
         if (!part)
             continue;
         ShipPartClass part_class = part->Class();
