@@ -1,7 +1,6 @@
 #include "MultiplayerLobbyWnd.h"
 
 #include <GG/Button.h>
-#include <GG/DrawUtil.h>
 #include <GG/Layout.h>
 #include <GG/StaticGraphic.h>
 
@@ -9,7 +8,7 @@
 #include "../util/Logger.h"
 #include "../util/Serialize.h"
 #include "../network/Message.h"
-#include "../network/ClientNetworking.h"
+#include "../client/ClientNetworking.h"
 #include "../client/human/HumanClientApp.h"
 #include "Hotkeys.h"
 #include "Sound.h"
@@ -49,12 +48,12 @@ namespace {
     // players or the host.
     struct PlayerRow : GG::ListBox::Row {
         PlayerRow() :
-            GG::ListBox::Row(GG::X(90), PlayerRowHeight(), ""),
+            GG::ListBox::Row(GG::X(90), PlayerRowHeight()),
             m_player_data(),
             m_player_id(Networking::INVALID_PLAYER_ID)
         {}
         PlayerRow(const PlayerSetupData& player_data, int player_id) :
-            GG::ListBox::Row(GG::X(90), PlayerRowHeight(), ""),
+            GG::ListBox::Row(GG::X(90), PlayerRowHeight()),
             m_player_data(player_data),
             m_player_id(player_id)
         {}
@@ -85,9 +84,10 @@ namespace {
             {}
 
             TypeRow(GG::X w, GG::Y h, Networking::ClientType type_, bool show_add_drop = false) :
-                GG::DropDownList::Row(w, h, "PlayerTypeSelectorRow"),
+                GG::DropDownList::Row(w, h),
                 type(type_)
             {
+                SetDragDropDataType("PlayerTypeSelectorRow");
                 switch (type) {
                 case Networking::CLIENT_TYPE_AI_PLAYER:
                     if (show_add_drop)
@@ -208,6 +208,10 @@ namespace {
                 }
             }
 
+#if BOOST_VERSION >= 106000
+            using boost::placeholders::_1;
+#endif
+
             SelChangedSignal.connect(
                 boost::bind(&TypeSelector::SelectionChanged, this, _1));
         }
@@ -249,8 +253,13 @@ namespace {
         void CompleteConstruction() override {
             PlayerRow::CompleteConstruction();
 
+#if BOOST_VERSION >= 106000
+            using boost::placeholders::_1;
+#endif
+
             // human / AI / observer indicator / selector
-            auto type_drop = GG::Wnd::Create<TypeSelector>(GG::X(90), PlayerRowHeight(), m_player_data.m_client_type, m_initial_disabled);
+            auto type_drop = GG::Wnd::Create<TypeSelector>(
+                GG::X(90), PlayerRowHeight(), m_player_data.m_client_type, m_initial_disabled);
             push_back(type_drop);
             if (m_initial_disabled)
                 type_drop->Disable();
@@ -359,21 +368,25 @@ namespace {
             DataChangedSignal();
         }
 
-        bool                                     m_initial_disabled;
+        bool m_initial_disabled;
     };
 
     // Row for player info when loading a game
     struct LoadGamePlayerRow : PlayerRow {
-        LoadGamePlayerRow(const PlayerSetupData& player_data, int player_id, const std::map<int, SaveGameEmpireData>& save_game_empire_data, bool disabled) :
+        LoadGamePlayerRow(const PlayerSetupData& player_data, int player_id, const std::map<int, SaveGameEmpireData>& save_game_empire_data, bool disabled, bool in_game) :
             PlayerRow(player_data, player_id),
-            m_empire_list(nullptr),
             m_save_game_empire_data(save_game_empire_data),
-            m_initial_disabled(disabled)
+            m_initial_disabled(disabled),
+            m_in_game(in_game)
         {}
 
         void CompleteConstruction() override {
             PlayerRow::CompleteConstruction();
 
+#if BOOST_VERSION >= 106000
+            using boost::placeholders::_1;
+#endif
+
             // human / AI / observer indicator / selector
             auto type_drop = GG::Wnd::Create<TypeSelector>(GG::X(90), PlayerRowHeight(), m_player_data.m_client_type, m_initial_disabled);
             push_back(type_drop);
@@ -394,17 +407,22 @@ namespace {
             for (auto it = m_save_game_empire_data.begin();
                  it != m_save_game_empire_data.end(); ++it)
             {
+                // don't allow to select eliminated empire
+                if (it->second.m_eliminated)
+                    continue;
+
                 // insert row into droplist of empires for this player row
                 m_empire_list->Insert(GG::Wnd::Create<CUISimpleDropDownListRow>(it->second.m_empire_name));
 
                 // attempt to choose a default empire to be selected in this
-                // player row.  if this empire row matches this player data's
-                // save gamge empire id, or if this empire row's player name
-                // matches this player data's player name, select the row
+                // player row. If this empire row matches this player data's
+                // save game empire id, or if this empire row's player name
+                // matches this player data's player name in loading game,
+                // select the row
                 if ((it->first == m_player_data.m_save_game_empire_id) ||
                         (m_player_data.m_save_game_empire_id == ALL_EMPIRES &&
-                         it->second.m_player_name == m_player_data.m_player_name)
-                   )
+                         it->second.m_player_name == m_player_data.m_player_name &&
+                         !m_in_game))
                 {
                     m_empire_list->Select(--m_empire_list->end());
                     m_player_data.m_empire_name =           it->second.m_empire_name;
@@ -465,24 +483,79 @@ namespace {
                 ErrorLogger() << "Empire changed to no empire.  Ignoring change.";
                 return;
             }
-            auto it = m_save_game_empire_data.begin();
-            std::advance(it, m_empire_list->IteratorToIndex(selected_it));
-            m_player_data.m_empire_name =           it->second.m_empire_name;
-            m_player_data.m_empire_color =          it->second.m_color;
-            m_player_data.m_save_game_empire_id =   it->second.m_empire_id;
-            m_color_selector->SelectColor(m_player_data.m_empire_color);
+            const std::string& empire_name = boost::polymorphic_downcast<GG::Label*>((*selected_it)->at(0))->Text();
+            for (const auto& it : m_save_game_empire_data) {
+                if (it.second.m_empire_name == empire_name) {
+                    m_player_data.m_empire_name = empire_name;
+                    m_player_data.m_empire_color = it.second.m_color;
+                    m_player_data.m_save_game_empire_id = it.second.m_empire_id;
+                    m_color_selector->SelectColor(m_player_data.m_empire_color);
 
-            // set previous player name indication
-            if (size() >= 5)
-                boost::polymorphic_downcast<GG::Label*>(at(4))->SetText(it->second.m_player_name);
+                    // set previous player name indication
+                    if (size() >= 5)
+                        boost::polymorphic_downcast<GG::Label*>(at(4))->SetText(it.second.m_player_name);
 
-            DataChangedSignal();
+                    DataChangedSignal();
+                    return;
+                }
+            }
         }
 
         std::shared_ptr<EmpireColorSelector>                     m_color_selector;
         std::shared_ptr<GG::DropDownList>                        m_empire_list;
         const std::map<int, SaveGameEmpireData>& m_save_game_empire_data;
         bool                                     m_initial_disabled;
+        bool                                     m_in_game;
+    };
+
+    // Row for empire without assigned player
+    struct LoadGameEmpireRow : PlayerRow {
+        LoadGameEmpireRow(const SaveGameEmpireData& save_game_empire_data, bool disabled) :
+            PlayerRow(),
+            m_save_game_empire_data(save_game_empire_data),
+            m_initial_disabled(disabled)
+        {}
+
+        void CompleteConstruction() override {
+            PlayerRow::CompleteConstruction();
+
+#if BOOST_VERSION >= 106000
+            using boost::placeholders::_1;
+#endif
+
+            auto type_drop = GG::Wnd::Create<TypeSelector>(
+                GG::X(90), PlayerRowHeight(), Networking::INVALID_CLIENT_TYPE, m_initial_disabled);
+            push_back(type_drop);
+            type_drop->TypeChangedSignal.connect(
+                boost::bind(&LoadGameEmpireRow::PlayerTypeChanged, this, _1));
+            // player name text
+            push_back(GG::Wnd::Create<CUILabel>(""));
+            // empire name
+            push_back(GG::Wnd::Create<CUILabel>(m_save_game_empire_data.m_empire_name));
+            // empire colour selector (disabled, so acts as colour indicator)
+            m_color_selector = GG::Wnd::Create<EmpireColorSelector>(PlayerFontHeight() + PlayerRowMargin());
+            m_color_selector->SelectColor(m_save_game_empire_data.m_color);
+            m_color_selector->Disable();
+            push_back(m_color_selector);
+            // original empire player name from saved game
+            push_back(GG::Wnd::Create<CUILabel>(m_save_game_empire_data.m_player_name));
+            // ready state
+            push_back(GG::Wnd::Create<CUILabel>(""));
+            // host
+            push_back(GG::Wnd::Create<CUILabel>(""));
+        }
+    private:
+        void PlayerTypeChanged(Networking::ClientType type) {
+            m_player_data.m_client_type = type;
+            m_player_data.m_empire_name =         m_save_game_empire_data.m_empire_name;
+            m_player_data.m_empire_color =        m_save_game_empire_data.m_color;
+            m_player_data.m_save_game_empire_id = m_save_game_empire_data.m_empire_id;
+            DataChangedSignal();
+        }
+
+        std::shared_ptr<EmpireColorSelector> m_color_selector;
+        const SaveGameEmpireData&            m_save_game_empire_data;
+        bool                                 m_initial_disabled = false;
     };
 
     // Row for indicating that an AI client should be added to the game
@@ -494,7 +567,12 @@ namespace {
         void CompleteConstruction() override {
             PlayerRow::CompleteConstruction();
 
-            auto type_drop = GG::Wnd::Create<TypeSelector>(GG::X(90), PlayerRowHeight(), Networking::INVALID_CLIENT_TYPE, false);
+#if BOOST_VERSION >= 106000
+            using boost::placeholders::_1;
+#endif
+
+            auto type_drop = GG::Wnd::Create<TypeSelector>(
+                GG::X(90), PlayerRowHeight(), Networking::INVALID_CLIENT_TYPE, false);
             push_back(type_drop);
             type_drop->TypeChangedSignal.connect(
                 boost::bind(&EmptyPlayerRow::PlayerTypeChanged, this, _1));
@@ -543,31 +621,24 @@ namespace {
 
 MultiPlayerLobbyWnd::MultiPlayerLobbyWnd() :
     CUIWnd(UserString("MPLOBBY_WINDOW_TITLE"),
-           GG::ONTOP | GG::INTERACTIVE | GG::RESIZABLE),
-    m_chat_wnd(nullptr),
-    m_any_can_edit(nullptr),
-    m_new_load_game_buttons(nullptr),
-    m_galaxy_setup_panel(nullptr),
-    m_browse_saves_btn(nullptr),
-    m_preview_image(nullptr),
-    m_players_lb(nullptr),
-    m_players_lb_headers(nullptr),
-    m_ready_bn(nullptr),
-    m_cancel_bn(nullptr),
-    m_start_conditions_text(nullptr)
+           GG::ONTOP | GG::INTERACTIVE | GG::RESIZABLE)
 {}
 
 void MultiPlayerLobbyWnd::CompleteConstruction() {
     Sound::TempUISoundDisabler sound_disabler;
 
+    TraceLogger() << "MultiPlayerLobbyWnd::CompleteConstruction";
+
     m_chat_wnd = GG::Wnd::Create<MessageWnd>(GG::INTERACTIVE, "mplobby.chat");
 
     m_any_can_edit = GG::Wnd::Create<CUIStateButton>(UserString("EDITABLE_GALAXY_SETTINGS"), GG::FORMAT_LEFT, std::make_shared<CUICheckBoxRepresenter>());
     m_any_can_edit->SetBrowseModeTime(GetOptionsDB().Get<int>("ui.tooltip.delay"));
     m_any_can_edit->SetBrowseText(UserString("EDITABLE_GALAXY_SETTINGS_DESC"));
 
+    TraceLogger() << "MultiPlayerLobbyWnd::CompleteConstruction creating galaxy setup panel";
     m_galaxy_setup_panel = GG::Wnd::Create<GalaxySetupPanel>(GALAXY_SETUP_PANEL_WIDTH, GALAXY_SETUP_PANEL_HEIGHT);
 
+    TraceLogger() << "MultiPlayerLobbyWnd::CompleteConstruction creating buttons";
     m_new_load_game_buttons = GG::Wnd::Create<GG::RadioButtonGroup>(GG::VERTICAL);
     m_new_load_game_buttons->AddButton(
         GG::Wnd::Create<CUIStateButton>(UserString("NEW_GAME_BN"), GG::FORMAT_LEFT, std::make_shared<CUIRadioRepresenter>()));
@@ -582,6 +653,7 @@ void MultiPlayerLobbyWnd::CompleteConstruction() {
     m_players_lb_headers = GG::Wnd::Create<PlayerLabelRow>();
     m_players_lb_headers->SetMinSize(GG::Pt(GG::X(0), PlayerRowHeight() + PlayerFontHeight()));
 
+    TraceLogger() << "MultiPlayerLobbyWnd::CompleteConstruction creating players list box";
     m_players_lb = GG::Wnd::Create<CUIListBox>();
     m_players_lb->SetStyle(GG::LIST_NOSORT | GG::LIST_NOSEL);
     m_players_lb->LockColWidths();
@@ -594,6 +666,7 @@ void MultiPlayerLobbyWnd::CompleteConstruction() {
     }
     m_players_lb->SetColHeaders(m_players_lb_headers);
 
+    TraceLogger() << "MultiPlayerLobbyWnd::CompleteConstruction creating ready and cancel buttons";
     m_ready_bn = Wnd::Create<CUIButton>(UserString("READY_BN"));
     m_cancel_bn = Wnd::Create<CUIButton>(UserString("CANCEL"));
 
@@ -611,39 +684,40 @@ void MultiPlayerLobbyWnd::CompleteConstruction() {
     AttachChild(m_cancel_bn);
     AttachChild(m_start_conditions_text);
 
+    TraceLogger() << "MultiPlayerLobbyWnd::CompleteConstruction positioning and layout";
     ResetDefaultPosition();
     SetMinSize(GG::Pt(LOBBY_WND_WIDTH, LOBBY_WND_HEIGHT));
     DoLayout();
     SaveDefaultedOptions();
 
+    TraceLogger() << "MultiPlayerLobbyWnd::CompleteConstruction default new game settings";
     // default settings (new game)
     m_new_load_game_buttons->SetCheck(0);
     PreviewImageChanged(m_galaxy_setup_panel->PreviewImage());
     m_save_file_text->Disable();
     m_browse_saves_btn->Disable();
 
-    m_any_can_edit->CheckedSignal.connect(
-        boost::bind(&MultiPlayerLobbyWnd::AnyCanEdit, this, _1));
-    m_new_load_game_buttons->ButtonChangedSignal.connect(
-        boost::bind(&MultiPlayerLobbyWnd::NewLoadClicked, this, _1));
-    m_galaxy_setup_panel->SettingsChangedSignal.connect(
-        boost::bind(&MultiPlayerLobbyWnd::GalaxySetupPanelChanged, this));
-    m_browse_saves_btn->LeftClickedSignal.connect(
-        boost::bind(&MultiPlayerLobbyWnd::SaveGameBrowse, this));
-    m_ready_bn->LeftClickedSignal.connect(
-        boost::bind(&MultiPlayerLobbyWnd::ReadyClicked, this));
-    m_galaxy_setup_panel->ImageChangedSignal.connect(
-        boost::bind(&MultiPlayerLobbyWnd::PreviewImageChanged, this, _1));
-    m_cancel_bn->LeftClickedSignal.connect(
-        boost::bind(&MultiPlayerLobbyWnd::CancelClicked, this));
+#if BOOST_VERSION >= 106000
+    using boost::placeholders::_1;
+#endif
 
+    m_any_can_edit->CheckedSignal.connect(boost::bind(&MultiPlayerLobbyWnd::AnyCanEdit, this, _1));
+    m_new_load_game_buttons->ButtonChangedSignal.connect(boost::bind(&MultiPlayerLobbyWnd::NewLoadClicked, this, _1));
+    m_galaxy_setup_panel->SettingsChangedSignal.connect(boost::bind(&MultiPlayerLobbyWnd::GalaxySetupPanelChanged, this));
+    m_browse_saves_btn->LeftClickedSignal.connect(boost::bind(&MultiPlayerLobbyWnd::SaveGameBrowse, this));
+    m_ready_bn->LeftClickedSignal.connect(boost::bind(&MultiPlayerLobbyWnd::ReadyClicked, this));
+    m_galaxy_setup_panel->ImageChangedSignal.connect(boost::bind(&MultiPlayerLobbyWnd::PreviewImageChanged, this, _1));
+    m_cancel_bn->LeftClickedSignal.connect(boost::bind(&MultiPlayerLobbyWnd::CancelClicked, this));
+
+    TraceLogger() << "MultiPlayerLobbyWnd::CompleteConstruction finishing...";
     CUIWnd::CompleteConstruction();
 
     Refresh();
+    TraceLogger() << "MultiPlayerLobbyWnd::CompleteConstruction done";
 }
 
 MultiPlayerLobbyWnd::PlayerLabelRow::PlayerLabelRow(GG::X width /* = GG::X(580)*/) :
-    GG::ListBox::Row(width, PlayerRowHeight(), "")
+    GG::ListBox::Row(width, PlayerRowHeight())
 {}
 
 void MultiPlayerLobbyWnd::PlayerLabelRow::CompleteConstruction() {
@@ -710,6 +784,9 @@ GG::Rect MultiPlayerLobbyWnd::CalculatePosition() const {
 bool MultiPlayerLobbyWnd::LoadGameSelected() const
 { return m_new_load_game_buttons->CheckedButton() == 1; }
 
+std::string MultiPlayerLobbyWnd::GetChatText() const
+{ return m_chat_wnd->GetText(); }
+
 void MultiPlayerLobbyWnd::Render() {
     CUIWnd::Render();
     GG::Pt image_ul = g_preview_ul + ClientUpperLeft(), image_lr = image_ul + PREVIEW_SZ;
@@ -730,14 +807,19 @@ void MultiPlayerLobbyWnd::ChatMessage(int player_id, const boost::posix_time::pt
     // look up player name by ID
     std::string player_name{UserString("PLAYER") + " " + std::to_string(player_id)};
     GG::Clr text_color{ClientUI::GetClientUI()->TextColor()};
-    for (std::pair<int, PlayerSetupData>& entry : m_lobby_data.m_players) {
-        if (entry.first != player_id || entry.first == Networking::INVALID_PLAYER_ID)
-            continue;
-        player_name = entry.second.m_player_name;
-        text_color = entry.second.m_empire_color;
+    if (player_id != Networking::INVALID_PLAYER_ID) {
+        for (auto& entry : m_lobby_data.m_players) {
+            if (entry.first != player_id || entry.first == Networking::INVALID_PLAYER_ID)
+                continue;
+            player_name = entry.second.m_player_name;
+            text_color = entry.second.m_empire_color;
+        }
+    } else {
+        // It's a server message. Don't set player name.
+        player_name = "";
     }
 
-    m_chat_wnd->HandlePlayerChatMessage(msg, player_name, text_color, timestamp, HumanClientApp::GetApp()->PlayerID());
+    m_chat_wnd->HandlePlayerChatMessage(msg, player_name, text_color, timestamp, HumanClientApp::GetApp()->PlayerID(), false);  // no pm messages for MP lobby yet
 }
 
 void MultiPlayerLobbyWnd::ChatMessage(const std::string& message_text,
@@ -746,9 +828,12 @@ void MultiPlayerLobbyWnd::ChatMessage(const std::string& message_text,
                                       const boost::posix_time::ptime& timestamp)
 {
     m_chat_wnd->HandlePlayerChatMessage(message_text, player_name, text_color, timestamp,
-                                        HumanClientApp::GetApp()->PlayerID());
+                                        HumanClientApp::GetApp()->PlayerID(), false);
 }
 
+void MultiPlayerLobbyWnd::TurnPhaseUpdate(Message::TurnProgressPhase phase_id)
+{ m_chat_wnd->HandleTurnPhaseUpdate(phase_id, true); }
+
 namespace {
     void LogPlayerSetupData(const std::list<std::pair<int, PlayerSetupData>>& psd) {
         DebugLogger() << "PlayerSetupData:";
@@ -916,6 +1001,9 @@ void MultiPlayerLobbyWnd::PlayerDataChangedLocally() {
 
             // empty rows that are still showing no player don't need to be sent to the server.
 
+        } else if (const LoadGameEmpireRow* empire_row = dynamic_cast<const LoadGameEmpireRow*>(player_row)) {
+            if (empire_row->m_player_data.m_client_type == Networking::CLIENT_TYPE_AI_PLAYER)
+                m_lobby_data.m_players.push_back({Networking::INVALID_PLAYER_ID, empire_row->m_player_data});
         } else {
             // all other row types pass along data directly
             m_lobby_data.m_players.push_back({player_row->m_player_id, player_row->m_player_data});
@@ -954,7 +1042,7 @@ bool MultiPlayerLobbyWnd::PopulatePlayerList() {
 
         } else {
             bool immutable_row = (!HasAuthRole(Networking::ROLE_HOST) && (data_player_id != HumanClientApp::GetApp()->PlayerID()) && !(psd.m_client_type == Networking::CLIENT_TYPE_AI_PLAYER && HasAuthRole(Networking::ROLE_GALAXY_SETUP))) || m_lobby_data.m_save_game_empire_data.empty();
-            auto row = GG::Wnd::Create<LoadGamePlayerRow>(psd, data_player_id, m_lobby_data.m_save_game_empire_data, immutable_row);
+            auto row = GG::Wnd::Create<LoadGamePlayerRow>(psd, data_player_id, m_lobby_data.m_save_game_empire_data, immutable_row, m_lobby_data.m_in_game);
             m_players_lb->Insert(row);
             row->DataChangedSignal.connect(
                 boost::bind(&MultiPlayerLobbyWnd::PlayerDataChangedLocally, this));
@@ -979,6 +1067,25 @@ bool MultiPlayerLobbyWnd::PopulatePlayerList() {
         { is_other_ready = is_other_ready && psd.m_player_ready; }
     }
 
+    // add rows for unassigned empires and adds "Add AI" to assign AI to empire
+    if (!m_lobby_data.m_new_game) {
+        for (const auto& save_game_empire_data : m_lobby_data.m_save_game_empire_data) {
+            bool is_assigned = false;
+            for (const auto& player : m_lobby_data.m_players) {
+                if (player.second.m_save_game_empire_id == save_game_empire_data.second.m_empire_id) {
+                    is_assigned = true;
+                    break;
+                }
+            }
+            if (!is_assigned) {
+                auto row = GG::Wnd::Create<LoadGameEmpireRow>(save_game_empire_data.second, !HasAuthRole(Networking::ROLE_GALAXY_SETUP));
+                m_players_lb->Insert(row);
+                row->DataChangedSignal.connect(
+                    boost::bind(&MultiPlayerLobbyWnd::PlayerDataChangedLocally, this));
+            }
+        }
+    }
+
     // on host, add extra empty row, which the host can use to select
     // "Add AI" to add an AI to the game.  This row's details are treated
     // specially when sending a lobby update to the server.
