@@ -16,16 +16,8 @@
 #include <GG/Layout.h>
 #include <GG/TabWnd.h>
 
-//boost::spirit::classic pulls in windows.h which in turn defines the macros
-//MessageBox, PlaySound, min and max. Disabling the generation of the min and
-// max macros and undefining those should avoid name collisions with std c++
-// library and FreeOrion function names.
-#define NOMINMAX
-#include <boost/spirit/include/classic.hpp>
-#ifdef FREEORION_WIN32
-#  undef MessageBox
-#  undef PlaySound
-#endif
+#include <boost/spirit/include/qi.hpp>
+#include <boost/spirit/include/phoenix_operator.hpp>
 
 #include <boost/format.hpp>
 #include <boost/algorithm/string/predicate.hpp>
@@ -133,7 +125,7 @@ namespace {
             fs::path path = FilenameToPath(file);
             return boost::algorithm::ends_with(file, STRINGTABLE_FILE_SUFFIX) &&
                 fs::exists(path) && !fs::is_directory(path);
-        } catch (std::exception ex) {
+        } catch (...) {
         }
         return false;
     }
@@ -145,7 +137,7 @@ namespace {
             fs::path path = FilenameToPath(file);
             return boost::algorithm::ends_with(file, FONT_FILE_SUFFIX) &&
                 fs::exists(path) && !fs::is_directory(path);
-        } catch (std::exception ex) {
+        } catch (...) {
         }
         return false;
     }
@@ -157,7 +149,7 @@ namespace {
             fs::path path = FilenameToPath(file);
             return boost::algorithm::ends_with(file, MUSIC_FILE_SUFFIX) &&
                 fs::exists(path) && !fs::is_directory(path);
-        } catch (std::exception ex) {
+        } catch (...) {
         }
         return false;
     }
@@ -169,7 +161,7 @@ namespace {
             fs::path path = FilenameToPath(file);
             return boost::algorithm::ends_with(file, SOUND_FILE_SUFFIX) &&
                 fs::exists(path) && !fs::is_directory(path);
-        } catch (std::exception ex) {
+        } catch (...) {
         }
         return false;
     }
@@ -180,7 +172,7 @@ namespace {
         try {
             fs::path path = FilenameToPath(file);
             return fs::exists(path) && fs::is_directory(path);
-        } catch (std::exception ex) {
+        } catch (...) {
         }
         return false;
     }
@@ -206,7 +198,7 @@ namespace {
             m_code_point = key_code_point;
             m_mods = mod_keys;
             // exit modal loop only if not a modifier
-            if (!(m_key >= GG::GGK_NUMLOCK && m_key <= GG::GGK_COMPOSE))
+            if (GG::GGK_LCONTROL > m_key || GG::GGK_RGUI < m_key)
                 m_done = true;
 
             /// @todo Clean up, ie transform LCTRL or RCTRL into CTRL and
@@ -227,10 +219,7 @@ namespace {
             CUIWnd(UserString("OPTIONS_FONTS"),
                    GG::GUI::GetGUI()->AppWidth() / 6,       GG::GUI::GetGUI()->AppHeight() / 6,
                    GG::GUI::GetGUI()->AppWidth() * 2 / 3,   GG::GUI::GetGUI()->AppHeight() * 2 / 3,
-                   GG::INTERACTIVE | GG::DRAGABLE | GG::MODAL | GG::RESIZABLE | CLOSABLE),
-            m_font_graphic(nullptr),
-            m_title_font_graphic(nullptr),
-            m_hscroll(nullptr)
+                   GG::INTERACTIVE | GG::DRAGABLE | GG::MODAL | GG::RESIZABLE | CLOSABLE)
         {}
 
         void CompleteConstruction() override {
@@ -250,6 +239,17 @@ namespace {
                 top += m_font_graphic->Height() + 1;
             }
 
+            font = ClientUI::GetBoldFont();
+            if (font)
+                texture = font->GetTexture();
+            if (texture) {
+                m_bold_font_graphic = GG::Wnd::Create<GG::StaticGraphic>(texture);
+                m_bold_font_graphic->MoveTo(GG::Pt(GG::X0, top));
+                m_bold_font_graphic->Resize(GG::Pt(texture->Width(), texture->Height()));
+                AttachChild(m_bold_font_graphic);
+                top += m_bold_font_graphic->Height() + 1;
+            }
+
             font = ClientUI::GetTitleFont();
             texture.reset();
             if (font)
@@ -265,6 +265,13 @@ namespace {
             m_hscroll =  GG::Wnd::Create<CUIScroll>(GG::HORIZONTAL);
             AttachChild(m_hscroll);
 
+#if BOOST_VERSION >= 106000
+            using boost::placeholders::_1;
+            using boost::placeholders::_2;
+            using boost::placeholders::_3;
+            using boost::placeholders::_4;
+#endif
+
             m_hscroll->ScrolledSignal.connect(
                 boost::bind(&FontTextureWnd::ScrolledSlot, this, _1, _2, _3, _4));
             DoLayout();
@@ -300,6 +307,7 @@ namespace {
 
     private:
         std::shared_ptr<GG::StaticGraphic>  m_font_graphic;
+        std::shared_ptr<GG::StaticGraphic>  m_bold_font_graphic;
         std::shared_ptr<GG::StaticGraphic>  m_title_font_graphic;
         std::shared_ptr<GG::Scroll>         m_hscroll;
     };
@@ -312,15 +320,14 @@ namespace {
     class OptionsListRow : public GG::ListBox::Row {
     public:
         OptionsListRow(GG::X w, GG::Y h, std::shared_ptr<RowContentsWnd> contents) :
-            GG::ListBox::Row(w, h, ""),
+            GG::ListBox::Row(w, h),
             m_contents(std::forward<std::shared_ptr<RowContentsWnd>>(contents))
         {
             SetChildClippingMode(ClipToClient);
         }
 
         OptionsListRow(GG::X w, GG::Y h, std::shared_ptr<Wnd> contents, int indentation = 0) :
-            GG::ListBox::Row(w, h, ""),
-            m_contents(nullptr)
+            GG::ListBox::Row(w, h)
         {
             SetChildClippingMode(ClipToClient);
             if (contents)
@@ -444,9 +451,7 @@ OptionsWnd::OptionsWnd(bool is_game_running_):
     CUIWnd(UserString("OPTIONS_TITLE"),
            GG::INTERACTIVE | GG::DRAGABLE | GG::MODAL | GG::RESIZABLE,
            OPTIONS_WND_NAME),
-    is_game_running(is_game_running_),
-    m_tabs(nullptr),
-    m_done_button(nullptr)
+    is_game_running(is_game_running_)
 {}
 
 void OptionsWnd::CompleteConstruction() {
@@ -518,6 +523,8 @@ void OptionsWnd::CompleteConstruction() {
     // UI settings tab
     current_page = CreatePage(UserString("OPTIONS_PAGE_UI"));
     CreateSectionHeader(current_page, 0, UserString("OPTIONS_MISC_UI"));
+
+    BoolOption(current_page, 0, "ui.pedia.search.articles.enabled", UserString("OPTIONS_PEDIA_SEARCH_ARTICLE_TEXT"));
     BoolOption(current_page, 0, "ui.input.mouse.button.swap.enabled", UserString("OPTIONS_SWAP_MOUSE_LR"));
     BoolOption(current_page, 0, "ui.fleet.multiple.enabled", UserString("OPTIONS_MULTIPLE_FLEET_WNDS"));
     BoolOption(current_page, 0, "ui.quickclose.enabled", UserString("OPTIONS_QUICK_CLOSE_WNDS"));
@@ -553,23 +560,6 @@ void OptionsWnd::CompleteConstruction() {
     IntOption(current_page, 0, "ui.input.mouse.button.repeat.delay",    UserString("OPTIONS_MOUSE_REPEAT_DELAY"));
     IntOption(current_page, 0, "ui.input.mouse.button.repeat.interval", UserString("OPTIONS_MOUSE_REPEAT_INTERVAL"));
 
-    CreateSectionHeader(current_page, 0,                                UserString("OPTIONS_FONTS"));
-    FontOption(current_page, 0, "ui.font.path",                         UserString("OPTIONS_FONT_TEXT"));
-    FontOption(current_page, 0, "ui.font.title.path",                   UserString("OPTIONS_FONT_TITLE"));
-
-    // show font texture button
-    auto show_font_texture_button = Wnd::Create<CUIButton>(UserString("SHOW_FONT_TEXTURES"));
-    row = GG::Wnd::Create<OptionsListRow>(
-        ROW_WIDTH, show_font_texture_button ->MinUsableSize().y + LAYOUT_MARGIN + 6,
-        show_font_texture_button , 0);
-    current_page->Insert(row);
-    show_font_texture_button->LeftClickedSignal.connect(
-        &ShowFontTextureWnd);
-
-    CreateSectionHeader(current_page, 0, UserString("OPTIONS_FONT_SIZES"));
-    IntOption(current_page,    0, "ui.font.size",                       UserString("OPTIONS_FONT_TEXT"));
-    IntOption(current_page,    0, "ui.font.title.size",                 UserString("OPTIONS_FONT_TITLE"));
-
     CreateSectionHeader(current_page, 0,                                UserString("OPTIONS_RESEARCH_WND"));
     DoubleOption(current_page, 0, "ui.research.tree.spacing.horizontal",UserString("OPTIONS_TECH_SPACING_HORIZONTAL"));
     DoubleOption(current_page, 0, "ui.research.tree.spacing.vertical",  UserString("OPTIONS_TECH_SPACING_VERTICAL"));
@@ -587,6 +577,29 @@ void OptionsWnd::CompleteConstruction() {
 
     m_tabs->SetCurrentWnd(0);
 
+    // Font tab
+    current_page = CreatePage(UserString("OPTIONS_FONTS"));
+
+    CreateSectionHeader(current_page, 0, UserString("OPTIONS_FONTS"));
+    FontOption(current_page, 0, "ui.font.path",                         UserString("OPTIONS_FONT_TEXT"));
+    FontOption(current_page, 0, "ui.font.bold.path",                    UserString("OPTIONS_FONT_BOLD_TEXT"));
+    FontOption(current_page, 0, "ui.font.title.path",                   UserString("OPTIONS_FONT_TITLE"));
+
+    // show font texture button
+    auto show_font_texture_button = Wnd::Create<CUIButton>(UserString("SHOW_FONT_TEXTURES"));
+    row = GG::Wnd::Create<OptionsListRow>(
+        ROW_WIDTH, show_font_texture_button ->MinUsableSize().y + LAYOUT_MARGIN + 6,
+        show_font_texture_button , 0);
+    current_page->Insert(row);
+    show_font_texture_button->LeftClickedSignal.connect(
+        &ShowFontTextureWnd);
+
+    CreateSectionHeader(current_page, 0, UserString("OPTIONS_FONT_SIZES"));
+    IntOption(current_page,    0, "ui.font.size",                       UserString("OPTIONS_FONT_TEXT"));
+    IntOption(current_page,    0, "ui.font.title.size",                 UserString("OPTIONS_FONT_TITLE"));
+
+    m_tabs->SetCurrentWnd(0);
+
     // Galaxy Map Page
     current_page = CreatePage(UserString("OPTIONS_GALAXY_MAP"));
     CreateSectionHeader(current_page, 0,                                UserString("OPTIONS_SYSTEM_ICONS"));
@@ -619,6 +632,7 @@ void OptionsWnd::CompleteConstruction() {
     CreateSectionHeader(current_page, 0,                                        UserString("OPTIONS_GALAXY_MAP_GENERAL"));
     BoolOption(current_page,   0, "ui.map.background.gas.shown",                UserString("OPTIONS_GALAXY_MAP_GAS"));
     BoolOption(current_page,   0, "ui.map.background.starfields.shown",         UserString("OPTIONS_GALAXY_MAP_STARFIELDS"));
+    DoubleOption(current_page, 0, "ui.map.background.starfields.scale",         UserString("OPTIONS_GALAXY_MAP_STARFIELDS_SCALE"));
     BoolOption(current_page,   0, "ui.map.scale.legend.shown",                  UserString("OPTIONS_GALAXY_MAP_SCALE_LINE"));
     BoolOption(current_page,   0, "ui.map.scale.circle.shown",                  UserString("OPTIONS_GALAXY_MAP_SCALE_CIRCLE"));
     BoolOption(current_page,   0, "ui.map.zoom.slider.shown",                   UserString("OPTIONS_GALAXY_MAP_ZOOM_SLIDER"));
@@ -747,6 +761,22 @@ void OptionsWnd::CompleteConstruction() {
     BoolOption(current_page, 0, "ui.map.sitrep.invalid.shown", UserString("OPTIONS_VERBOSE_SITREP_DESC"));
     BoolOption(current_page, 0, "effects.accounting.enabled", UserString("OPTIONS_EFFECT_ACCOUNTING"));
 
+    // Create full state config button
+    auto all_config_button = GG::Wnd::Create<CUIButton>(UserString("OPTIONS_WRITE_ALL_CONFIG"));
+    all_config_button->SetBrowseModeTime(GetOptionsDB().Get<int>("ui.tooltip.delay"));
+    all_config_button->SetBrowseInfoWnd(
+        GG::Wnd::Create<TextBrowseWnd>(UserString("OPTIONS_CREATE_ALL_CONFIG_TOOLTIP_TITLE"),
+                                       UserString("OPTIONS_CREATE_ALL_CONFIG_TOOLTIP_DESC"), ROW_WIDTH));
+    all_config_button->LeftClickedSignal.connect([]() {
+        if (GetOptionsDB().Commit(false, false))
+            ClientUI::MessageBox(UserString("OPTIONS_CREATE_ALL_CONFIG_SUCCESS"));
+        else
+            ClientUI::MessageBox(UserString("OPTIONS_CREATE_ALL_CONFIG_FAILURE"));
+    });
+    current_page->Insert(GG::Wnd::Create<OptionsListRow>(ROW_WIDTH,
+                                                         all_config_button->MinUsableSize().y + LAYOUT_MARGIN + 6,
+                                                         all_config_button, 0));
+
     // Create persistent config button
     auto persistent_config_button = GG::Wnd::Create<CUIButton>(UserString("OPTIONS_CREATE_PERSISTENT_CONFIG"));
     persistent_config_button->SetBrowseModeTime(GetOptionsDB().Get<int>("ui.tooltip.delay"));
@@ -891,10 +921,8 @@ void OptionsWnd::HotkeyOption(GG::ListBox* page, int indentation_level, const st
     auto row = GG::Wnd::Create<OptionsListRow>(ROW_WIDTH, std::max(button->MinUsableSize().y, text_control->MinUsableSize().y) + 6,
                                                layout, indentation_level);
 
-    button->LeftClickedSignal.connect(
-        boost::bind(HandleSetHotkeyOption, hotkey_name, button.get()));
-    button->RightClickedSignal.connect(
-        boost::bind(HandleResetHotkeyOption, hotkey_name, button.get()));
+    button->LeftClickedSignal.connect(boost::bind(HandleSetHotkeyOption, hotkey_name, button.get()));
+    button->RightClickedSignal.connect(boost::bind(HandleResetHotkeyOption, hotkey_name, button.get()));
 
     page->Insert(row);
 }
@@ -992,6 +1020,13 @@ void OptionsWnd::MusicVolumeOption(GG::ListBox* page, int indentation_level, Sou
     button->SetBrowseText(UserString(GetOptionsDB().GetDescription("audio.music.enabled")));
     slider->SetBrowseModeTime(GetOptionsDB().Get<int>("ui.tooltip.delay"));
     slider->SetBrowseText(UserString(GetOptionsDB().GetDescription("audio.music.volume")));
+
+#if BOOST_VERSION >= 106000
+    using boost::placeholders::_1;
+    using boost::placeholders::_2;
+    using boost::placeholders::_3;
+#endif
+
     button->CheckedSignal.connect(
         boost::bind(&OptionsWnd::SoundOptionsFeedback::MusicClicked, &fb, _1));
     slider->SlidSignal.connect(
@@ -1021,6 +1056,13 @@ void OptionsWnd::VolumeOption(GG::ListBox* page, int indentation_level, const st
     button->SetBrowseText(UserString(GetOptionsDB().GetDescription(toggle_option_name)));
     slider->SetBrowseModeTime(GetOptionsDB().Get<int>("ui.tooltip.delay"));
     slider->SetBrowseText(UserString(GetOptionsDB().GetDescription(volume_option_name)));
+
+#if BOOST_VERSION >= 106000
+    using boost::placeholders::_1;
+    using boost::placeholders::_2;
+    using boost::placeholders::_3;
+#endif
+
     button->CheckedSignal.connect(
         boost::bind(&OptionsWnd::SoundOptionsFeedback::SoundEffectsEnableClicked, &fb, _1));
     slider->SlidAndStoppedSignal.connect(
@@ -1210,7 +1252,7 @@ void OptionsWnd::ResolutionOption(GG::ListBox* page, int indentation_level) {
     // fullscreen / windowed toggle
     BoolOption(page, indentation_level, "video.fullscreen.enabled", UserString("OPTIONS_FULLSCREEN"));
     // Fake mode change is not possible without the opengl frame buffer extension
-    if (GG::SDLGUI::GetGUI()->FramebuffersAvailable()) {
+    if (SDLGUI::GetGUI()->FramebuffersAvailable()) {
         BoolOption(page, indentation_level, "video.fullscreen.fake.enabled", UserString("OPTIONS_FAKE_MODE_CHANGE"));
     } else {
         GetOptionsDB().Set<bool>("video.fullscreen.fake.enabled", false);
@@ -1265,9 +1307,12 @@ void OptionsWnd::ResolutionOption(GG::ListBox* page, int indentation_level) {
             if (!drop_list_row)
                 return;
             int w, h;
-            namespace classic = boost::spirit::classic;
-            classic::rule<> resolution_p = classic::int_p[classic::assign_a(w)] >> classic::str_p(" x ") >> classic::int_p[classic::assign_a(h)];
-            classic::parse(drop_list_row->Name().c_str(), resolution_p);
+            namespace phx = boost::phoenix;
+            namespace qi = boost::spirit::qi;
+            qi::parse(
+                drop_list_row->Name().begin(), drop_list_row->Name().end(),
+                (qi::int_[phx::ref(w) = qi::_1] >> " x " >> qi::int_[phx::ref(h) = qi::_1])
+            );
             GetOptionsDB().Set<int>("video.fullscreen.width", w);
             GetOptionsDB().Set<int>("video.fullscreen.height", h);
         }
@@ -1283,7 +1328,7 @@ namespace {
 
         const std::regex dot { "\\.+" };
         const std::vector<std::string> nodes {
-            std::sregex_token_iterator(name.cbegin(), name.cend(), dot, -1),
+            std::sregex_token_iterator(name.begin(), name.end(), dot, -1),
             std::sregex_token_iterator()
         };
 
