@@ -6,7 +6,7 @@
 #include "../../universe/Species.h"
 #include "../../universe/Universe.h"
 #include "../../network/Networking.h"
-#include "../../network/ClientNetworking.h"
+#include "../ClientNetworking.h"
 #include "../../util/i18n.h"
 #include "../util/GameRules.h"
 #include "../../util/OptionsDB.h"
@@ -19,6 +19,7 @@
 
 #include <boost/format.hpp>
 #include <boost/uuid/uuid_io.hpp>
+#include <boost/uuid/nil_generator.hpp>
 #include <thread>
 
 /** \page statechart_notes Notes on Boost Statechart transitions
@@ -58,7 +59,7 @@
 
     Two constructions that may cause problems are:
 
-        - MessageBox blocks execution locally and starts an EventPump that handles events that may
+        - MessageBox blocks execution locally and starts an modal loop that handles events that may
           transit<> to a new state which makes a local transition lexically after the MessageBox
           potentially fatal.
 
@@ -69,7 +70,7 @@
 
 
 class CombatLogManager;
-CombatLogManager&   GetCombatLogManager();
+CombatLogManager& GetCombatLogManager();
 
 namespace {
     DeclareThreadSafeLogger(FSM);
@@ -127,6 +128,7 @@ IntroMenu::IntroMenu(my_context ctx) :
 {
     TraceLogger(FSM) << "(HumanClientFSM) IntroMenu";
     Client().GetClientUI().ShowIntroScreen();
+    GetGameRules().ResetToDefaults();
 }
 
 IntroMenu::~IntroMenu() {
@@ -242,7 +244,9 @@ boost::statechart::result WaitingForSPHostAck::react(const StartQuittingGame& e)
 
 boost::statechart::result WaitingForSPHostAck::react(const CheckSum& e) {
     TraceLogger(FSM) << "(HumanClientFSM) CheckSum.";
-    Client().VerifyCheckSum(e.m_message);
+    bool result = Client().VerifyCheckSum(e.m_message);
+    if (!result)
+        ClientUI::MessageBox(UserString("ERROR_CHECKSUM_MISMATCH"), true);
     return discard_event();
 }
 
@@ -319,7 +323,9 @@ boost::statechart::result WaitingForMPHostAck::react(const StartQuittingGame& e)
 
 boost::statechart::result WaitingForMPHostAck::react(const CheckSum& e) {
     TraceLogger(FSM) << "(HumanClientFSM) CheckSum.";
-    Client().VerifyCheckSum(e.m_message);
+    bool result = Client().VerifyCheckSum(e.m_message);
+    if (!result)
+        ClientUI::MessageBox(UserString("ERROR_CHECKSUM_MISMATCH"), true);
     return discard_event();
 }
 
@@ -344,9 +350,11 @@ boost::statechart::result WaitingForMPJoinAck::react(const JoinGame& msg) {
 
         if (!cookie.is_nil()) {
             try {
-                std::string cookie_option = "network.server.cookie." + Client().Networking().Destination();
-                GetOptionsDB().Remove(cookie_option);
-                GetOptionsDB().Add(cookie_option, "OPTIONS_DB_SERVER_COOKIE", boost::uuids::to_string(cookie));
+                std::string cookie_option = HumanClientApp::EncodeServerAddressOption(Client().Networking().Destination());
+                if (!GetOptionsDB().OptionExists(cookie_option + ".cookie")) {
+                    GetOptionsDB().Add(cookie_option + ".cookie", "OPTIONS_DB_SERVER_COOKIE", boost::uuids::to_string(boost::uuids::nil_uuid()));
+                }
+                GetOptionsDB().Set(cookie_option + ".cookie", boost::uuids::to_string(cookie));
                 GetOptionsDB().Commit();
             } catch(const std::exception& err) {
                 WarnLogger() << "Cann't save cookie for server " << Client().Networking().Destination() << ": "
@@ -489,7 +497,8 @@ boost::statechart::result MPLobby::react(const PlayerChat& msg) {
     int player_id;
     boost::posix_time::ptime timestamp;
     std::string data;
-    ExtractServerPlayerChatMessageData(msg.m_message, player_id, timestamp, data);
+    bool pm;
+    ExtractServerPlayerChatMessageData(msg.m_message, player_id, timestamp, data, pm);
 
     Client().GetClientUI().GetMultiPlayerLobbyWnd()->ChatMessage(player_id, timestamp, data);
     return discard_event();
@@ -523,8 +532,14 @@ boost::statechart::result MPLobby::react(const GameStart& msg) {
     // transitioning into WaitingForGameStart
     post_event(msg);
 
+    std::string chat_text = Client().GetClientUI().GetMultiPlayerLobbyWnd()->GetChatText();
+
     Client().GetClientUI().GetMapWnd()->Sanitize();
     Client().Remove(Client().GetClientUI().GetMultiPlayerLobbyWnd());
+    Client().Register(Client().GetClientUI().GetMessageWnd());
+
+    Client().GetClientUI().GetMessageWnd()->SetChatText(chat_text);
+
     return transit<WaitingForGameStart>();
 }
 
@@ -558,7 +573,9 @@ boost::statechart::result MPLobby::react(const StartQuittingGame& e) {
 
 boost::statechart::result MPLobby::react(const CheckSum& e) {
     TraceLogger(FSM) << "(HumanClientFSM) CheckSum.";
-    Client().VerifyCheckSum(e.m_message);
+    bool result = Client().VerifyCheckSum(e.m_message);
+    if (!result)
+        ClientUI::MessageBox(UserString("ERROR_CHECKSUM_MISMATCH"), true);
     return discard_event();
 }
 
@@ -570,7 +587,35 @@ boost::statechart::result MPLobby::react(const ChatHistory& msg) {
 
     const auto& wnd = Client().GetClientUI().GetMultiPlayerLobbyWnd();
     for (const auto& elem : chat_history)
-        wnd->ChatMessage(elem.m_text, elem.m_player_name, elem.m_text_color, elem.m_timestamp);
+        wnd->ChatMessage(elem.m_text,
+                         elem.m_player_name,
+                         elem.m_player_name.empty() ? Client().GetClientUI().TextColor() : elem.m_text_color,
+                         elem.m_timestamp);
+
+    return discard_event();
+}
+
+boost::statechart::result MPLobby::react(const PlayerStatus& msg) {
+    TraceLogger(FSM) << "(HumanClientFSM) PlayerStatus.";
+    // ToDo: show it in player ready status
+
+    return discard_event();
+}
+
+boost::statechart::result MPLobby::react(const SaveGameComplete& msg) {
+    TraceLogger(FSM) << "(HumanClientFSM) SaveGameComplete.";
+    // ignore it
+
+    return discard_event();
+}
+
+boost::statechart::result MPLobby::react(const TurnProgress& msg) {
+    TraceLogger(FSM) << "(HumanClientFSM) TurnProgress.";
+
+    Message::TurnProgressPhase phase_id;
+    ExtractTurnProgressMessageData(msg.m_message, phase_id);
+    const auto& wnd = Client().GetClientUI().GetMultiPlayerLobbyWnd();
+    wnd->TurnPhaseUpdate(phase_id);
 
     return discard_event();
 }
@@ -586,7 +631,6 @@ PlayingGame::PlayingGame(my_context ctx) :
 
     Client().Register(Client().GetClientUI().GetMapWnd());
     Client().GetClientUI().GetMapWnd()->Show();
-    Client().GetClientUI().GetMessageWnd()->Clear();
 }
 
 PlayingGame::~PlayingGame() {
@@ -619,19 +663,25 @@ boost::statechart::result PlayingGame::react(const PlayerChat& msg) {
     std::string text;
     int sending_player_id;
     boost::posix_time::ptime timestamp;
-    ExtractServerPlayerChatMessageData(msg.m_message, sending_player_id, timestamp, text);
+    bool pm;
+    ExtractServerPlayerChatMessageData(msg.m_message, sending_player_id, timestamp, text, pm);
 
     std::string player_name{UserString("PLAYER") + " " + std::to_string(sending_player_id)};
     GG::Clr text_color{Client().GetClientUI().TextColor()};
-    auto players = Client().Players();
-    auto player_it = players.find(sending_player_id);
-    if (player_it != players.end()) {
-        player_name = player_it->second.name;
-        if (auto empire = GetEmpire(player_it->second.empire_id))
-            text_color = empire->Color();
+    if (sending_player_id != Networking::INVALID_PLAYER_ID) {
+        auto players = Client().Players();
+        auto player_it = players.find(sending_player_id);
+        if (player_it != players.end()) {
+            player_name = player_it->second.name;
+            if (auto empire = GetEmpire(player_it->second.empire_id))
+                text_color = empire->Color();
+        }
+    } else {
+        // It's a server message. Don't set player name.
+        player_name = "";
     }
 
-    Client().GetClientUI().GetMessageWnd()->HandlePlayerChatMessage(text, player_name, text_color, timestamp, Client().PlayerID());
+    Client().GetClientUI().GetMessageWnd()->HandlePlayerChatMessage(text, player_name, text_color, timestamp, Client().PlayerID(), pm);
 
     return discard_event();
 }
@@ -648,13 +698,11 @@ boost::statechart::result PlayingGame::react(const Disconnection& d) {
 
 boost::statechart::result PlayingGame::react(const PlayerStatus& msg) {
     TraceLogger(FSM) << "(HumanClientFSM) PlayingGame.PlayerStatus";
-    int about_player_id;
     Message::PlayerStatus status;
-    ExtractPlayerStatusMessageData(msg.m_message, about_player_id, status);
+    int about_empire_id;
+    ExtractPlayerStatusMessageData(msg.m_message, status, about_empire_id);
 
-    Client().SetPlayerStatus(about_player_id, status);
-    Client().GetClientUI().GetMessageWnd()->HandlePlayerStatusUpdate(status, about_player_id);
-    Client().GetClientUI().GetPlayerListWnd()->HandlePlayerStatusUpdate(status, about_player_id);
+    Client().SetEmpireStatus(about_empire_id, status);
     // TODO: tell the map wnd or something else as well?
 
     return discard_event();
@@ -766,6 +814,25 @@ boost::statechart::result PlayingGame::react(const LobbyUpdate& msg) {
     return transit<MPLobby>();
 }
 
+boost::statechart::result PlayingGame::react(const TurnTimeout& msg) {
+    DebugLogger(FSM) << "(PlayerFSM) PlayingGame::TurnTimeout message received: " << msg.m_message.Text();
+    const std::string& text = msg.m_message.Text();
+    int timeout_remain = 0;
+    try {
+        timeout_remain = boost::lexical_cast<int>(text);
+    } catch (const boost::bad_lexical_cast& ex) {
+        ErrorLogger(FSM) << "PlayingGame::react(const TurnTimeout& msg) could not convert \"" << text << "\" to timeout";
+    }
+    Client().GetClientUI().GetMapWnd()->ResetTimeoutClock(timeout_remain);
+    return discard_event();
+}
+
+boost::statechart::result PlayingGame::react(const PlayerInfoMsg& msg) {
+    DebugLogger(FSM) << "(PlayerFSM) PlayingGame::PlayerInfoMsg message received: " << msg.m_message.Text();
+    ExtractPlayerInfoMessageData(msg.m_message, Client().Players());
+    Client().GetClientUI().GetPlayerListWnd()->Refresh();
+    return discard_event();
+}
 
 ////////////////////////////////////////////////////////////
 // WaitingForGameStart
@@ -775,7 +842,6 @@ WaitingForGameStart::WaitingForGameStart(my_context ctx) :
 {
     TraceLogger(FSM) << "(HumanClientFSM) WaitingForGameStart";
 
-    Client().Register(Client().GetClientUI().GetMessageWnd());
     Client().Register(Client().GetClientUI().GetPlayerListWnd());
 
     Client().GetClientUI().GetMapWnd()->EnableOrderIssuing(false);
@@ -796,15 +862,18 @@ boost::statechart::result WaitingForGameStart::react(const GameStart& msg) {
     bool single_player_game = false;
     int empire_id = ALL_EMPIRES;
     int current_turn = INVALID_GAME_TURN;
-    Client().PlayerStatus().clear();
     Client().Orders().Reset();
 
-    ExtractGameStartMessageData(msg.m_message,       single_player_game,             empire_id,
-                                current_turn,        Empires(),                      GetUniverse(),
-                                GetSpeciesManager(), GetCombatLogManager(),          GetSupplyManager(),
-                                Client().Players(),  Client().Orders(),              loaded_game_data,
-                                ui_data_available,   ui_data,                        save_state_string_available,
-                                save_state_string,   Client().GetGalaxySetupData());
+    try {
+        ExtractGameStartMessageData(msg.m_message,       single_player_game,             empire_id,
+                                    current_turn,        Empires(),                      GetUniverse(),
+                                    GetSpeciesManager(), GetCombatLogManager(),          GetSupplyManager(),
+                                    Client().Players(),  Client().Orders(),              loaded_game_data,
+                                    ui_data_available,   ui_data,                        save_state_string_available,
+                                    save_state_string,   Client().GetGalaxySetupData());
+    } catch (...) {
+        return transit<IntroMenu>();
+    }
 
     DebugLogger(FSM) << "Extracted GameStart message for turn: " << current_turn << " with empire: " << empire_id;
 
@@ -817,13 +886,20 @@ boost::statechart::result WaitingForGameStart::react(const GameStart& msg) {
     bool is_new_game = !(loaded_game_data && ui_data_available);
     Client().StartGame(is_new_game);
 
+    TraceLogger(FSM) << "Restoring UI data from save data...";
+
     if (!is_new_game)
         Client().GetClientUI().RestoreFromSaveData(ui_data);
 
+    TraceLogger(FSM) << "UI data from save data restored";
+
     // if I am the host on the first turn, do an autosave.
     if (is_new_game && Client().Networking().PlayerIsHost(Client().PlayerID()))
         Client().Autosave();
 
+    Client().GetClientUI().GetPlayerListWnd()->Refresh();
+    Client().GetClientUI().GetMapWnd()->ResetTimeoutClock(0);
+
     return transit<PlayingTurn>();
 }
 
@@ -841,14 +917,6 @@ WaitingForTurnData::WaitingForTurnData(my_context ctx) :
 WaitingForTurnData::~WaitingForTurnData()
 { TraceLogger(FSM) << "(HumanClientFSM) ~WaitingForTurnData"; }
 
-boost::statechart::result WaitingForTurnData::react(const SaveGameDataRequest& msg) {
-    TraceLogger(FSM) << "(HumanClientFSM) WaitingForTurnData.SaveGameDataRequest";
-    DebugLogger(FSM) << "Sending Save Game Data to Server";
-    Client().GetClientUI().GetMessageWnd()->HandleGameStatusUpdate(UserString("SERVER_SAVE_INITIATE_ACK") + "\n");
-    Client().HandleSaveGameDataRequest();
-    return discard_event();
-}
-
 boost::statechart::result WaitingForTurnData::react(const SaveGameComplete& msg) {
     TraceLogger(FSM) << "(HumanClientFSM) WaitingForTurnData.SaveGameComplete";
 
@@ -868,6 +936,7 @@ boost::statechart::result WaitingForTurnData::react(const TurnUpdate& msg) {
     TraceLogger(FSM) << "(HumanClientFSM) PlayingGame.TurnUpdate";
 
     int current_turn = INVALID_GAME_TURN;
+    Client().Orders().Reset();
 
     try {
         ExtractTurnUpdateMessageData(msg.m_message,           Client().EmpireID(),    current_turn,
@@ -888,6 +957,16 @@ boost::statechart::result WaitingForTurnData::react(const TurnUpdate& msg) {
 
     Client().HandleTurnUpdate();
 
+    Client().GetClientUI().GetPlayerListWnd()->Refresh();
+    Client().GetClientUI().GetMapWnd()->ResetTimeoutClock(0);
+
+    return transit<PlayingTurn>();
+}
+
+boost::statechart::result WaitingForTurnData::react(const TurnRevoked& msg) {
+    TraceLogger(FSM) << "(HumanClientFSM) PlayingGame.TurnRevoked";
+
+    // Allow player to change orders
     return transit<PlayingTurn>();
 }
 
@@ -911,9 +990,6 @@ PlayingTurn::PlayingTurn(my_context ctx) :
     // TODO: reselect last fleet if stored in save game ui data?
     Client().GetClientUI().GetMessageWnd()->HandleGameStatusUpdate(
         boost::io::str(FlexibleFormat(UserString("TURN_BEGIN")) % CurrentTurn()) + "\n");
-    Client().GetClientUI().GetMessageWnd()->HandlePlayerStatusUpdate(Message::PLAYING_TURN, Client().PlayerID());
-    Client().GetClientUI().GetPlayerListWnd()->Refresh();
-    Client().GetClientUI().GetPlayerListWnd()->HandlePlayerStatusUpdate(Message::PLAYING_TURN, Client().PlayerID());
 
     if (Client().GetApp()->GetClientType() != Networking::CLIENT_TYPE_HUMAN_OBSERVER)
         Client().GetClientUI().GetMapWnd()->EnableOrderIssuing(true);
@@ -948,14 +1024,6 @@ PlayingTurn::PlayingTurn(my_context ctx) :
 PlayingTurn::~PlayingTurn()
 { TraceLogger(FSM) << "(HumanClientFSM) ~PlayingTurn"; }
 
-boost::statechart::result PlayingTurn::react(const SaveGameDataRequest& msg) {
-    TraceLogger(FSM) << "(HumanClientFSM) PlayingTurn.SaveGameDataRequest";
-    DebugLogger(FSM) << "Sending Save Game Data to Server";
-    Client().GetClientUI().GetMessageWnd()->HandleGameStatusUpdate(UserString("SERVER_SAVE_INITIATE_ACK") + "\n");
-    Client().HandleSaveGameDataRequest();
-    return discard_event();
-}
-
 boost::statechart::result PlayingTurn::react(const SaveGameComplete& msg) {
     TraceLogger(FSM) << "(HumanClientFSM) PlayingTurn.SaveGameComplete";
 
@@ -981,7 +1049,9 @@ boost::statechart::result PlayingTurn::react(const SaveGameComplete& msg) {
 }
 
 boost::statechart::result PlayingTurn::react(const AdvanceTurn& d) {
-    Client().StartTurn();
+    SaveGameUIData ui_data;
+    Client().GetClientUI().GetSaveGameUIData(ui_data);
+    Client().StartTurn(ui_data);
     return discard_event();
 }
 
@@ -1004,33 +1074,19 @@ boost::statechart::result PlayingTurn::react(const TurnEnded& msg) {
 
 boost::statechart::result PlayingTurn::react(const PlayerStatus& msg) {
     TraceLogger(FSM) << "(HumanClientFSM) PlayingTurn.PlayerStatus";
-    int about_player_id;
     Message::PlayerStatus status;
-    ExtractPlayerStatusMessageData(msg.m_message, about_player_id, status);
+    int about_empire_id;
+    ExtractPlayerStatusMessageData(msg.m_message, status, about_empire_id);
 
-    Client().SetPlayerStatus(about_player_id, status);
-    Client().GetClientUI().GetMessageWnd()->HandlePlayerStatusUpdate(status, about_player_id);
-    Client().GetClientUI().GetPlayerListWnd()->HandlePlayerStatusUpdate(status, about_player_id);
+    Client().SetEmpireStatus(about_empire_id, status);
 
     if (Client().GetApp()->GetClientType() == Networking::CLIENT_TYPE_HUMAN_MODERATOR &&
         Client().GetClientUI().GetMapWnd()->AutoEndTurnEnabled())
     {
-        // check status of all non-mod non-obs players: are they all done their turns?
+        // check status of all empires: are they all done their turns?
         bool all_participants_waiting = true;
-        const auto& player_status = Client().PlayerStatus();
-        for (auto& entry : Client().Players()) {
-            int player_id = entry.first;
-
-            if (entry.second.client_type != Networking::CLIENT_TYPE_AI_PLAYER &&
-                entry.second.client_type != Networking::CLIENT_TYPE_HUMAN_PLAYER)
-            { continue; }   // only active participants matter...
-
-            auto status_it = player_status.find(player_id);
-            if (status_it == player_status.end()) {
-                all_participants_waiting = false;
-                break;
-            }
-            if (status_it->second != Message::WAITING) {
+        for (auto& entry : Client().Empires()) {
+            if (!entry.second->Ready()) {
                 all_participants_waiting = false;
                 break;
             }
