@@ -37,7 +37,7 @@ unroll and hide the stack trace, print a message and still crash anyways. */
 // installed version of FO is run with the command-line flag added in as
 // appropriate.
 #ifdef FREEORION_WIN32
-const bool  STORE_FULLSCREEN_FLAG = false;
+const bool STORE_FULLSCREEN_FLAG = false;
 // Windows keeps good care of the resolution state itself,
 // so there is no reason to default to not touching it.
 const bool FAKE_MODE_CHANGE_FLAG = false;
@@ -130,13 +130,10 @@ int mainConfigOptionsSetup(const std::vector<std::string>& args) {
         GetOptionsDB().Add<bool>("video.fullscreen.fake.enabled",   UserStringNop("OPTIONS_DB_FAKE_MODE_CHANGE"),       FAKE_MODE_CHANGE_FLAG);
         GetOptionsDB().Add<int>("video.monitor.id",                 UserStringNop("OPTIONS_DB_FULLSCREEN_MONITOR_ID"),  0,
                                 RangedValidator<int>(0, 5));
-        GetOptionsDB().AddFlag('q', "quickstart",                   UserStringNop("OPTIONS_DB_QUICKSTART"),             false);
         GetOptionsDB().AddFlag("continue",                          UserStringNop("OPTIONS_DB_CONTINUE"),               false);
         GetOptionsDB().AddFlag("auto-quit",                         UserStringNop("OPTIONS_DB_AUTO_QUIT"),              false);
         GetOptionsDB().Add<int>("auto-advance-n-turns",             UserStringNop("OPTIONS_DB_AUTO_N_TURNS"),           0,
                                 RangedValidator<int>(0, 400),                                                           false);
-        GetOptionsDB().Add<std::string>("load",                     UserStringNop("OPTIONS_DB_LOAD"),                   "",
-                                        Validator<std::string>(),                                                       false);
         GetOptionsDB().Add("audio.music.enabled",                   UserStringNop("OPTIONS_DB_MUSIC_ON"),               true);
         GetOptionsDB().Add("audio.effects.enabled",                 UserStringNop("OPTIONS_DB_SOUND_ON"),               true);
         GetOptionsDB().Add<std::string>("version.string",           UserStringNop("OPTIONS_DB_VERSION_STRING"),         FreeOrionVersionString(),
@@ -216,8 +213,8 @@ int mainConfigOptionsSetup(const std::vector<std::string>& args) {
         // did the player request generation of config.xml, saving the default (or current) options to disk?
         if (GetOptionsDB().Get<bool>("generate-config-xml")) {
             try {
-                GetOptionsDB().Commit();
-            } catch (const std::exception&) {
+                GetOptionsDB().Commit(false);
+            } catch (...) {
                 std::cerr << UserString("UNABLE_TO_WRITE_CONFIG_XML") << std::endl;
             }
         }
@@ -257,9 +254,9 @@ int mainSetupAndRun() {
         bool fullscreen = GetOptionsDB().Get<bool>("video.fullscreen.enabled");
         bool fake_mode_change = GetOptionsDB().Get<bool>("video.fullscreen.fake.enabled");
 
-        std::pair<int, int> width_height = HumanClientApp::GetWindowWidthHeight();
+        auto width_height = HumanClientApp::GetWindowWidthHeight();
         int width(width_height.first), height(width_height.second);
-        std::pair<int, int> left_top = HumanClientApp::GetWindowLeftTop();
+        auto left_top = HumanClientApp::GetWindowLeftTop();
         int left(left_top.first), top(left_top.second);
 
 #ifdef FREEORION_WIN32
@@ -300,8 +297,7 @@ int mainSetupAndRun() {
         }
 
         // run rendering loop
-        app();  // calls GUI::operator() which calls SDLGUI::Run() which starts rendering loop
-
+        app.Run();
 #ifndef FREEORION_CHMAIN_KEEP_STACKTRACE
     } catch (const std::invalid_argument& e) {
         ErrorLogger() << "main() caught exception(std::invalid_argument): " << e.what();
@@ -311,7 +307,7 @@ int mainSetupAndRun() {
         ErrorLogger() << "main() caught exception(std::runtime_error): " << e.what();
         std::cerr << "main() caught exception(std::runtime_error): " << e.what() << std::endl;
         return 1;
-    } catch (const  boost::io::format_error& e) {
+    } catch (const boost::io::format_error& e) {
         ErrorLogger() << "main() caught exception(boost::io::format_error): " << e.what();
         std::cerr << "main() caught exception(boost::io::format_error): " << e.what() << std::endl;
         return 1;
