@@ -8,7 +8,7 @@ from galaxy import DisjointSets
 from util import MapGenerationError, report_error
 
 
-class StarlaneAlteringMonsters(object):
+class StarlaneAlteringMonsters:
     def __init__(self, systems):
         self.systems = systems
         self.placed = set()
@@ -80,7 +80,7 @@ def populate_monster_fleet(fleet_plan, system):
         if fo.create_monster(design, monster_fleet) == fo.invalid_object():
             raise MapGenerationError("Python generate_monsters: unable to create monster %s" % design)
 
-    print "Spawn", fleet_plan.name(), "at", fo.get_name(system)
+    print("Spawn", fleet_plan.name(), "at", fo.get_name(system))
 
 
 def generate_monsters(monster_freq, systems):
@@ -94,7 +94,7 @@ def generate_monsters(monster_freq, systems):
     # a value of 0 means no monsters, in this case return immediately
     if basic_chance <= 0:
         return
-    print "Default monster spawn chance:", basic_chance
+    print("Default monster spawn chance:", basic_chance)
     expectation_tally = 0.0
     actual_tally = 0
 
@@ -127,19 +127,19 @@ def generate_monsters(monster_freq, systems):
     # @content_tag{CAN_ALTER_STARLANES} universe_generator special handling
     # for fleets containing a hull design with this tag.
     fleet_can_alter_starlanes = {fp for fp in fleet_plans
-                                 if any([universe.getGenericShipDesign(design).hull_type.hasTag("CAN_ALTER_STARLANES")
+                                 if any([universe.getGenericShipDesign(design).ship_hull.hasTag("CAN_ALTER_STARLANES")
                                          for design in fp.ship_designs()])}
 
     # dump a list of all monster fleets meeting these conditions and their properties to the log
-    print "Monster fleets available for generation at game start:"
+    print("Monster fleets available for generation at game start:")
     fp_location_cache = {}
     for fleet_plan in fleet_plans:
-        print "...", fleet_plan.name(), ": spawn rate", fleet_plan.spawn_rate(),
-        print "/ spawn limit", fleet_plan.spawn_limit(),
-        print "/ effective chance", basic_chance * fleet_plan.spawn_rate(),
+        print("...", fleet_plan.name(), ": spawn rate", fleet_plan.spawn_rate(), end=' ')
+        print("/ spawn limit", fleet_plan.spawn_limit(), end=' ')
+        print("/ effective chance", basic_chance * fleet_plan.spawn_rate(), end=' ')
         fp_location_cache[fleet_plan] = set(fleet_plan.locations(systems))
-        print ("/ can be spawned at", len(fp_location_cache[fleet_plan]),
-               "of", len(systems), "systems")
+        print("/ can be spawned at", len(fp_location_cache[fleet_plan]),
+              "of", len(systems), "systems")
         if fleet_plan.name() in nest_name_map.values():
             universe_statistics.tracked_monsters_chance[fleet_plan.name()] = basic_chance * fleet_plan.spawn_rate()
 
@@ -202,14 +202,14 @@ def generate_monsters(monster_freq, systems):
             report_error(str(err))
             continue
 
-    print "Actual # monster fleets placed: %d; Total Placement Expectation: %.1f" % (actual_tally, expectation_tally)
+    print("Actual # monster fleets placed: %d; Total Placement Expectation: %.1f" % (actual_tally, expectation_tally))
     # finally, compile some statistics to be dumped to the log later
     universe_statistics.monsters_summary = [
-        (fp.name(), fp.spawn_limit() - counter) for fp, counter in spawn_limits.iteritems()
+        (fp.name(), fp.spawn_limit() - counter) for fp, counter in spawn_limits.items()
     ]
     universe_statistics.tracked_monsters_tries.update(tracked_plan_tries)
     universe_statistics.tracked_monsters_summary.update(tracked_plan_counts)
     universe_statistics.tracked_monsters_location_summary.update(
-        (fp.name(), count) for fp, count in tracked_plan_valid_locations.iteritems())
+        (fp.name(), count) for fp, count in tracked_plan_valid_locations.items())
     universe_statistics.tracked_nest_location_summary.update(
         (nest_name_map[nest], count) for nest, count in tracked_nest_valid_locations.items())
