@@ -10,6 +10,7 @@
 #include "../universe/Species.h"
 #include "../universe/Universe.h"
 #include "../util/OptionsDB.h"
+#include "../util/OrderSet.h"
 #include "../util/Serialize.h"
 #include "../util/ScopedTimer.h"
 #include "../util/i18n.h"
@@ -22,7 +23,6 @@
 #include <boost/serialization/set.hpp>
 #include <boost/serialization/vector.hpp>
 #include <boost/serialization/weak_ptr.hpp>
-#include <boost/timer.hpp>
 #include <boost/date_time/posix_time/time_serialize.hpp>
 #include <boost/uuid/uuid_serialize.hpp>
 #include <boost/uuid/uuid_io.hpp>
@@ -179,7 +179,7 @@ Message GameStartMessage(bool single_player_game, int empire_id,
                          const Universe& universe, const SpeciesManager& species,
                          CombatLogManager& combat_logs, const SupplyManager& supply,
                          const std::map<int, PlayerInfo>& players,
-                         const GalaxySetupData& galaxy_setup_data,
+                         GalaxySetupData galaxy_setup_data,
                          bool use_binary_serialization)
 {
     std::ostringstream os;
@@ -198,6 +198,7 @@ Message GameStartMessage(bool single_player_game, int empire_id,
             bool loaded_game_data = false;
             oa << BOOST_SERIALIZATION_NVP(players)
                << BOOST_SERIALIZATION_NVP(loaded_game_data);
+            galaxy_setup_data.m_encoding_empire = empire_id;
             oa << BOOST_SERIALIZATION_NVP(galaxy_setup_data);
         } else {
             freeorion_xml_oarchive oa(os);
@@ -213,6 +214,7 @@ Message GameStartMessage(bool single_player_game, int empire_id,
             bool loaded_game_data = false;
             oa << BOOST_SERIALIZATION_NVP(players)
                << BOOST_SERIALIZATION_NVP(loaded_game_data);
+            galaxy_setup_data.m_encoding_empire = empire_id;
             oa << BOOST_SERIALIZATION_NVP(galaxy_setup_data);
         }
     }
@@ -225,7 +227,7 @@ Message GameStartMessage(bool single_player_game, int empire_id,
                          CombatLogManager& combat_logs, const SupplyManager& supply,
                          const std::map<int, PlayerInfo>& players,
                          const OrderSet& orders, const SaveGameUIData* ui_data,
-                         const GalaxySetupData& galaxy_setup_data,
+                         GalaxySetupData galaxy_setup_data,
                          bool use_binary_serialization)
 {
     std::ostringstream os;
@@ -251,6 +253,7 @@ Message GameStartMessage(bool single_player_game, int empire_id,
                 oa << boost::serialization::make_nvp("ui_data", *ui_data);
             bool save_state_string_available = false;
             oa << BOOST_SERIALIZATION_NVP(save_state_string_available);
+            galaxy_setup_data.m_encoding_empire = empire_id;
             oa << BOOST_SERIALIZATION_NVP(galaxy_setup_data);
         } else {
             freeorion_xml_oarchive oa(os);
@@ -269,10 +272,18 @@ Message GameStartMessage(bool single_player_game, int empire_id,
             Serialize(oa, orders);
             bool ui_data_available = (ui_data != nullptr);
             oa << BOOST_SERIALIZATION_NVP(ui_data_available);
-            if (ui_data_available)
-                oa << boost::serialization::make_nvp("ui_data", *ui_data);
+            if (ui_data_available) {
+                if (ui_data) {
+                    oa << boost::serialization::make_nvp("ui_data", *ui_data);
+                } else {
+                    ErrorLogger() << "GameStartMessage expected UI data but it was nullptr";
+                    SaveGameUIData temp_UI_data;
+                    oa << boost::serialization::make_nvp("ui_data", temp_UI_data);
+                }
+            }
             bool save_state_string_available = false;
             oa << BOOST_SERIALIZATION_NVP(save_state_string_available);
+            galaxy_setup_data.m_encoding_empire = empire_id;
             oa << BOOST_SERIALIZATION_NVP(galaxy_setup_data);
         }
     }
@@ -285,7 +296,7 @@ Message GameStartMessage(bool single_player_game, int empire_id,
                          CombatLogManager& combat_logs, const SupplyManager& supply,
                          const std::map<int, PlayerInfo>& players,
                          const OrderSet& orders, const std::string* save_state_string,
-                         const GalaxySetupData& galaxy_setup_data,
+                         GalaxySetupData galaxy_setup_data,
                          bool use_binary_serialization)
 {
     std::ostringstream os;
@@ -311,6 +322,7 @@ Message GameStartMessage(bool single_player_game, int empire_id,
             oa << BOOST_SERIALIZATION_NVP(save_state_string_available);
             if (save_state_string_available)
                 oa << boost::serialization::make_nvp("save_state_string", *save_state_string);
+            galaxy_setup_data.m_encoding_empire = empire_id;
             oa << BOOST_SERIALIZATION_NVP(galaxy_setup_data);
         } else {
             freeorion_xml_oarchive oa(os);
@@ -331,8 +343,16 @@ Message GameStartMessage(bool single_player_game, int empire_id,
             oa << BOOST_SERIALIZATION_NVP(ui_data_available);
             bool save_state_string_available = (save_state_string != nullptr);
             oa << BOOST_SERIALIZATION_NVP(save_state_string_available);
-            if (save_state_string_available)
-                oa << boost::serialization::make_nvp("save_state_string", *save_state_string);
+            if (save_state_string_available) {
+                if (save_state_string) {
+                    oa << boost::serialization::make_nvp("save_state_string", *save_state_string);
+                } else {
+                    ErrorLogger() << "GameStartMessage expectes save_state_string but it was nullptr";
+                    std::string temp_sss;
+                    oa << boost::serialization::make_nvp("save_state_string", temp_sss);
+                }
+            }
+            galaxy_setup_data.m_encoding_empire = empire_id;
             oa << BOOST_SERIALIZATION_NVP(galaxy_setup_data);
         }
     }
@@ -356,15 +376,47 @@ Message JoinAckMessage(int player_id, boost::uuids::uuid cookie)
     return Message(Message::JOIN_GAME, os.str());
 }
 
-Message TurnOrdersMessage(const OrderSet& orders) {
+Message TurnOrdersMessage(const OrderSet& orders, const SaveGameUIData& ui_data) {
     std::ostringstream os;
     {
         freeorion_xml_oarchive oa(os);
         Serialize(oa, orders);
+        bool ui_data_available = true;
+        bool save_state_string_available = false;
+        oa << BOOST_SERIALIZATION_NVP(ui_data_available)
+           << BOOST_SERIALIZATION_NVP(ui_data)
+           << BOOST_SERIALIZATION_NVP(save_state_string_available);
     }
     return Message(Message::TURN_ORDERS, os.str());
 }
 
+Message TurnOrdersMessage(const OrderSet& orders, const std::string& save_state_string) {
+    std::ostringstream os;
+    {
+        freeorion_xml_oarchive oa(os);
+        Serialize(oa, orders);
+        bool ui_data_available = false;
+        bool save_state_string_available = true;
+        oa << BOOST_SERIALIZATION_NVP(ui_data_available)
+           << BOOST_SERIALIZATION_NVP(save_state_string_available)
+           << BOOST_SERIALIZATION_NVP(save_state_string);
+    }
+    return Message(Message::TURN_ORDERS, os.str());
+}
+
+Message TurnPartialOrdersMessage(const std::pair<OrderSet, std::set<int>>& orders_updates) {
+    std::ostringstream os;
+    {
+        freeorion_xml_oarchive oa(os);
+        Serialize(oa, orders_updates.first);
+        oa << boost::serialization::make_nvp("deleted", orders_updates.second);
+    }
+    return Message(Message::TURN_PARTIAL_ORDERS, os.str());
+}
+
+Message TurnTimeoutMessage(int timeout_remaining)
+{ return Message(Message::TURN_TIMEOUT, std::to_string(timeout_remaining)); }
+
 Message TurnProgressMessage(Message::TurnProgressPhase phase_id) {
     std::ostringstream os;
     {
@@ -374,12 +426,14 @@ Message TurnProgressMessage(Message::TurnProgressPhase phase_id) {
     return Message(Message::TURN_PROGRESS, os.str());
 }
 
-Message PlayerStatusMessage(int about_player_id, Message::PlayerStatus player_status) {
+Message PlayerStatusMessage(Message::PlayerStatus player_status,
+                            int about_empire_id)
+{
     std::ostringstream os;
     {
         freeorion_xml_oarchive oa(os);
-        oa << BOOST_SERIALIZATION_NVP(about_player_id)
-           << BOOST_SERIALIZATION_NVP(player_status);
+        oa << BOOST_SERIALIZATION_NVP(player_status)
+           << BOOST_SERIALIZATION_NVP(about_empire_id);
     }
     return Message(Message::PLAYER_STATUS, os.str());
 }
@@ -435,54 +489,9 @@ Message TurnPartialUpdateMessage(int empire_id, const Universe& universe,
     return Message(Message::TURN_PARTIAL_UPDATE, os.str());
 }
 
-Message ClientSaveDataMessage(const OrderSet& orders, const SaveGameUIData& ui_data) {
-    std::ostringstream os;
-    {
-        freeorion_xml_oarchive oa(os);
-        Serialize(oa, orders);
-        bool ui_data_available = true;
-        bool save_state_string_available = false;
-        oa << BOOST_SERIALIZATION_NVP(ui_data_available)
-           << BOOST_SERIALIZATION_NVP(ui_data)
-           << BOOST_SERIALIZATION_NVP(save_state_string_available);
-    }
-    return Message(Message::CLIENT_SAVE_DATA, os.str());
-}
-
-Message ClientSaveDataMessage(const OrderSet& orders, const std::string& save_state_string) {
-    std::ostringstream os;
-    {
-        freeorion_xml_oarchive oa(os);
-        Serialize(oa, orders);
-        bool ui_data_available = false;
-        bool save_state_string_available = true;
-        oa << BOOST_SERIALIZATION_NVP(ui_data_available)
-           << BOOST_SERIALIZATION_NVP(save_state_string_available)
-           << BOOST_SERIALIZATION_NVP(save_state_string);
-}
-    return Message(Message::CLIENT_SAVE_DATA, os.str());
-}
-
-Message ClientSaveDataMessage(const OrderSet& orders) {
-    std::ostringstream os;
-    {
-        freeorion_xml_oarchive oa(os);
-        Serialize(oa, orders);
-        bool ui_data_available = false;
-        bool save_state_string_available = false;
-        oa << BOOST_SERIALIZATION_NVP(ui_data_available)
-           << BOOST_SERIALIZATION_NVP(save_state_string_available);
-    }
-    return Message(Message::CLIENT_SAVE_DATA, os.str());
-}
-
 Message HostSaveGameInitiateMessage(const std::string& filename)
 { return Message(Message::SAVE_GAME_INITIATE, filename); }
 
-Message ServerSaveGameDataRequestMessage() {
-    return Message(Message::SAVE_GAME_DATA_REQUEST, DUMMY_EMPTY_MESSAGE);
-}
-
 Message ServerSaveGameCompleteMessage(const std::string& save_filename, int bytes_written) {
     std::ostringstream os;
     {
@@ -564,12 +573,24 @@ Message RequestCombatLogsMessage(const std::vector<int>& ids) {
     return Message(Message::REQUEST_COMBAT_LOGS, os.str());
 }
 
-Message DispatchCombatLogsMessage(const std::vector<std::pair<int, const CombatLog>>& logs) {
+Message DispatchCombatLogsMessage(const std::vector<std::pair<int, const CombatLog>>& logs,
+                                  bool use_binary_serialization)
+{
     std::ostringstream os;
     {
-        freeorion_xml_oarchive oa(os);
-        oa << BOOST_SERIALIZATION_NVP(logs);
+        try {
+            if (use_binary_serialization) {
+                freeorion_bin_oarchive oa(os);
+                oa << BOOST_SERIALIZATION_NVP(logs);
+            } else {
+                freeorion_xml_oarchive oa(os);
+                oa << BOOST_SERIALIZATION_NVP(logs);
+            }
+        } catch (const std::exception& e) {
+            ErrorLogger() << "Caught exception serializing combat logs: " << e.what();
+        }
     }
+
     return Message(Message::DISPATCH_COMBAT_LOGS, os.str());
 }
 
@@ -625,26 +646,27 @@ Message ChatHistoryMessage(const std::vector<std::reference_wrapper<const ChatHi
     return Message(Message::CHAT_HISTORY, os.str());
 }
 
-Message PlayerChatMessage(const std::string& data, int receiver) {
+Message PlayerChatMessage(const std::string& data, std::set<int> recipients, bool pm) {
     std::ostringstream os;
     {
         freeorion_xml_oarchive oa(os);
-        oa << BOOST_SERIALIZATION_NVP(receiver)
-           << BOOST_SERIALIZATION_NVP(data);
+        oa << BOOST_SERIALIZATION_NVP(recipients)
+           << BOOST_SERIALIZATION_NVP(data)
+           << BOOST_SERIALIZATION_NVP(pm);
     }
     return Message(Message::PLAYER_CHAT, os.str());
 }
 
-Message ServerPlayerChatMessage(int sender,
-                                const boost::posix_time::ptime& timestamp,
-                                const std::string& data)
+Message ServerPlayerChatMessage(int sender, const boost::posix_time::ptime& timestamp,
+                                const std::string& data, bool pm)
 {
     std::ostringstream os;
     {
         freeorion_xml_oarchive oa(os);
         oa << BOOST_SERIALIZATION_NVP(sender)
            << BOOST_SERIALIZATION_NVP(timestamp)
-           << BOOST_SERIALIZATION_NVP(data);
+           << BOOST_SERIALIZATION_NVP(data)
+           << BOOST_SERIALIZATION_NVP(pm);
     }
     return Message(Message::PLAYER_CHAT, os.str());
 }
@@ -689,6 +711,18 @@ Message SetAuthorizationRolesMessage(const Networking::AuthRoles& roles)
 Message EliminateSelfMessage()
 { return Message(Message::ELIMINATE_SELF, DUMMY_EMPTY_MESSAGE); }
 
+Message UnreadyMessage()
+{ return Message(Message::UNREADY, DUMMY_EMPTY_MESSAGE); }
+
+Message PlayerInfoMessage(const std::map<int, PlayerInfo>& players) {
+    std::ostringstream os;
+    {
+        freeorion_xml_oarchive oa(os);
+        oa << BOOST_SERIALIZATION_NVP(players);
+    }
+    return Message(Message::PLAYER_INFO, os.str());
+}
+
 ////////////////////////////////////////////////
 // Message data extractors
 ////////////////////////////////////////////////
@@ -758,12 +792,13 @@ void ExtractChatHistoryMessage(const Message& msg, std::vector<ChatHistoryEntity
     }
 }
 
-void ExtractPlayerChatMessageData(const Message& msg, int& receiver, std::string& data) {
+void ExtractPlayerChatMessageData(const Message& msg, std::set<int>& recipients, std::string& data, bool& pm) {
     try {
         std::istringstream is(msg.Text());
         freeorion_xml_iarchive ia(is);
-        ia >> BOOST_SERIALIZATION_NVP(receiver)
-           >> BOOST_SERIALIZATION_NVP(data);
+        ia >> BOOST_SERIALIZATION_NVP(recipients)
+           >> BOOST_SERIALIZATION_NVP(data)
+           >> BOOST_SERIALIZATION_NVP(pm);
 
     } catch (const std::exception& err) {
         ErrorLogger() << "ExtractPlayerChatMessageData(const Message& msg, int& receiver, std::string& data) failed! Message:\n"
@@ -774,16 +809,16 @@ void ExtractPlayerChatMessageData(const Message& msg, int& receiver, std::string
 }
 
 void ExtractServerPlayerChatMessageData(const Message& msg,
-                                        int& sender,
-                                        boost::posix_time::ptime& timestamp,
-                                        std::string& data)
+                                        int& sender, boost::posix_time::ptime& timestamp,
+                                        std::string& data, bool& pm)
 {
     try {
         std::istringstream is(msg.Text());
         freeorion_xml_iarchive ia(is);
         ia >> BOOST_SERIALIZATION_NVP(sender)
            >> BOOST_SERIALIZATION_NVP(timestamp)
-           >> BOOST_SERIALIZATION_NVP(data);
+           >> BOOST_SERIALIZATION_NVP(data)
+           >> BOOST_SERIALIZATION_NVP(pm);
     } catch (const std::exception& err) {
         ErrorLogger() << "ExtractServerPlayerChatMessageData(const Message& msg, int& sender, std::string& data) failed! Message:\n"
                       << msg.Text() << "\n"
@@ -812,9 +847,9 @@ void ExtractGameStartMessageData(const Message& msg, bool& single_player_game, i
                    >> BOOST_SERIALIZATION_NVP(current_turn);
                 GetUniverse().EncodingEmpire() = empire_id;
 
-                boost::timer deserialize_timer;
+                ScopedTimer deserialize_timer;
                 ia >> BOOST_SERIALIZATION_NVP(empires);
-                DebugLogger() << "ExtractGameStartMessage empire deserialization time " << (deserialize_timer.elapsed() * 1000.0);
+                DebugLogger() << "ExtractGameStartMessage empire deserialization time " << deserialize_timer.DurationString();
 
                 ia >> BOOST_SERIALIZATION_NVP(species);
                 combat_logs.Clear();    // only needed when loading new game, not when incrementally serializing logs on turn update
@@ -823,7 +858,7 @@ void ExtractGameStartMessageData(const Message& msg, bool& single_player_game, i
 
                 deserialize_timer.restart();
                 Deserialize(ia, universe);
-                DebugLogger() << "ExtractGameStartMessage universe deserialization time " << (deserialize_timer.elapsed() * 1000.0);
+                DebugLogger() << "ExtractGameStartMessage universe deserialization time " << deserialize_timer.DurationString();
 
 
                 ia >> BOOST_SERIALIZATION_NVP(players)
@@ -857,9 +892,10 @@ void ExtractGameStartMessageData(const Message& msg, bool& single_player_game, i
                >> BOOST_SERIALIZATION_NVP(current_turn);
             GetUniverse().EncodingEmpire() = empire_id;
 
-            boost::timer deserialize_timer;
+            ScopedTimer deserialize_timer;
             ia >> BOOST_SERIALIZATION_NVP(empires);
-            DebugLogger() << "ExtractGameStartMessage empire deserialization time " << (deserialize_timer.elapsed() * 1000.0);
+
+            DebugLogger() << "ExtractGameStartMessage empire deserialization time " << deserialize_timer.DurationString();
 
             ia >> BOOST_SERIALIZATION_NVP(species);
             combat_logs.Clear();    // only needed when loading new game, not when incrementally serializing logs on turn update
@@ -868,29 +904,35 @@ void ExtractGameStartMessageData(const Message& msg, bool& single_player_game, i
 
             deserialize_timer.restart();
             Deserialize(ia, universe);
-            DebugLogger() << "ExtractGameStartMessage universe deserialization time " << (deserialize_timer.elapsed() * 1000.0);
+            DebugLogger() << "ExtractGameStartMessage universe deserialization time " << deserialize_timer.DurationString();;
 
 
             ia >> BOOST_SERIALIZATION_NVP(players)
                >> BOOST_SERIALIZATION_NVP(loaded_game_data);
+            TraceLogger() << "ExtractGameStartMessage players and loaded_game_data=" << loaded_game_data << " deserialization time " << deserialize_timer.DurationString();
             if (loaded_game_data) {
                 Deserialize(ia, orders);
+                TraceLogger() << "ExtractGameStartMessage orders deserialization time " << deserialize_timer.DurationString();
                 ia >> BOOST_SERIALIZATION_NVP(ui_data_available);
                 if (ui_data_available)
                     ia >> BOOST_SERIALIZATION_NVP(ui_data);
+                TraceLogger() << "ExtractGameStartMessage UI data " << ui_data_available << " deserialization time " << deserialize_timer.DurationString();
                 ia >> BOOST_SERIALIZATION_NVP(save_state_string_available);
                 if (save_state_string_available)
                     ia >> BOOST_SERIALIZATION_NVP(save_state_string);
+                TraceLogger() << "ExtractGameStartMessage save state " << save_state_string_available << " deserialization time " << deserialize_timer.DurationString();
             } else {
                 ui_data_available = false;
                 save_state_string_available = false;
             }
             ia >> BOOST_SERIALIZATION_NVP(galaxy_setup_data);
+            TraceLogger() << "ExtractGameStartMessage galaxy setup data deserialization time " << deserialize_timer.DurationString();
         }
 
     } catch (const std::exception& err) {
         ErrorLogger() << "ExtractGameStartMessageData(...) failed!  Message probably long, so not outputting to log.\n"
                       << "Error: " << err.what();
+        TraceLogger() << "Message: " << msg.Text();
         throw err;
     }
 }
@@ -935,15 +977,47 @@ void ExtractJoinAckMessageData(const Message& msg, int& player_id,
     }
 }
 
-void ExtractTurnOrdersMessageData(const Message& msg, OrderSet& orders) {
+void ExtractTurnOrdersMessageData(const Message& msg,
+                                  OrderSet& orders,
+                                  bool& ui_data_available,
+                                  SaveGameUIData& ui_data,
+                                  bool& save_state_string_available,
+                                  std::string& save_state_string)
+{
     try {
         std::istringstream is(msg.Text());
         freeorion_xml_iarchive ia(is);
+        DebugLogger() << "deserializing orders";
         Deserialize(ia, orders);
+        DebugLogger() << "checking for ui data";
+        ia >> BOOST_SERIALIZATION_NVP(ui_data_available);
+        if (ui_data_available) {
+            DebugLogger() << "deserializing UI data";
+            ia >> BOOST_SERIALIZATION_NVP(ui_data);
+        }
+        DebugLogger() << "checking for save state string";
+        ia >> BOOST_SERIALIZATION_NVP(save_state_string_available);
+        if (save_state_string_available) {
+            DebugLogger() << "deserializing save state string";
+            ia >> BOOST_SERIALIZATION_NVP(save_state_string);
+        }
 
     } catch (const std::exception& err) {
-        ErrorLogger() << "ExtractTurnOrdersMessageData(const Message& msg, OrderSet& orders) failed!  Message:\n"
-                      << msg.Text() << "\n"
+        ErrorLogger() << "ExtractTurnOrdersMessageData(const Message& msg, ...) failed! Message probably long, so not outputting to log.\n"
+                      << "Error: " << err.what();
+        throw err;
+    }
+}
+
+void ExtractTurnPartialOrdersMessageData(const Message& msg, OrderSet& added, std::set<int>& deleted) {
+    try {
+        std::istringstream is(msg.Text());
+        freeorion_xml_iarchive ia(is);
+        DebugLogger() << "deserializing partial orders";
+        Deserialize(ia, added);
+        ia >> BOOST_SERIALIZATION_NVP(deleted);
+    } catch (const std::exception& err) {
+        ErrorLogger() << "ExtractTurnPartialOrdersMessageData(const Message& msg) failed! Message probably long, so not outputting to log.\n"
                       << "Error: " << err.what();
         throw err;
     }
@@ -1030,35 +1104,6 @@ void ExtractTurnPartialUpdateMessageData(const Message& msg, int empire_id, Univ
     }
 }
 
-void ExtractClientSaveDataMessageData(const Message& msg, OrderSet& orders, bool& ui_data_available,
-                                      SaveGameUIData& ui_data, bool& save_state_string_available,
-                                      std::string& save_state_string)
-{
-    try {
-        std::istringstream is(msg.Text());
-        freeorion_xml_iarchive ia(is);
-        DebugLogger() << "deserializing orders";
-        Deserialize(ia, orders);
-        DebugLogger() << "checking for ui data";
-        ia >> BOOST_SERIALIZATION_NVP(ui_data_available);
-        if (ui_data_available) {
-            DebugLogger() << "deserializing UI data";
-            ia >> BOOST_SERIALIZATION_NVP(ui_data);
-        }
-        DebugLogger() << "checking for save state string";
-        ia >> BOOST_SERIALIZATION_NVP(save_state_string_available);
-        if (save_state_string_available) {
-            DebugLogger() << "deserializing save state string";
-            ia >> BOOST_SERIALIZATION_NVP(save_state_string);
-        }
-
-    } catch (const std::exception& err) {
-        ErrorLogger() << "ExtractClientSaveDataMessageData(...) failed!  Message probably long, so not outputting to log.\n"
-                      << "Error: " << err.what();
-        throw err;
-    }
-}
-
 void ExtractTurnProgressMessageData(const Message& msg, Message::TurnProgressPhase& phase_id) {
     try {
         std::istringstream is(msg.Text());
@@ -1073,15 +1118,17 @@ void ExtractTurnProgressMessageData(const Message& msg, Message::TurnProgressPha
     }
 }
 
-void ExtractPlayerStatusMessageData(const Message& msg, int& about_player_id, Message::PlayerStatus& status) {
+void ExtractPlayerStatusMessageData(const Message& msg,
+                                    Message::PlayerStatus& status,
+                                    int& about_empire_id) {
     try {
         std::istringstream is(msg.Text());
         freeorion_xml_iarchive ia(is);
-        ia >> BOOST_SERIALIZATION_NVP(about_player_id)
-           >> BOOST_SERIALIZATION_NVP(status);
+        ia >> BOOST_SERIALIZATION_NVP(status)
+           >> BOOST_SERIALIZATION_NVP(about_empire_id);
 
     } catch (const std::exception& err) {
-        ErrorLogger() << "ExtractPlayerStatusMessageData(const Message& msg, int& about_player_id, Message::PlayerStatus&) failed!  Message:\n"
+        ErrorLogger() << "ExtractPlayerStatusMessageData(const Message& msg, Message::PlayerStatus&, int& about_empire_id) failed!  Message:\n"
                       << msg.Text() << "\n"
                       << "Error: " << err.what();
         throw err;
@@ -1213,16 +1260,32 @@ FO_COMMON_API void ExtractDispatchCombatLogsMessageData(
     const Message& msg, std::vector<std::pair<int, CombatLog>>& logs)
 {
     try {
-        std::istringstream is(msg.Text());
-        freeorion_xml_iarchive ia(is);
-        ia >> BOOST_SERIALIZATION_NVP(logs);
+        bool try_xml = false;
+        if (std::strncmp(msg.Data(), "<?xml", 5)) {
+            try {
+                // first attempt binary deserialization
+                std::istringstream is(msg.Text());
+                freeorion_bin_iarchive ia(is);
+                ia >> BOOST_SERIALIZATION_NVP(logs);
+            } catch (...) {
+                try_xml = true;
+            }
+        } else {
+            try_xml = true;
+        }
+        if (try_xml) {
+            // try again with more-portable XML deserialization
+            std::istringstream is(msg.Text());
+            freeorion_xml_iarchive ia(is);
+            ia >> BOOST_SERIALIZATION_NVP(logs);
+        }
+
     } catch(const std::exception& err) {
         ErrorLogger() << "ExtractDispatchCombatLogMessageData(const Message& msg, std::vector<std::pair<int, const CombatLog&>>& logs) failed!  Message:\n"
                       << msg.Text() << "\n"
                       << "Error: " << err.what();
         throw err;
     }
-
 }
 
 FO_COMMON_API void ExtractLoggerConfigMessageData(
@@ -1300,3 +1363,15 @@ void ExtractAuthResponseMessageData(const Message& msg, std::string& player_name
 
 void ExtractSetAuthorizationRolesMessage(const Message &msg, Networking::AuthRoles& roles)
 { roles.SetText(msg.Text()); }
+
+void ExtractPlayerInfoMessageData(const Message &msg, std::map<int, PlayerInfo>& players) {
+    try {
+        std::istringstream is(msg.Text());
+        freeorion_xml_iarchive ia(is);
+        ia >> BOOST_SERIALIZATION_NVP(players);
+    } catch(const std::exception& err) {
+        ErrorLogger() << "ExtractPlayerInfo(const Message &msg, std::map<int, PlayerInfo>& players) failed!  Message:\n"
+                      << msg.Text() << "\n"
+                      << "Error: " << err.what();
+    }
+}
