@@ -2,8 +2,8 @@
 
 #include "ValueRefParser.h"
 
-#include "../universe/Condition.h"
-#include "../universe/ValueRef.h"
+#include "../universe/Conditions.h"
+#include "../universe/ValueRefs.h"
 
 #include <boost/spirit/include/phoenix.hpp>
 
@@ -15,10 +15,10 @@ namespace phoenix = boost::phoenix;
 #if DEBUG_CONDITION_PARSERS
 namespace std {
     inline ostream& operator<<(ostream& os, const std::vector<condition_payload>&) { return os; }
-    inline ostream& operator<<(ostream& os, const std::vector<ValueRef::ValueRefBase<std::string>*>&) { return os; }
-    inline ostream& operator<<(ostream& os, const std::vector<ValueRef::ValueRefBase<PlanetSize>*>&) { return os; }
-    inline ostream& operator<<(ostream& os, const std::vector<ValueRef::ValueRefBase<PlanetType>*>&) { return os; }
-    inline ostream& operator<<(ostream& os, const std::vector<ValueRef::ValueRefBase<PlanetEnvironment>*>&) { return os; }
+    inline ostream& operator<<(ostream& os, const std::vector<ValueRef::ValueRef<std::string>*>&) { return os; }
+    inline ostream& operator<<(ostream& os, const std::vector<ValueRef::ValueRef<PlanetSize>*>&) { return os; }
+    inline ostream& operator<<(ostream& os, const std::vector<ValueRef::ValueRef<PlanetType>*>&) { return os; }
+    inline ostream& operator<<(ostream& os, const std::vector<ValueRef::ValueRef<PlanetEnvironment>*>&) { return os; }
 }
 #endif
 
@@ -111,7 +111,7 @@ namespace parse { namespace detail {
             =   universe_object_type_rules.enum_expr [
                 _val = construct_movable_(
                     new_<Condition::Type>(
-                        construct<std::unique_ptr<ValueRef::ValueRefBase<UniverseObjectType>>>(
+                        construct<std::unique_ptr<ValueRef::ValueRef<UniverseObjectType>>>(
                             new_<ValueRef::Constant<UniverseObjectType>>(_1)))) ]
             |   (
                 tok.ObjectType_
