@@ -1,7 +1,11 @@
 #include "EnumParser.h"
 
 #include "../universe/Enums.h"
+#include "../universe/ShipPart.h"
+#include "../universe/UnlockableItem.h"
 
+#include <boost/phoenix/object/dynamic_cast.hpp>
+#include <boost/phoenix/operator/self.hpp>
 
 namespace qi = boost::spirit::qi;
 
@@ -18,6 +22,7 @@ namespace parse {
         rule
             =   tok.TheEmpire_  [ _val = AFFIL_SELF ]
             |   tok.EnemyOf_    [ _val = AFFIL_ENEMY ]
+            |   tok.PeaceWith_  [ _val = AFFIL_PEACE ]
             |   tok.AllyOf_     [ _val = AFFIL_ALLY ]
             |   tok.AnyEmpire_  [ _val = AFFIL_ANY ]
             |   tok.None_       [ _val = AFFIL_NONE ]
@@ -111,7 +116,6 @@ namespace parse {
             |   tok.TargetResearch_         [ _val = METER_TARGET_RESEARCH ]
             |   tok.TargetTrade_            [ _val = METER_TARGET_TRADE ]
             |   tok.TargetHappiness_        [ _val = METER_TARGET_HAPPINESS ]
-
             |   tok.MaxDefense_             [ _val = METER_MAX_DEFENSE ]
             |   tok.MaxFuel_                [ _val = METER_MAX_FUEL ]
             |   tok.MaxShield_              [ _val = METER_MAX_SHIELD ]
@@ -152,6 +156,8 @@ namespace parse {
             |   tok.MaxDamage_              [ _val = METER_MAX_CAPACITY ]
             |   tok.Capacity_               [ _val = METER_CAPACITY ]
             |   tok.Damage_                 [ _val = METER_CAPACITY ]
+            |   tok.SecondaryStat_          [ _val = METER_SECONDARY_STAT ]
+            |   tok.MaxSecondaryStat_       [ _val = METER_MAX_SECONDARY_STAT ]
             ;
     }
 
