@@ -4,13 +4,12 @@
 #include "MovableEnvelope.h"
 #include "ConditionParserImpl.h"
 
+#include "../universe/Condition.h"
 #include "../universe/Universe.h"
-#include "../universe/UniverseGenerator.h"
+#include "../universe/FleetPlan.h"
 #include "../util/Directories.h"
 
 #include <boost/spirit/include/phoenix.hpp>
-//TODO: replace with std::make_unique when transitioning to C++14
-#include <boost/smart_ptr/make_unique.hpp>
 
 #define DEBUG_PARSERS 0
 
@@ -27,10 +26,11 @@ namespace {
         const std::string& fleet_name, const std::vector<std::string>& ship_design_names,
         const boost::optional<double>& spawn_rate,
         const boost::optional<int>& spawn_limit,
-        const boost::optional<parse::detail::condition_payload>& location, bool& pass)
+        const boost::optional<parse::detail::condition_payload>& location,
+        bool& pass)
     {
         plans.push_back(
-            boost::make_unique<MonsterFleetPlan>(
+            std::make_unique<MonsterFleetPlan>(
                 fleet_name, ship_design_names,
                 (spawn_rate ? *spawn_rate : 1.0),
                 (spawn_limit ? *spawn_limit : 9999),
