@@ -4,7 +4,6 @@
 #include "EnumValueRefRules.h"
 
 #include "../universe/Enums.h"
-#include "../universe/ValueRef.h"
 
 namespace parse { namespace detail {
     universe_object_type_parser_rules::universe_object_type_parser_rules(
@@ -29,6 +28,7 @@ namespace parse { namespace detail {
             |   tok.ProductionCenter_   [ _val = OBJ_PROD_CENTER ]
             |   tok.System_             [ _val = OBJ_SYSTEM ]
             |   tok.Field_              [ _val = OBJ_FIELD ]
+            |   tok.Fighter_            [ _val = OBJ_FIGHTER ]
             ;
     }
 }
