@@ -4,17 +4,17 @@
 #include "../Empire/Diplomacy.h"
 #include "../universe/Predicates.h"
 #include "../universe/UniverseObject.h"
+#include "../universe/UnlockableItem.h"
 #include "../universe/Planet.h"
 #include "../universe/Tech.h"
 #include "../universe/Enums.h"
-#include "../util/SitRepEntry.h"
 #include "../util/AppInterface.h"
 #include "../util/Logger.h"
+#include "../util/SitRepEntry.h"
 #include "SetWrapper.h"
 
 #include <GG/Clr.h>
 
-#include <boost/function.hpp>
 #include <boost/mpl/vector.hpp>
 #include <boost/python.hpp>
 #include <boost/python/suite/indexing/map_indexing_suite.hpp>
@@ -30,24 +30,33 @@ namespace {
     // Research queue tests whether it contains a Tech by name, but Python needs
     // a __contains__ function that takes a *Queue::Element.  This helper
     // functions take an Element and returns the associated Tech name string.
-    const std::string&  TechFromResearchQueueElement(const ResearchQueue::Element& element)             { return element.name; }
+    const std::string&  TechFromResearchQueueElement(const ResearchQueue::Element& element)
+    { return element.name; }
 
-    std::vector<std::string> (TechManager::*TechNamesVoid)(void) const =                                &TechManager::TechNames;
+    std::vector<std::string> (TechManager::*TechNamesVoid)(void) const = &TechManager::TechNames;
     auto TechNamesMemberFunc = TechNamesVoid;
 
-    std::vector<std::string> (TechManager::*TechNamesCategory)(const std::string&) const =              &TechManager::TechNames;
+    std::vector<std::string> (TechManager::*TechNamesCategory)(const std::string&) const = &TechManager::TechNames;
     auto TechNamesCategoryMemberFunc = TechNamesCategory;
 
     std::vector<std::string>    TechRecursivePrereqs(const Tech& tech, int empire_id)
     { return GetTechManager().RecursivePrereqs(tech.Name(), empire_id); }
     auto TechRecursivePrereqsFunc = TechRecursivePrereqs;
 
-    // Concatenate functions to create one that takes two parameters.  The first parameter is a ResearchQueue*, which
-    // is passed directly to ResearchQueue::InQueue as the this pointer.  The second parameter is a
-    // ResearchQueue::Element which is passed into TechFromResearchQueueElement, which returns a Tech*, which is
-    // passed into ResearchQueue::InQueue as the second parameter.
+#if BOOST_VERSION >= 106000
+    using boost::placeholders::_1;
+    using boost::placeholders::_2;
+#endif
+
+    // Concatenate functions to create one that takes two parameters.  The first
+    // parameter is a ResearchQueue*, which is passed directly to
+    // ResearchQueue::InQueue as the this pointer.  The second parameter is a
+    // ResearchQueue::Element which is passed into TechFromResearchQueueElement,
+    // which returns a Tech*, which is passed into ResearchQueue::InQueue as the
+    // second parameter.
     auto InQueueFromResearchQueueElementFunc =
-        boost::bind(&ResearchQueue::InQueue, _1, boost::bind(TechFromResearchQueueElement, _2));
+        boost::bind(&ResearchQueue::InQueue, _1,
+                    boost::bind(TechFromResearchQueueElement, _2));
 
     // ProductionQueue::Element contains a ProductionItem which contains details of the item on the queue.  Need helper
     // functions to get the details about the item in the Element without adding extra pointless exposed classes to
@@ -70,9 +79,9 @@ namespace {
     }
     auto GetEmpireSitRepFunc = GetSitRep;
 
-    const Meter*            (Empire::*EmpireGetMeter)(const std::string&) const =                &Empire::GetMeter;
-    
-    template<class T1, class T2>
+    const Meter* (Empire::*EmpireGetMeter)(const std::string&) const = &Empire::GetMeter;
+
+    template<typename T1, typename T2>
     struct PairToTupleConverter {
         static PyObject* convert(const std::pair<T1, T2>& pair) {
             return boost::python::incref(boost::python::make_tuple(pair.first, pair.second).ptr());
@@ -169,9 +178,10 @@ namespace {
         std::map<std::set<int>, float> planets_with_available_pp;
         for (const auto& objects_pp : prod_queue.AvailablePP(industry_pool)) {
             std::set<int> planets;
-            for (int object_id : objects_pp.first) {
-                if (/* auto planet = */ GetPlanet(object_id))
-                    planets.insert(object_id);
+            for (const auto& planet : Objects().find<Planet>(objects_pp.first)) {
+                if (!planet)
+                    continue;
+                planets.insert(planet->ID());
             }
             if (!planets.empty())
                 planets_with_available_pp[planets] = objects_pp.second;
@@ -185,9 +195,10 @@ namespace {
         std::map<std::set<int>, float> planets_with_allocated_pp;
         for (const auto& objects_pp : prod_queue.AllocatedPP()) {
             std::set<int> planets;
-            for (int object_id : objects_pp.first) {
-                if (GetPlanet(object_id))
-                    planets.insert(object_id);
+            for (const auto& planet : Objects().find<Planet>(objects_pp.first)) {
+                if (!planet)
+                    continue;
+                planets.insert(planet->ID());
             }
             if (!planets.empty())
                 planets_with_allocated_pp[planets] = objects_pp.second;
@@ -202,9 +213,10 @@ namespace {
         std::set<std::set<int>> planets_with_wasted_pp;
         for (const auto& objects : prod_queue.ObjectsWithWastedPP(industry_pool)) {
                  std::set<int> planets;
-                 for (int object_id : objects) {
-                     if (GetPlanet(object_id))
-                         planets.insert(object_id);
+                 for (const auto& planet : Objects().find<Planet>(objects)) {
+                    if (!planet)
+                        continue;
+                    planets.insert(planet->ID());
                  }
                  if (!planets.empty())
                      planets_with_wasted_pp.insert(planets);
@@ -235,6 +247,11 @@ namespace FreeOrionPython {
     using boost::python::return_by_value;
     using boost::python::return_internal_reference;
 
+#if BOOST_VERSION >= 106000
+    using boost::placeholders::_1;
+    using boost::placeholders::_2;
+#endif
+
     /**
      * CallPolicies:
      *
@@ -262,8 +279,8 @@ namespace FreeOrionPython {
         class_<std::vector<IntPair>>("IntPairVec")
             .def(boost::python::vector_indexing_suite<std::vector<IntPair>, true>())
         ;
-        class_<std::vector<ItemSpec>>("ItemSpecVec")
-            .def(boost::python::vector_indexing_suite<std::vector<ItemSpec>, true>())
+        class_<std::vector<UnlockableItem>>("UnlockableItemVec")
+            .def(boost::python::vector_indexing_suite<std::vector<UnlockableItem>, true>())
         ;
         boost::python::to_python_converter<FloatIntPair, FloatIntPairConverter>();
 
@@ -475,9 +492,9 @@ namespace FreeOrionPython {
         boost::python::setattr(techsInCategoryFunc, "__doc__", boost::python::str("Returns the names of all techs (StringVec) in the indicated tech category name (string)."));
         def("techsInCategory", techsInCategoryFunc);
 
-        class_<ItemSpec>("ItemSpec", init<UnlockableItemType, const std::string&>())
-            .add_property("type",               &ItemSpec::type)
-            .add_property("name",               &ItemSpec::name)
+        class_<UnlockableItem>("UnlockableItem", init<UnlockableItemType, const std::string&>())
+            .add_property("type",               &UnlockableItem::type)
+            .add_property("name",               &UnlockableItem::name)
         ;
 
         ///////////////////
@@ -514,7 +531,7 @@ namespace FreeOrionPython {
         ///////////
         // Color //
         ///////////
-        class_<GG::Clr>("GGColor", no_init)
+        class_<GG::Clr>("GGColor", init<unsigned char, unsigned char, unsigned char, unsigned char>())
             .add_property("r",                  &GG::Clr::r)
             .add_property("g",                  &GG::Clr::g)
             .add_property("b",                  &GG::Clr::b)
