@@ -175,6 +175,7 @@ GG_ENUM(EmpireAffiliationType,
     INVALID_EMPIRE_AFFIL_TYPE = -1,
     AFFIL_SELF,     ///< the given empire iteslf
     AFFIL_ENEMY,    ///< enemies of the given empire
+    AFFIL_PEACE,    ///< empires at peace with the given empire
     AFFIL_ALLY,     ///< allies of the given empire
     AFFIL_ANY,      ///< any empire
     AFFIL_NONE,     ///< no empire
@@ -192,17 +193,6 @@ GG_ENUM(DiplomaticStatus,
     NUM_DIPLO_STATUSES
 )
 
-/** types of items that can be unlocked for empires */
-GG_ENUM(UnlockableItemType,
-    INVALID_UNLOCKABLE_ITEM_TYPE = -1,
-    UIT_BUILDING,               ///< a kind of Building
-    UIT_SHIP_PART,              ///< a kind of ship part (which are placed into hulls to make designs)
-    UIT_SHIP_HULL,              ///< a ship hull (into which parts are placed)
-    UIT_SHIP_DESIGN,            ///< a complete ship design
-    UIT_TECH,                   ///< a technology
-    NUM_UNLOCKABLE_ITEM_TYPES   ///< keep last, the number of types of unlockable item
-)
-
 /** Research status of techs, relating to whether they have been or can be researched */
 GG_ENUM(TechStatus,
     INVALID_TECH_STATUS = -1,
@@ -235,29 +225,6 @@ GG_ENUM(ResourceType,
     NUM_RESOURCE_TYPES
 )
 
-/** Types "classes" of ship parts */
-GG_ENUM(ShipPartClass,
-    INVALID_SHIP_PART_CLASS = -1,
-    PC_DIRECT_WEAPON,       ///< direct-fire weapons
-    PC_FIGHTER_BAY,         ///< launch aparatus for fighters, which are self-propelled platforms that function independently of ships in combat, but don't exist on the main game map
-    PC_FIGHTER_HANGAR,      ///< storage for fighters, also determines their weapon strength stat
-    PC_SHIELD,              ///< energy-based defense
-    PC_ARMOUR,              ///< defensive material on hull of ship
-    PC_TROOPS,              ///< ground troops, used to conquer planets
-    PC_DETECTION,           ///< range of vision and seeing through stealth
-    PC_STEALTH,             ///< hiding from enemies
-    PC_FUEL,                ///< distance that can be traveled away from resupply
-    PC_COLONY,              ///< transports colonists and allows ships to make new colonies
-    PC_SPEED,               ///< affects ship speed on starlanes
-    PC_GENERAL,             ///< special purpose parts that don't fall into another class
-    PC_BOMBARD,             ///< permit orbital bombardment by ships against planets
-    PC_INDUSTRY,            ///< generates production points for owner at its location
-    PC_RESEARCH,            ///< generates research points for owner
-    PC_TRADE,               ///< generates trade points for owner
-    PC_PRODUCTION_LOCATION, ///< allows production items to be produced at its location
-    NUM_SHIP_PART_CLASSES
-)
-
 /* Types of slots in hulls.  Parts may be restricted to only certain slot types */
 GG_ENUM(ShipSlotType,
     INVALID_SHIP_SLOT_TYPE = -1,
