@@ -6,13 +6,6 @@
 const float Meter::LARGE_VALUE = static_cast<float>(2 << 15);
 const float Meter::INVALID_VALUE = -LARGE_VALUE;
 
-Meter::Meter()
-{}
-
-Meter::Meter(float current_value) :
-    m_current_value(current_value)
-{}
-
 Meter::Meter(float current_value, float initial_value) :
     m_current_value(current_value),
     m_initial_value(initial_value)
