@@ -1,21 +1,23 @@
 #include "Planet.h"
 
 #include "Building.h"
+#include "BuildingType.h"
+#include "Condition.h"
 #include "Fleet.h"
 #include "Ship.h"
 #include "System.h"
 #include "Predicates.h"
 #include "Species.h"
-#include "Condition.h"
 #include "Universe.h"
-#include "ValueRef.h"
 #include "Enums.h"
+#include "ValueRef.h"
 #include "../util/Logger.h"
 #include "../util/GameRules.h"
 #include "../util/OptionsDB.h"
 #include "../util/Random.h"
 #include "../util/Directories.h"
 #include "../util/SitRepEntry.h"
+#include "../util/i18n.h"
 #include "../Empire/Empire.h"
 #include "../Empire/EmpireManager.h"
 
@@ -116,6 +118,8 @@ void Planet::Copy(std::shared_ptr<const UniverseObject> copied_object, int empir
         this->m_rotational_period =         copied_planet->m_rotational_period;
         this->m_axial_tilt =                copied_planet->m_axial_tilt;
         this->m_turn_last_conquered =       copied_planet->m_turn_last_conquered;
+        this->m_turn_last_colonized =       copied_planet->m_turn_last_colonized;
+
 
         if (vis >= VIS_PARTIAL_VISIBILITY) {
             if (vis >= VIS_FULL_VISIBILITY) {
@@ -187,11 +191,12 @@ std::string Planet::Dump(unsigned short ntabs) const {
         os << building_id << (it == m_buildings.end() ? "" : ", ");
     }
     if (m_is_about_to_be_colonized)
-        os << " (About to be Colonize)";
+        os << " (About to be Colonized)";
     if (m_is_about_to_be_invaded)
         os << " (About to be Invaded)";
 
-    os << " conqured on turn: " << m_turn_last_conquered;
+    os << " colonized on turn: " << m_turn_last_colonized;
+    os << " conquered on turn: " << m_turn_last_conquered;
     if (m_is_about_to_be_bombarded)
         os << " (About to be Bombarded)";
     if (m_ordered_given_to_empire_id != ALL_EMPIRES)
@@ -421,12 +426,6 @@ Meter* Planet::GetMeter(MeterType type)
 const Meter* Planet::GetMeter(MeterType type) const
 { return UniverseObject::GetMeter(type); }
 
-float Planet::InitialMeterValue(MeterType type) const
-{ return UniverseObject::InitialMeterValue(type); }
-
-float Planet::CurrentMeterValue(MeterType type) const
-{ return UniverseObject::CurrentMeterValue(type); }
-
 std::string Planet::CardinalSuffix() const {
     std::string retval = "";
     // Early return for invalid ID
@@ -435,7 +434,7 @@ std::string Planet::CardinalSuffix() const {
         return retval;
     }
 
-    auto cur_system = GetSystem(SystemID());
+    auto cur_system = Objects().get<System>(SystemID());
     // Early return for no system
     if (!cur_system) {
         ErrorLogger() << "Planet " << Name() << "(" << ID()
@@ -467,7 +466,7 @@ std::string Planet::CardinalSuffix() const {
             continue;
         }
 
-        PlanetType other_planet_type = GetPlanet(sys_orbit)->Type();
+        PlanetType other_planet_type = Objects().get<Planet>(sys_orbit)->Type();
         if (other_planet_type == INVALID_PLANET_TYPE)
             continue;
 
@@ -610,11 +609,14 @@ void Planet::Reset() {
     GetMeter(METER_REBEL_TROOPS)->Reset();
 
     if (m_is_about_to_be_colonized && !OwnedBy(ALL_EMPIRES)) {
-        for (int building_id : m_buildings)
-            if (auto building = GetBuilding(building_id))
-                building->Reset();
+        for (const auto& building : Objects().find<Building>(m_buildings)) {
+            if (!building)
+                continue;
+            building->Reset();
+        }
     }
 
+    //m_turn_last_colonized left unchanged
     //m_turn_last_conquered left unchanged
     m_is_about_to_be_colonized = false;
     m_is_about_to_be_invaded = false;
@@ -640,7 +642,7 @@ void Planet::Conquer(int conquerer) {
     Empire::ConquerProductionQueueItemsAtLocation(ID(), conquerer);
 
     // deal with UniverseObjects (eg. buildings) located on this planet
-    for (auto& building : Objects().FindObjects<Building>(m_buildings)) {
+    for (auto& building : Objects().find<Building>(m_buildings)) {
         const BuildingType* type = GetBuildingType(building->BuildingTypeName());
 
         // determine what to do with building of this type...
@@ -653,7 +655,7 @@ void Planet::Conquer(int conquerer) {
             // destroy object
             //DebugLogger() << "Planet::Conquer destroying object: " << building->Name();
             this->RemoveBuilding(building->ID());
-            if (auto system = GetSystem(this->SystemID()))
+            if (auto system = Objects().get<System>(this->SystemID()))
                 system->Remove(building->ID());
             GetUniverse().Destroy(building->ID());
         } else if (cap_result == CR_RETAIN) {
@@ -686,6 +688,12 @@ void Planet::Conquer(int conquerer) {
     GetMeter(METER_DETECTION)->BackPropagate();
 }
 
+void Planet::SetSpecies(const std::string& species_name) {
+    if (SpeciesName().empty() && !species_name.empty())
+        m_turn_last_colonized = CurrentTurn();  // if setting species with an effect, not via Colonize, consider it a colonization when there was no previous species set
+    PopCenter::SetSpecies(species_name);
+}
+
 bool Planet::Colonize(int empire_id, const std::string& species_name, double population) {
     const Species* species = nullptr;
 
@@ -694,12 +702,13 @@ bool Planet::Colonize(int empire_id, const std::string& species_name, double pop
         // check if specified species exists and get reference
         species = GetSpecies(species_name);
         if (!species) {
-            ErrorLogger() << "Planet::Colonize couldn't get species already on planet with name: " << species_name;
+            ErrorLogger() << "Planet::Colonize couldn't get species: " << species_name;
             return false;
         }
         // check if specified species can colonize this planet
         if (EnvironmentForSpecies(species_name) < PE_HOSTILE) {
-            ErrorLogger() << "Planet::Colonize: can't colonize planet already populated by species " << species_name;
+            ErrorLogger() << "Planet::Colonize: can't colonize planet with species " << species_name << " because planet is "
+                          << m_type << " which for that species is environment: " << EnvironmentForSpecies(species_name);
             return false;
         }
     }
@@ -709,9 +718,11 @@ bool Planet::Colonize(int empire_id, const std::string& species_name, double pop
         Reset();
     } else {
         PopCenter::Reset();
-        for (int building_id : m_buildings)
-            if (auto building = GetBuilding(building_id))
-                building->Reset();
+        for (const auto& building : Objects().find<Building>(m_buildings)) {
+            if (!building)
+                continue;
+            building->Reset();
+        }
         m_is_about_to_be_colonized = false;
         m_is_about_to_be_invaded = false;
         m_is_about_to_be_bombarded = false;
@@ -721,6 +732,7 @@ bool Planet::Colonize(int empire_id, const std::string& species_name, double pop
     // if desired pop > 0, we want a colony, not an outpost, so we have to set the colony species
     if (population > 0.0)
         SetSpecies(species_name);
+    m_turn_last_colonized = CurrentTurn();  // may be redundant with same in SetSpecies, but here occurrs always, whereas in SetSpecies is only done if species is initially empty
 
     // find a default focus. use first defined available focus.
     // AvailableFoci function should return a vector of all names of
@@ -752,8 +764,8 @@ bool Planet::Colonize(int empire_id, const std::string& species_name, double pop
     SetOwner(empire_id);
 
     // if there are buildings on the planet, set the specified empire as their owner too
-    for (auto& building : Objects().FindObjects<Building>(BuildingIDs()))
-    { building->SetOwner(empire_id); }
+    for (auto& building : Objects().find<Building>(BuildingIDs()))
+        building->SetOwner(empire_id);
 
     return true;
 }
@@ -812,18 +824,12 @@ void Planet::PopGrowthProductionResearchPhase() {
     // should be run after a meter update, but before a backpropagation, so check current, not initial, meter values
 
     // check for colonies without positive population, and change to outposts
-    if (!SpeciesName().empty() && CurrentMeterValue(METER_POPULATION) <= 0.0f) {
+    if (!SpeciesName().empty() && GetMeter(METER_POPULATION)->Current() <= 0.0f) {
         if (Empire* empire = GetEmpire(this->Owner())) {
             empire->AddSitRepEntry(CreatePlanetDepopulatedSitRep(this->ID()));
 
-            if (!HasTag(TAG_STAT_SKIP_DEPOP)) {
-                // record depopulation of planet with species while owned by this empire
-                auto species_it = empire->SpeciesPlanetsDepoped().find(SpeciesName());
-                if (species_it == empire->SpeciesPlanetsDepoped().end())
-                    empire->SpeciesPlanetsDepoped()[SpeciesName()] = 1;
-                else
-                    species_it->second++;
-            }
+            if (!HasTag(TAG_STAT_SKIP_DEPOP))
+                empire->RecordPlanetDepopulated(*this);
         }
         // remove species
         PopCenter::Reset();
