@@ -1,8 +1,6 @@
 #ifndef _Tech_h_
 #define _Tech_h_
 
-#include "ValueRefFwd.h"
-
 #include "EnumsFwd.h"
 #include "../util/Export.h"
 #include "../util/Pending.h"
@@ -22,8 +20,12 @@
 
 namespace Effect
 { class EffectsGroup; }
+namespace ValueRef {
+    template <typename T>
+    struct ValueRef;
+}
 class TechManager;
-struct ItemSpec;
+struct UnlockableItem;
 
 /** encasulates the data for a single FreeOrion technology */
 class FO_COMMON_API Tech {
@@ -33,8 +35,8 @@ public:
         TechInfo();
         TechInfo(const std::string& name_, const std::string& description_,
                  const std::string& short_description_, const std::string& category_,
-                 std::unique_ptr<ValueRef::ValueRefBase<double>>&& research_cost_,
-                 std::unique_ptr<ValueRef::ValueRefBase<int>>&& research_turns_,
+                 std::unique_ptr<ValueRef::ValueRef<double>>&& research_cost_,
+                 std::unique_ptr<ValueRef::ValueRef<int>>&& research_turns_,
                  bool researchable_,
                  const std::set<std::string>& tags_);
         ~TechInfo();
@@ -43,8 +45,8 @@ public:
         std::string                     description;
         std::string                     short_description;
         std::string                     category;
-        std::unique_ptr<ValueRef::ValueRefBase<double>> research_cost;
-        std::unique_ptr<ValueRef::ValueRefBase<int>>    research_turns;
+        std::unique_ptr<ValueRef::ValueRef<double>> research_cost;
+        std::unique_ptr<ValueRef::ValueRef<int>>    research_turns;
         bool                            researchable;
         std::set<std::string>           tags;
     };
@@ -52,13 +54,13 @@ public:
     /** \name Structors */ //@{
     Tech(const std::string& name, const std::string& description,
          const std::string& short_description, const std::string& category,
-         std::unique_ptr<ValueRef::ValueRefBase<double>>&& research_cost,
-         std::unique_ptr<ValueRef::ValueRefBase<int>>&& research_turns,
+         std::unique_ptr<ValueRef::ValueRef<double>>&& research_cost,
+         std::unique_ptr<ValueRef::ValueRef<int>>&& research_turns,
          bool researchable,
          const std::set<std::string>& tags,
          const std::vector<std::shared_ptr<Effect::EffectsGroup>>& effects,
          const std::set<std::string>& prerequisites,
-         const std::vector<ItemSpec>& unlocked_items,
+         const std::vector<UnlockableItem>& unlocked_items,
          const std::string& graphic);
 
     /** basic ctor taking helper struct to reduce number of direct parameters
@@ -66,7 +68,7 @@ public:
     Tech(TechInfo& tech_info,
          std::vector<std::unique_ptr<Effect::EffectsGroup>>&& effects,
          const std::set<std::string>& prerequisites,
-         const std::vector<ItemSpec>& unlocked_items,
+         const std::vector<UnlockableItem>& unlocked_items,
          const std::string& graphic);
 
     ~Tech();
@@ -93,7 +95,11 @@ public:
 
     const std::set<std::string>&    Prerequisites() const { return m_prerequisites; }   //!< returns the set of names of all techs required before this one can be researched
     const std::string&              Graphic() const       { return m_graphic; }         //!< returns the name of the grapic file for this tech
-    const std::vector<ItemSpec>&    UnlockedItems() const { return m_unlocked_items; }  //!< returns the set all items that are unlocked by researching this tech
+
+    //! Returns the set all items that are unlocked by researching this tech
+    const std::vector<UnlockableItem>&    UnlockedItems() const
+    { return m_unlocked_items; }
+
     const std::set<std::string>&    UnlockedTechs() const { return m_unlocked_techs; }  //!< returns the set of names of all techs for which this one is a prerequisite
 
     /** Returns a number, calculated from the contained data, which should be
@@ -114,13 +120,13 @@ private:
     std::string                     m_description;
     std::string                     m_short_description;
     std::string                     m_category;
-    std::unique_ptr<ValueRef::ValueRefBase<double>> m_research_cost;
-    std::unique_ptr<ValueRef::ValueRefBase<int>>    m_research_turns;
+    std::unique_ptr<ValueRef::ValueRef<double>> m_research_cost;
+    std::unique_ptr<ValueRef::ValueRef<int>>    m_research_turns;
     bool                            m_researchable;
     std::set<std::string>           m_tags;
     std::vector<std::shared_ptr<Effect::EffectsGroup>> m_effects;
     std::set<std::string>           m_prerequisites;
-    std::vector<ItemSpec>           m_unlocked_items;
+    std::vector<UnlockableItem>     m_unlocked_items;
     std::string                     m_graphic;
     std::set<std::string>           m_unlocked_techs;
 
@@ -128,24 +134,6 @@ private:
 };
 
 
-/** specifies a single item of game content that may be unlocked for an empire.  The \a type field
-  * stores the type of item that is being unlocked, such as a building or ship component, and the
-  * \a name field contains the name of the actual item (e.g. (UIT_BUILDING, "Superfarm") or
-  * (UIT_SHIP_PART, "Death Ray")). */
-struct FO_COMMON_API ItemSpec {
-    ItemSpec();
-    ItemSpec(UnlockableItemType type_, const std::string& name_) :
-        type(type_),
-        name(name_)
-    {}
-    std::string Dump(unsigned short ntabs = 0) const;   ///< returns a data file format representation of this object
-    UnlockableItemType type;    ///< the kind of item this is
-    std::string        name;    ///< the exact item this is
-};
-
-FO_COMMON_API bool operator==(const ItemSpec& lhs, const ItemSpec& rhs);
-bool operator!=(const ItemSpec& lhs, const ItemSpec& rhs);
-
 /** specifies a category of techs, with associated \a name, \a graphic (icon), and \a colour.*/
 struct FO_COMMON_API TechCategory {
     TechCategory() :
@@ -165,7 +153,6 @@ struct FO_COMMON_API TechCategory {
 };
 
 namespace CheckSums {
-    FO_COMMON_API void CheckSumCombine(unsigned int& sum, const ItemSpec& item);
     FO_COMMON_API void CheckSumCombine(unsigned int& sum, const TechCategory& cat);
 }
 
@@ -308,7 +295,14 @@ private:
 /** returns the singleton tech manager */
 FO_COMMON_API TechManager& GetTechManager();
 
-/** returns a pointer to the tech with the name \a name, or 0 if no such tech exists */
+//! @brief Returns the ::Tech identified by @p name
+//!
+//! @param name
+//! The identifying name of the requested ::Tech.
+//!
+//! @return
+//! A pointer to the ::Tech matching @p name or nullptr if no ::Tech with that
+//! name was found.
 FO_COMMON_API const Tech* GetTech(const std::string& name);
 
 /** returns a pointer to the tech category with the name \a name, or 0 if no such category exists */
