@@ -43,8 +43,11 @@ public:
 
     /** \name Accessors */ //@{
     /** Returns the ID of the Empire issuing the order. */
-    int EmpireID() const
-    { return m_empire; }
+    int EmpireID() const { return m_empire; }
+
+    /** Returns true iff this order has been executed (a second execution
+      * indicates server-side execution). */
+    bool Executed() const;
     //@}
 
     /** Executes the order on the Universe and Empires.
@@ -71,15 +74,10 @@ protected:
     /** Verifies that the empire ID in this order is valid and return the Empire pointer.
      *  Throws an std::runtime_error if not valid. */
     Empire* GetValidatedEmpire() const;
-
-    /** Returns true iff this order has been executed (a second execution
-     *  indicates server-side execution). */
-    bool Executed() const;
     //@}
 
 private:
     virtual void ExecuteImpl() const = 0;
-
     virtual bool UndoImpl() const;
 
     int m_empire = ALL_EMPIRES;
@@ -88,7 +86,7 @@ private:
     mutable bool m_executed = false;
 
     friend class boost::serialization::access;
-    template <class Archive>
+    template <typename Archive>
     void serialize(Archive& ar, const unsigned int version);
 };
 
@@ -113,6 +111,9 @@ public:
     { return m_name; }
     //@}
 
+    //! Returns true when the Order parameters are valid.
+    static bool Check(int empire, int object, const std::string& new_name);
+
 private:
     RenameOrder() = default;
 
@@ -130,7 +131,7 @@ private:
     std::string m_name;
 
     friend class boost::serialization::access;
-    template <class Archive>
+    template <typename Archive>
     void serialize(Archive& ar, const unsigned int version);
 };
 
@@ -144,31 +145,25 @@ class FO_COMMON_API NewFleetOrder : public Order {
 public:
     /** \name Structors */ //@{
     NewFleetOrder(int empire, const std::string& fleet_name,
-                  int system_id, const std::vector<int>& ship_ids,
-                  bool aggressive = false);
-
-    NewFleetOrder(int empire, const std::vector<std::string>& fleet_names,
-                  int system_id, const std::vector<std::vector<int>>& ship_id_groups,
-                  const std::vector<bool>& aggressives);
+                  const std::vector<int>& ship_ids,
+                  bool aggressive);
     //@}
 
     /** \name Accessors */ //@{
-    int SystemID() const
-    { return m_system_id; }
+    const std::string& FleetName() const
+    { return m_fleet_name; }
 
-    const std::vector<std::string>& FleetNames() const
-    { return m_fleet_names; }
+    const int& FleetID() const
+    { return m_fleet_id; }
 
-    const std::vector<int>& FleetIDs() const
-    { return m_fleet_ids; }
+    const std::vector<int>& ShipIDs() const
+    { return m_ship_ids; }
 
-    const std::vector<std::vector<int>>& ShipIDGroups() const
-    { return m_ship_id_groups; }
-
-    const std::vector<bool>& Aggressive() const
-    { return m_aggressives; }
+    bool Aggressive() const
+    { return m_aggressive; }
     //@}
 
+    static bool Check(int empire, const std::string& fleet_name, const std::vector<int>& ship_ids, bool aggressive);
 private:
     NewFleetOrder() = default;
 
@@ -182,15 +177,14 @@ private:
      */
     void ExecuteImpl() const override;
 
-    std::vector<std::string> m_fleet_names;
-    int m_system_id = INVALID_OBJECT_ID;
-    /** m_fleet_ids is mutable because ExecuteImpl generates the fleet ids. */
-    mutable std::vector<int> m_fleet_ids;
-    std::vector<std::vector<int>> m_ship_id_groups;
-    std::vector<bool> m_aggressives;
+    std::string m_fleet_name;
+    /** m_fleet_id is mutable because ExecuteImpl generates the fleet id. */
+    mutable int m_fleet_id = INVALID_OBJECT_ID;
+    std::vector<int> m_ship_ids;
+    bool m_aggressive = false;
 
     friend class boost::serialization::access;
-    template <class Archive>
+    template <typename Archive>
     void serialize(Archive& ar, const unsigned int version);
 };
 
@@ -203,7 +197,7 @@ private:
 class FO_COMMON_API FleetMoveOrder : public Order {
 public:
     /** \name Structors */ //@{
-    FleetMoveOrder(int empire_id, int fleet_id, int start_system_id, int dest_system_id,
+    FleetMoveOrder(int empire_id, int fleet_id, int dest_system_id,
                    bool append = false);
     //@}
 
@@ -212,11 +206,6 @@ public:
     int FleetID() const
     { return m_fleet; }
 
-    /** Returns ID of system set as the start system for this order (the system
-        the route starts from). */
-    int StartSystemID() const
-    { return m_start_system; }
-
     /* Returns ID of system set as destination for this order. */
     int DestinationSystemID() const
     { return m_dest_system; }
@@ -226,6 +215,7 @@ public:
     { return m_route; }
     //@}
 
+    static bool Check(int empire_id, int fleet_id, int dest_fleet_id, bool append = false);
 private:
     FleetMoveOrder() = default;
 
@@ -243,13 +233,12 @@ private:
     void ExecuteImpl() const override;
 
     int m_fleet = INVALID_OBJECT_ID;
-    int m_start_system = INVALID_OBJECT_ID;
     int m_dest_system = INVALID_OBJECT_ID;
     std::vector<int> m_route;
     bool m_append = false;
 
     friend class boost::serialization::access;
-    template <class Archive>
+    template <typename Archive>
     void serialize(Archive& ar, const unsigned int version);
 };
 
@@ -276,6 +265,8 @@ public:
     { return m_add_ships; }
     //@}
 
+    static bool Check(int empire_id, int dest_fleet_id, const std::vector<int>& ship_ids);
+
 private:
     FleetTransferOrder() = default;
 
@@ -294,7 +285,7 @@ private:
     std::vector<int> m_add_ships;
 
     friend class boost::serialization::access;
-    template <class Archive>
+    template <typename Archive>
     void serialize(Archive& ar, const unsigned int version);
 };
 
@@ -319,6 +310,8 @@ public:
     { return m_ship; }
     //@}
 
+    static bool Check(int empire_id, int ship_id, int planet_id);
+
 private:
     ColonizeOrder() = default;
 
@@ -341,7 +334,7 @@ private:
     int m_planet = INVALID_OBJECT_ID;
 
     friend class boost::serialization::access;
-    template <class Archive>
+    template <typename Archive>
     void serialize(Archive& ar, const unsigned int version);
 };
 
@@ -366,6 +359,8 @@ public:
     { return m_ship; }
     //@}
 
+    static bool Check(int empire_id, int ship_id, int planet_id);
+
 private:
     InvadeOrder() = default;
 
@@ -388,7 +383,7 @@ private:
     int m_planet = INVALID_OBJECT_ID;
 
     friend class boost::serialization::access;
-    template <class Archive>
+    template <typename Archive>
     void serialize(Archive& ar, const unsigned int version);
 };
 
@@ -413,6 +408,8 @@ public:
     { return m_ship; }
     //@}
 
+    static bool Check(int empire_id, int ship_id, int planet_id);
+
 private:
     BombardOrder() = default;
 
@@ -433,7 +430,7 @@ private:
     int m_planet = INVALID_OBJECT_ID;
 
     friend class boost::serialization::access;
-    template <class Archive>
+    template <typename Archive>
     void serialize(Archive& ar, const unsigned int version);
 };
 
@@ -454,6 +451,8 @@ public:
     { return m_planet; }
     //@}
 
+    static bool Check(int empire_id, int planet_id, const std::string& focus);
+
 private:
     ChangeFocusOrder() = default;
 
@@ -470,7 +469,7 @@ private:
     std::string m_focus;
 
     friend class boost::serialization::access;
-    template <class Archive>
+    template <typename Archive>
     void serialize(Archive& ar, const unsigned int version);
 };
 
@@ -505,7 +504,7 @@ private:
     static const int INVALID_PAUSE_RESUME = -1;
 
     friend class boost::serialization::access;
-    template <class Archive>
+    template <typename Archive>
     void serialize(Archive& ar, const unsigned int version);
 };
 
@@ -520,17 +519,30 @@ private:
   * \a empire's queue. */
 class FO_COMMON_API ProductionQueueOrder : public Order {
 public:
+    enum ProdQueueOrderAction : int {
+        INVALID_PROD_QUEUE_ACTION = -1,
+        PLACE_IN_QUEUE,
+        REMOVE_FROM_QUEUE,
+        SPLIT_INCOMPLETE,
+        DUPLICATE_ITEM,
+        SET_QUANTITY_AND_BLOCK_SIZE,
+        SET_QUANTITY,
+        MOVE_ITEM_TO_INDEX,
+        SET_RALLY_POINT,
+        PAUSE_PRODUCTION,
+        RESUME_PRODUCTION,
+        ALLOW_STOCKPILE_USE,
+        DISALLOW_STOCKPILE_USE,
+        NUM_PROD_QUEUE_ACTIONS
+    };
+
     /** \name Structors */ //@{
-    ProductionQueueOrder(int empire, const ProductionQueue::ProductionItem& item, int number, int location, int pos = -1);
-    ProductionQueueOrder(int empire, int index, int new_quantity, bool dummy);
-    ProductionQueueOrder(int empire, int index, int rally_point_id, bool dummy1, bool dummy2);
-    ProductionQueueOrder(int empire, int index, int new_quantity, int new_blocksize);
-    ProductionQueueOrder(int empire, int index, int new_index);
-    ProductionQueueOrder(int empire, int index);
-    ProductionQueueOrder(int empire, int index, bool pause, float dummy);
-    ProductionQueueOrder(int empire, int index, float dummy1);
-    ProductionQueueOrder(int empire, int index, float dummy1, float dummy2);
-    ProductionQueueOrder(int empire, int index, bool allow_use_imperial_pp, float dummy, float dummy2);
+    ProductionQueueOrder(ProdQueueOrderAction action, int empire,
+                         const ProductionQueue::ProductionItem& item,
+                         int number, int location, int pos = -1);
+    ProductionQueueOrder(ProdQueueOrderAction action, int empire,
+                         boost::uuids::uuid uuid,
+                         int num1 = -1, int num2 = -1);
     //@}
 
 private:
@@ -539,30 +551,19 @@ private:
     void ExecuteImpl() const override;
 
     ProductionQueue::ProductionItem m_item;
-    int m_number = 0;
-    int m_location = INVALID_OBJECT_ID;
-    int m_index = INVALID_INDEX;
-    int m_new_quantity = INVALID_QUANTITY;
-    int m_new_blocksize = INVALID_QUANTITY;
-    int m_new_index = INVALID_INDEX;
-    int m_rally_point_id = INVALID_OBJECT_ID;
-    int m_pause = INVALID_PAUSE_RESUME;
-    int m_split_incomplete = INVALID_SPLIT_INCOMPLETE;
-    int m_dupe = INVALID_SPLIT_INCOMPLETE;
-    int m_use_imperial_pp = INVALID_USE_IMPERIAL_PP;
+    int                             m_location = INVALID_OBJECT_ID;
+    int                             m_new_quantity = INVALID_QUANTITY;
+    int                             m_new_blocksize = INVALID_QUANTITY;
+    int                             m_new_index = INVALID_INDEX;
+    int                             m_rally_point_id = INVALID_OBJECT_ID;
+    boost::uuids::uuid              m_uuid, m_uuid2;
+    ProdQueueOrderAction            m_action = INVALID_PROD_QUEUE_ACTION;
 
     static const int INVALID_INDEX = -500;
     static const int INVALID_QUANTITY = -1000;
-    static const int PAUSE = 1;
-    static const int RESUME = 2;
-    static const int INVALID_PAUSE_RESUME = -1;
-    static const int INVALID_SPLIT_INCOMPLETE = -1;
-    static const int USE_IMPERIAL_PP = 4;
-    static const int DONT_USE_IMPERIAL_PP = 8;
-    static const int INVALID_USE_IMPERIAL_PP = -4;
 
     friend class boost::serialization::access;
-    template <class Archive>
+    template <typename Archive>
     void serialize(Archive& ar, const unsigned int version);
 };
 
@@ -637,7 +638,7 @@ private:
     // end details of design to create
 
     friend class boost::serialization::access;
-    template <class Archive>
+    template <typename Archive>
     void serialize(Archive& ar, const unsigned int version);
 };
 
@@ -659,6 +660,7 @@ public:
     { return m_object_id; }
     //@}
 
+    static bool Check(int empire_id, int object_id);
 private:
     ScrapOrder() = default;
 
@@ -677,7 +679,7 @@ private:
     int m_object_id = INVALID_OBJECT_ID;
 
     friend class boost::serialization::access;
-    template <class Archive>
+    template <typename Archive>
     void serialize(Archive& ar, const unsigned int version);
 };
 
@@ -703,6 +705,8 @@ public:
     { return m_aggression; }
     //@}
 
+    static bool Check(int empire_id, int object_id, bool aggression);
+
 private:
     AggressiveOrder() = default;
 
@@ -720,7 +724,7 @@ private:
     bool m_aggression = false;
 
     friend class boost::serialization::access;
-    template <class Archive>
+    template <typename Archive>
     void serialize(Archive& ar, const unsigned int version);
 };
 
@@ -746,6 +750,7 @@ public:
     { return m_recipient_empire_id; }
     //@}
 
+    static bool Check(int empire_id, int object_id, int recipient_empire_id);
 private:
     GiveObjectToEmpireOrder() = default;
 
@@ -765,7 +770,7 @@ private:
     int m_recipient_empire_id = ALL_EMPIRES;
 
     friend class boost::serialization::access;
-    template <class Archive>
+    template <typename Archive>
     void serialize(Archive& ar, const unsigned int version);
 };
 
@@ -800,7 +805,7 @@ private:
     int m_object_id = INVALID_OBJECT_ID;
 
     friend class boost::serialization::access;
-    template <class Archive>
+    template <typename Archive>
     void serialize(Archive& ar, const unsigned int version);
 };
 
