@@ -11,85 +11,139 @@
 #include <mutex>
 
 namespace {
-    std::string GetDefaultStringTableFileName()
-    { return PathToString(GetResourceDir() / "stringtables" / "en.txt"); }
+    std::map<std::string, std::shared_ptr<const StringTable>>  stringtables;
+    std::recursive_mutex                                       stringtable_access_mutex;
+    bool                                                       stringtable_filename_init = false;
 
-    std::map<std::string, std::shared_ptr<const StringTable_>>  stringtables;
-    std::recursive_mutex                                        stringtable_access_mutex;
-    bool                                                        stringtable_filename_init = false;
+    // fallback stringtable to look up key in if entry is not found in currently configured stringtable
+    boost::filesystem::path DevDefaultEnglishStringtablePath()
+    { return GetResourceDir() / "stringtables/en.txt"; }
 
-    /** Determines stringtable to use from users locale when stringtable filename is at default setting */
-    void InitStringtableFileName() {
-        // Only check on the first call
-        if (stringtable_filename_init)
-            return;
-        stringtable_filename_init = true;
+    // filename to use as default value for stringtable filename option.
+    // based on the system's locale. not necessarily the same as the
+    // "dev default" (english) stringtable filename for fallback lookup
+    // includes "<resource-dir>/stringtables/" directory part of path
+    boost::filesystem::path GetDefaultStringTableFileName() {
+        std::string lang;
 
-        bool was_specified = false;
-        if (!GetOptionsDB().IsDefaultValue("resource.stringtable.path"))
-            was_specified = true;
-
-        // Set the english stingtable as the default option
-        GetOptionsDB().SetDefault("resource.stringtable.path", PathToString(GetResourceDir() / "stringtables/en.txt"));
-        if (was_specified) {
-            DebugLogger() << "Detected language: Previously specified " << GetOptionsDB().Get<std::string>("resource.stringtable.path");
-            return;
-        }
-
-        std::string lang {};
+        // early return when unable to get locale language string
         try {
             lang = std::use_facet<boost::locale::info>(GetLocale()).language();
-        } catch(std::bad_cast) {
-            WarnLogger() << "Detected language: Bad cast, falling back to default";
-            return;
+        } catch(const std::bad_cast&) {
+            ErrorLogger() << "Bad locale cast when setting default language";
         }
 
         boost::algorithm::to_lower(lang);
 
-        // early return when determined language is empty or C locale
+        // handle failed locale lookup or C locale
         if (lang.empty() || lang == "c" || lang == "posix") {
-            WarnLogger() << "Detected lanuage: Not detected, falling back to default";
+            WarnLogger() << "Lanuage not detected from locale: \"" << lang << "\"; falling back to default en";
+            lang = "en";
+        } else {
+            DebugLogger() << "Detected locale language: " << lang;
+        }
+
+        boost::filesystem::path lang_filename{ lang + ".txt" };
+        boost::filesystem::path default_stringtable_path{ GetResourceDir() / "stringtables" / lang_filename };
+
+        // default to english if locale-derived filename not present
+        if (!IsExistingFile(default_stringtable_path)) {
+            WarnLogger() << "Detected language file not present: " << PathToString(default_stringtable_path) << "  Reverting to en.txt";
+            default_stringtable_path = DevDefaultEnglishStringtablePath();
+        }
+
+        if (!IsExistingFile(default_stringtable_path))
+            ErrorLogger() << "Default english stringtable file also not presennt!!: " << PathToString(default_stringtable_path);
+
+        DebugLogger() << "GetDefaultStringTableFileName returning: " << PathToString(default_stringtable_path);
+        return default_stringtable_path;
+    }
+
+    // sets the stringtable filename option default value.
+    // also checks the option-set stringtable path, and if it is blank or the
+    // specified file doesn't exist, tries to reinterpret the option value as
+    // a path in the standard location, or reverts to the default stringtable
+    // location if other attempts fail.
+    void InitStringtableFileName() {
+        stringtable_filename_init = true;
+
+        // set option default value based on system locale
+        auto default_stringtable_path = GetDefaultStringTableFileName();
+        GetOptionsDB().SetDefault("resource.stringtable.path", PathToString(default_stringtable_path));
+
+        // get option-configured stringtable path. may be the default empty
+        // string (set by call to:   db.Add<std::string>("resource.stringtable.path" ...
+        // or this may have been overridden from one of the config XML files or from
+        // a command line argument.
+        std::string option_path = GetOptionsDB().Get<std::string>("resource.stringtable.path");
+        boost::filesystem::path stringtable_path{option_path};
+
+        // verify that option-derived stringtable file exists, with fallbacks
+        DebugLogger() << "Stringtable option path: " << option_path;
+
+        if (option_path.empty()) {
+            DebugLogger() << "Stringtable option path not specified yet, using default: " << PathToString(default_stringtable_path);
+            stringtable_path = PathToString(default_stringtable_path);
+            GetOptionsDB().Set("resource.stringtable.path", PathToString(stringtable_path));
             return;
         }
 
-        DebugLogger() << "Detected language: " << lang;
+        bool set_option = false;
 
-        boost::filesystem::path lang_filename{ lang + ".txt" };
-        boost::filesystem::path stringtable_file{ GetResourceDir() / "stringtables" / lang_filename };
+        if (!IsExistingFile(stringtable_path)) {
+            set_option = true;
+            // try interpreting path as a filename located in the stringtables directory
+            stringtable_path = GetResourceDir() / "stringtables" / option_path;
+        }
+        if (!IsExistingFile(stringtable_path)) {
+            set_option = true;
+            // try interpreting path as directory and filename in resources directory
+            stringtable_path = GetResourceDir() / option_path;
+        }
+        if (!IsExistingFile(stringtable_path)) {
+            set_option = true;
+            // fall back to default option value
+            ErrorLogger() << "Stringtable option path file is missing: " << PathToString(stringtable_path);
+            DebugLogger() << "Resetting to default: " << PathToString(default_stringtable_path);
+            stringtable_path = default_stringtable_path;
+        }
 
-        if (IsExistingFile(stringtable_file))
-            GetOptionsDB().Set("resource.stringtable.path", PathToString(stringtable_file));
-        else
-            WarnLogger() << "Stringtable file " << PathToString(stringtable_file)
-                         << " not found, falling back to default";
+        if (set_option)
+            GetOptionsDB().Set("resource.stringtable.path", PathToString(stringtable_path));
     }
 
+    // get currently set stringtable filename option value, or the default value
+    // if the currenty value is empty
     std::string GetStringTableFileName() {
         std::lock_guard<std::recursive_mutex> stringtable_lock(stringtable_access_mutex);
-        InitStringtableFileName();
+        // initialize option value and default on first call
+        if (!stringtable_filename_init)
+            InitStringtableFileName();
 
-        std::string option_filename = GetOptionsDB().Get<std::string>("resource.stringtable.path");
-        if (option_filename.empty())
-            return GetDefaultStringTableFileName();
+        std::string option_path = GetOptionsDB().Get<std::string>("resource.stringtable.path");
+        if (option_path.empty())
+            return GetOptionsDB().GetDefault<std::string>("resource.stringtable.path");
         else
-            return option_filename;
+            return option_path;
     }
 
-    const StringTable_& GetStringTable(std::string stringtable_filename = "") {
+    const StringTable& GetStringTable(boost::filesystem::path stringtable_path) {
         std::lock_guard<std::recursive_mutex> stringtable_lock(stringtable_access_mutex);
 
-        // get option-configured stringtable if no filename specified
-        if (stringtable_filename.empty())
-            stringtable_filename = GetStringTableFileName();
+        if (!stringtable_filename_init)
+            InitStringtableFileName();
 
         // ensure the default stringtable is loaded first
-        auto default_stringtable_it = stringtables.find(GetDefaultStringTableFileName());
+        auto default_stringtable_filename{GetOptionsDB().GetDefault<std::string>("resource.stringtable.path")};
+        auto default_stringtable_it = stringtables.find(default_stringtable_filename);
         if (default_stringtable_it == stringtables.end()) {
-            auto table = std::make_shared<StringTable_>(GetDefaultStringTableFileName());
-            stringtables[GetDefaultStringTableFileName()] = table;
-            default_stringtable_it = stringtables.find(GetDefaultStringTableFileName());
+            auto table = std::make_shared<StringTable>(default_stringtable_filename);
+            stringtables[default_stringtable_filename] = table;
+            default_stringtable_it = stringtables.find(default_stringtable_filename);
         }
 
+        auto stringtable_filename = PathToString(stringtable_path);
+
         // attempt to find requested stringtable...
         auto it = stringtables.find(stringtable_filename);
         if (it != stringtables.end())
@@ -97,14 +151,17 @@ namespace {
 
         // if not already loaded, load, store, and return,
         // using default stringtable for fallback expansion lookups
-        auto table = std::make_shared<StringTable_>(stringtable_filename, default_stringtable_it->second);
+        auto table = std::make_shared<StringTable>(stringtable_filename, default_stringtable_it->second);
         stringtables[stringtable_filename] = table;
 
         return *table;
     }
 
-    const StringTable_& GetDefaultStringTable()
-    { return GetStringTable(GetDefaultStringTableFileName()); }
+    const StringTable& GetStringTable()
+    { return GetStringTable(GetStringTableFileName()); }
+
+    const StringTable& GetDevDefaultStringTable()
+    { return GetStringTable(DevDefaultEnglishStringtablePath()); }
 }
 
 std::locale GetLocale(const std::string& name) {
@@ -118,7 +175,7 @@ std::locale GetLocale(const std::string& name) {
         locale_gen.locale_cache_enabled(true);
         try {
             InfoLogger() << "Global locale: " << std::use_facet<boost::locale::info>(locale_gen("")).name();
-        } catch (std::runtime_error) {
+        } catch (const std::runtime_error&) {
             ErrorLogger() << "Global locale: set to invalid locale, setting to C locale";
             std::locale::global(std::locale::classic());
         }
@@ -128,7 +185,7 @@ std::locale GetLocale(const std::string& name) {
     std::locale retval;
     try {
         retval = locale_gen(name);
-    } catch(std::runtime_error) {
+    } catch(const std::runtime_error&) {
         ErrorLogger() << "Requested locale \"" << name << "\" is not a valid locale for this operating system";
         return std::locale::classic();
     }
@@ -146,8 +203,8 @@ void FlushLoadedStringTables() {
 const std::string& UserString(const std::string& str) {
     std::lock_guard<std::recursive_mutex> stringtable_lock(stringtable_access_mutex);
     if (GetStringTable().StringExists(str))
-        return GetStringTable().String(str);
-    return GetDefaultStringTable().String(str);
+        return GetStringTable()[str];
+    return GetDevDefaultStringTable()[str];
 }
 
 std::vector<std::string> UserStringList(const std::string& key) {
@@ -162,9 +219,7 @@ std::vector<std::string> UserStringList(const std::string& key) {
 
 bool UserStringExists(const std::string& str) {
     std::lock_guard<std::recursive_mutex> stringtable_lock(stringtable_access_mutex);
-    if (GetStringTable().StringExists(str))
-        return true;
-    return GetDefaultStringTable().StringExists(str);
+    return GetStringTable().StringExists(str) || GetDevDefaultStringTable().StringExists(str);
 }
 
 boost::format FlexibleFormat(const std::string &string_to_format) {
@@ -228,7 +283,6 @@ namespace {
         int pow10 = static_cast<int>(floor(log10(mag)));
         //std::cout << "magnitude power of 10: " << pow10 << std::endl;
 
-
         // round number to fit in requested number of digits
         // shift number by power of 10 so that ones digit is the lowest-value digit
         // that will be retained in final number
@@ -254,20 +308,6 @@ namespace {
 
         return mag;
     }
-
-    int TestRounding() {
-        for (double num : {-0.001, -0.02, 0.0001,
-                           84.5, 90.9, 99.9,
-                           9999.9, 245.1, 2451.1, 12451.1, 1124451.1})
-        {
-            std::cout << "n: " << num
-                      << "  r2: " << DoubleToString(num, 2, false)
-                      << "  r3: " << DoubleToString(num, 3, false)
-                      << "  r5: " << DoubleToString(num, 5, false) << std::endl;
-        }
-        exit(0);
-    }
-    //int dummy = TestRounding();
 }
 
 std::string DoubleToString(double val, int digits, bool always_show_sign) {
